@@ -72,7 +72,7 @@ BEGIN {
 		}
 	else if ($1 == "FILE_PATTERNS")
 		{
-		print "FILE_PATTERNS = lua.c"
+		print "FILE_PATTERNS = lua.cc"
 		FILE_PATTERNS_found = "TRUE"
 		next
 		}
@@ -100,7 +100,7 @@ BEGIN {
 		{print}
 		}
 }
-' ../doxygen.conf > "$TMPFILE"
+' "$SRCDIR"/doxygen.conf > "$TMPFILE"
 
 doxygen "$TMPFILE"
 
