@@ -22,16 +22,17 @@
 #include "main.h"
 #include "bar-exif.h"
 
-#include "exif.h"
-#include "metadata.h"
-#include "filedata.h"
-#include "ui-misc.h"
-#include "ui-menu.h"
 #include "bar.h"
-#include "rcfile.h"
 #include "dnd.h"
-#include "ui-utildlg.h"
+#include "exif.h"
+#include "filedata.h"
 #include "layout.h"
+#include "metadata.h"
+#include "misc.h"
+#include "rcfile.h"
+#include "ui-menu.h"
+#include "ui-misc.h"
+#include "ui-utildlg.h"
 
 #define MIN_HEIGHT 25
 /*
@@ -93,7 +94,7 @@ static gboolean bar_pane_exif_menu_cb(GtkWidget *widget, GdkEventButton *bevent,
 static void bar_pane_exif_notify_cb(FileData *fd, NotifyType type, gpointer data);
 static gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data);
 
-static void bar_pane_exif_entry_changed(GtkEntry *UNUSED(text_entry), gpointer data)
+static void bar_pane_exif_entry_changed(GtkEntry *, gpointer data)
 {
 	auto ee = static_cast<ExifEntry *>(data);
 	gchar *text;
@@ -104,7 +105,7 @@ static void bar_pane_exif_entry_changed(GtkEntry *UNUSED(text_entry), gpointer d
 	g_free(text);
 }
 
-static void bar_pane_exif_entry_destroy(GtkWidget *UNUSED(widget), gpointer data)
+static void bar_pane_exif_entry_destroy(GtkWidget *, gpointer data)
 {
 	auto ee = static_cast<ExifEntry *>(data);
 
@@ -118,17 +119,17 @@ static void bar_pane_exif_setup_entry_box(PaneExifData *ped, ExifEntry *ee)
 	gboolean horizontal = !ee->editable;
 	gboolean editable = ee->editable;
 
-	if (ee->box) gtk_widget_destroy(ee->box);
+	if (ee->box) g_object_unref(ee->box);
 
 	ee->box = horizontal ? gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0) : gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
-	gtk_container_add(GTK_CONTAINER(ee->ebox), ee->box);
+	gq_gtk_container_add(GTK_WIDGET(ee->ebox), ee->box);
 	gtk_widget_show(ee->box);
 
 	ee->title_label = gtk_label_new(nullptr);
 	gtk_label_set_xalign(GTK_LABEL(ee->title_label), horizontal ? 1.0 : 0.0);
 	gtk_label_set_yalign(GTK_LABEL(ee->title_label), 0.5);
 	gtk_size_group_add_widget(ped->size_group, ee->title_label);
-	gtk_box_pack_start(GTK_BOX(ee->box), ee->title_label, FALSE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(ee->box), ee->title_label, FALSE, TRUE, 0);
 	gtk_widget_show(ee->title_label);
 
 	if (editable)
@@ -141,14 +142,12 @@ static void bar_pane_exif_setup_entry_box(PaneExifData *ped, ExifEntry *ee)
 	else
 		{
 		ee->value_widget = gtk_label_new(nullptr);
-//		gtk_label_set_width_chars(GTK_LABEL(ee->value_widget), 20);
 		gtk_label_set_ellipsize(GTK_LABEL(ee->value_widget), PANGO_ELLIPSIZE_END);
-//		gtk_widget_set_size_request(ee->value_widget, 100, -1);
 		gtk_label_set_xalign(GTK_LABEL(ee->value_widget), 0.0);
 		gtk_label_set_yalign(GTK_LABEL(ee->value_widget), 0.5);
 		}
 
-	gtk_box_pack_start(GTK_BOX(ee->box), ee->value_widget, TRUE, TRUE, 1);
+	gq_gtk_box_pack_start(GTK_BOX(ee->box), ee->value_widget, TRUE, TRUE, 1);
 	gtk_widget_show(ee->value_widget);
 }
 
@@ -177,7 +176,7 @@ static GtkWidget *bar_pane_exif_add_entry(PaneExifData *ped, const gchar *key, c
 	g_signal_connect_after(G_OBJECT(ee->ebox), "destroy",
 			       G_CALLBACK(bar_pane_exif_entry_destroy), ee);
 
-	gtk_box_pack_start(GTK_BOX(ped->vbox), ee->ebox, FALSE, FALSE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(ped->vbox), ee->ebox, FALSE, FALSE, 0);
 
 	bar_pane_exif_entry_dnd_init(ee->ebox);
 	g_signal_connect(ee->ebox, "button_release_event", G_CALLBACK(bar_pane_exif_menu_cb), ped);
@@ -208,7 +207,7 @@ static void bar_pane_exif_reparent_entry(GtkWidget *entry, GtkWidget *pane)
 
 	ee->ped = ped;
 	gtk_size_group_add_widget(ped->size_group, ee->title_label);
-	gtk_box_pack_start(GTK_BOX(ped->vbox), entry, FALSE, FALSE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(ped->vbox), entry, FALSE, FALSE, 0);
 }
 
 static void bar_pane_exif_entry_update_title(ExifEntry *ee)
@@ -247,7 +246,7 @@ static void bar_pane_exif_update_entry(PaneExifData *ped, GtkWidget *entry, gboo
 		if (ee->editable)
 			{
 			g_signal_handlers_block_by_func(ee->value_widget, (gpointer *)bar_pane_exif_entry_changed, ee);
-			gtk_entry_set_text(GTK_ENTRY(ee->value_widget), text ? text : "");
+			gq_gtk_entry_set_text(GTK_ENTRY(ee->value_widget), text ? text : "");
 			g_signal_handlers_unblock_by_func(ee->value_widget, (gpointer)bar_pane_exif_entry_changed, ee);
 			gtk_widget_set_tooltip_text(ee->box, nullptr);
 			}
@@ -285,7 +284,7 @@ static void bar_pane_exif_update(PaneExifData *ped)
 	gtk_widget_set_sensitive(ped->pane.title, !ped->all_hidden);
 }
 
-void bar_pane_exif_set_fd(GtkWidget *widget, FileData *fd)
+static void bar_pane_exif_set_fd(GtkWidget *widget, FileData *fd)
 {
 	PaneExifData *ped;
 
@@ -298,7 +297,7 @@ void bar_pane_exif_set_fd(GtkWidget *widget, FileData *fd)
 	bar_pane_exif_update(ped);
 }
 
-gint bar_pane_exif_event(GtkWidget *bar, GdkEvent *event)
+static gint bar_pane_exif_event(GtkWidget *bar, GdkEvent *event)
 {
 	PaneExifData *ped;
 	gboolean ret = FALSE;
@@ -351,9 +350,9 @@ static GtkTargetEntry bar_pane_exif_drop_types[] = {
 static gint n_exif_entry_drop_types = 2;
 
 
-static void bar_pane_exif_entry_dnd_get(GtkWidget *entry, GdkDragContext *UNUSED(context),
+static void bar_pane_exif_entry_dnd_get(GtkWidget *entry, GdkDragContext *,
 				     GtkSelectionData *selection_data, guint info,
-				     guint UNUSED(time), gpointer UNUSED(data))
+				     guint, gpointer)
 {
 	auto ee = static_cast<ExifEntry *>(g_object_get_data(G_OBJECT(entry), "entry_data"));
 
@@ -372,10 +371,10 @@ static void bar_pane_exif_entry_dnd_get(GtkWidget *entry, GdkDragContext *UNUSED
 
 }
 
-static void bar_pane_exif_dnd_receive(GtkWidget *pane, GdkDragContext *UNUSED(context),
+static void bar_pane_exif_dnd_receive(GtkWidget *pane, GdkDragContext *,
 					  gint x, gint y,
 					  GtkSelectionData *selection_data, guint info,
-					  guint UNUSED(time), gpointer UNUSED(data))
+					  guint, gpointer)
 {
 	PaneExifData *ped;
 	GList *work, *list;
@@ -423,7 +422,7 @@ static void bar_pane_exif_dnd_receive(GtkWidget *pane, GdkDragContext *UNUSED(co
 	gtk_box_reorder_child(GTK_BOX(ped->vbox), new_entry, pos);
 }
 
-static void bar_pane_exif_entry_dnd_begin(GtkWidget *entry, GdkDragContext *context, gpointer UNUSED(data))
+static void bar_pane_exif_entry_dnd_begin(GtkWidget *entry, GdkDragContext *context, gpointer)
 {
 	auto ee = static_cast<ExifEntry *>(g_object_get_data(G_OBJECT(entry), "entry_data"));
 
@@ -431,7 +430,7 @@ static void bar_pane_exif_entry_dnd_begin(GtkWidget *entry, GdkDragContext *cont
 	dnd_set_drag_label(entry, context, ee->key);
 }
 
-static void bar_pane_exif_entry_dnd_end(GtkWidget *UNUSED(widget), GdkDragContext *UNUSED(context), gpointer UNUSED(data))
+static void bar_pane_exif_entry_dnd_end(GtkWidget *, GdkDragContext *, gpointer)
 {
 }
 
@@ -461,24 +460,24 @@ static void bar_pane_exif_dnd_init(GtkWidget *pane)
 			 G_CALLBACK(bar_pane_exif_dnd_receive), NULL);
 }
 
-static void bar_pane_exif_edit_close_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void bar_pane_exif_edit_close_cb(GtkWidget *, gpointer data)
 {
 	auto gd = static_cast<GenericDialog *>(data);
 	generic_dialog_close(gd);
 }
 
-static void bar_pane_exif_edit_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void bar_pane_exif_edit_destroy_cb(GtkWidget *, gpointer data)
 {
 	auto cdd = static_cast<ConfDialogData *>(data);
 	g_signal_handlers_disconnect_by_func(cdd->widget, (gpointer)(bar_pane_exif_edit_close_cb), cdd->gd);
 	g_free(cdd);
 }
 
-static void bar_pane_exif_edit_cancel_cb(GenericDialog *UNUSED(gd), gpointer UNUSED(data))
+static void bar_pane_exif_edit_cancel_cb(GenericDialog *, gpointer)
 {
 }
 
-static void bar_pane_exif_edit_ok_cb(GenericDialog *UNUSED(gd), gpointer data)
+static void bar_pane_exif_edit_ok_cb(GenericDialog *, gpointer data)
 {
 	auto cdd = static_cast<ConfDialogData *>(data);
 
@@ -489,8 +488,8 @@ static void bar_pane_exif_edit_ok_cb(GenericDialog *UNUSED(gd), gpointer data)
 	if (ped)
 		{
 		bar_pane_exif_add_entry(ped,
-					gtk_entry_get_text(GTK_ENTRY(cdd->key_entry)),
-					gtk_entry_get_text(GTK_ENTRY(cdd->title_entry)),
+					gq_gtk_entry_get_text(GTK_ENTRY(cdd->key_entry)),
+					gq_gtk_entry_get_text(GTK_ENTRY(cdd->title_entry)),
 					cdd->if_set, cdd->editable);
 		}
 
@@ -509,8 +508,8 @@ static void bar_pane_exif_edit_ok_cb(GenericDialog *UNUSED(gd), gpointer data)
 		if (!pane) return;
 
 		g_free(ee->key);
-		ee->key = g_strdup(gtk_entry_get_text(GTK_ENTRY(cdd->key_entry)));
-		title = gtk_entry_get_text(GTK_ENTRY(cdd->title_entry));
+		ee->key = g_strdup(gq_gtk_entry_get_text(GTK_ENTRY(cdd->key_entry)));
+		title = gq_gtk_entry_get_text(GTK_ENTRY(cdd->title_entry));
 		if (!title || strlen(title) == 0)
 			{
 			g_free(ee->title);
@@ -564,25 +563,25 @@ static void bar_pane_exif_conf_dialog(GtkWidget *widget)
 
 	generic_dialog_add_message(gd, nullptr, ee ? _("Configure entry") : _("Add entry"), nullptr, FALSE);
 
-	generic_dialog_add_button(gd, GTK_STOCK_OK, nullptr,
+	generic_dialog_add_button(gd, GQ_ICON_OK, "OK",
 				  bar_pane_exif_edit_ok_cb, TRUE);
 
 	table = pref_table_new(gd->vbox, 3, 2, FALSE, TRUE);
-	pref_table_label(table, 0, 0, _("Key:"), 1.0);
+	pref_table_label(table, 0, 0, _("Key:"), GTK_ALIGN_END);
 
 	cdd->key_entry = gtk_entry_new();
 	gtk_widget_set_size_request(cdd->key_entry, 300, -1);
-	if (ee) gtk_entry_set_text(GTK_ENTRY(cdd->key_entry), ee->key);
-	gtk_table_attach_defaults(GTK_TABLE(table), cdd->key_entry, 1, 2, 0, 1);
+	if (ee) gq_gtk_entry_set_text(GTK_ENTRY(cdd->key_entry), ee->key);
+	gq_gtk_grid_attach_default(GTK_GRID(table), cdd->key_entry, 1, 2, 0, 1);
 	generic_dialog_attach_default(gd, cdd->key_entry);
 	gtk_widget_show(cdd->key_entry);
 
-	pref_table_label(table, 0, 1, _("Title:"), 1.0);
+	pref_table_label(table, 0, 1, _("Title:"), GTK_ALIGN_END);
 
 	cdd->title_entry = gtk_entry_new();
 	gtk_widget_set_size_request(cdd->title_entry, 300, -1);
-	if (ee) gtk_entry_set_text(GTK_ENTRY(cdd->title_entry), ee->title);
-	gtk_table_attach_defaults(GTK_TABLE(table), cdd->title_entry, 1, 2, 1, 2);
+	if (ee) gq_gtk_entry_set_text(GTK_ENTRY(cdd->title_entry), ee->title);
+	gq_gtk_grid_attach_default(GTK_GRID(table), cdd->title_entry, 1, 2, 1, 2);
 	generic_dialog_attach_default(gd, cdd->title_entry);
 	gtk_widget_show(cdd->title_entry);
 
@@ -592,19 +591,25 @@ static void bar_pane_exif_conf_dialog(GtkWidget *widget)
 	gtk_widget_show(gd->dialog);
 }
 
-static void bar_pane_exif_conf_dialog_cb(GtkWidget *UNUSED(menu_widget), gpointer data)
+static void bar_pane_exif_conf_dialog_cb(GtkWidget *, gpointer data)
 {
 	auto widget = static_cast<GtkWidget *>(data);
 	bar_pane_exif_conf_dialog(widget);
 }
 
-static void bar_pane_exif_delete_entry_cb(GtkWidget *UNUSED(menu_widget), gpointer data)
+static void bar_pane_exif_delete_entry_cb(GtkWidget *, gpointer data)
 {
 	auto entry = static_cast<GtkWidget *>(data);
-	gtk_widget_destroy(entry);
+	g_object_unref(entry);
 }
 
-static void bar_pane_exif_copy_entry_cb(GtkWidget *UNUSED(menu_widget), gpointer data)
+#ifdef HAVE_GTK4
+static void bar_pane_exif_copy_entry_cb(GtkWidget *, gpointer data)
+{
+/* @FIXME GTK4 stub */
+}
+#else
+static void bar_pane_exif_copy_entry_cb(GtkWidget *, gpointer data)
 {
 	auto widget = static_cast<GtkWidget *>(data);
 	GtkClipboard *clipboard;
@@ -616,8 +621,9 @@ static void bar_pane_exif_copy_entry_cb(GtkWidget *UNUSED(menu_widget), gpointer
 	clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
 	gtk_clipboard_set_text(clipboard, value, -1);
 }
+#endif
 
-static void bar_pane_exif_toggle_show_all_cb(GtkWidget *UNUSED(menu_widget), gpointer data)
+static void bar_pane_exif_toggle_show_all_cb(GtkWidget *, gpointer data)
 {
 	auto ped = static_cast<PaneExifData *>(data);
 	ped->show_all = !ped->show_all;
@@ -640,9 +646,9 @@ static void bar_pane_exif_menu_popup(GtkWidget *widget, PaneExifData *ped)
 		gchar *del = g_strdup_printf(_("Remove \"%s\""), ee->title);
 		gchar *copy = g_strdup_printf(_("Copy \"%s\""), ee->title);
 
-		menu_item_add_stock(menu, conf, GTK_STOCK_EDIT, G_CALLBACK(bar_pane_exif_conf_dialog_cb), widget);
-		menu_item_add_stock(menu, del, GTK_STOCK_DELETE, G_CALLBACK(bar_pane_exif_delete_entry_cb), widget);
-		menu_item_add_stock(menu, copy, GTK_STOCK_COPY, G_CALLBACK(bar_pane_exif_copy_entry_cb), widget);
+		menu_item_add_icon(menu, conf, GQ_ICON_EDIT, G_CALLBACK(bar_pane_exif_conf_dialog_cb), widget);
+		menu_item_add_icon(menu, del, GQ_ICON_DELETE, G_CALLBACK(bar_pane_exif_delete_entry_cb), widget);
+		menu_item_add_icon(menu, copy, GQ_ICON_COPY, G_CALLBACK(bar_pane_exif_copy_entry_cb), widget);
 		menu_item_add_divider(menu);
 
 		g_free(conf);
@@ -650,7 +656,7 @@ static void bar_pane_exif_menu_popup(GtkWidget *widget, PaneExifData *ped)
 		}
 
 	/* for the pane */
-	menu_item_add_stock(menu, _("Add entry"), GTK_STOCK_ADD, G_CALLBACK(bar_pane_exif_conf_dialog_cb), ped->widget);
+	menu_item_add_icon(menu, _("Add entry"), GQ_ICON_ADD, G_CALLBACK(bar_pane_exif_conf_dialog_cb), ped->widget);
 	menu_item_add_check(menu, _("Show hidden entries"), ped->show_all, G_CALLBACK(bar_pane_exif_toggle_show_all_cb), ped);
 
 	gtk_menu_popup_at_pointer(GTK_MENU(menu), nullptr);
@@ -667,7 +673,14 @@ static gboolean bar_pane_exif_menu_cb(GtkWidget *widget, GdkEventButton *bevent,
 	return FALSE;
 }
 
-static gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer UNUSED(data))
+#ifdef HAVE_GTK4
+static gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer)
+{
+/* @FIXME GTK4 stub */
+	return FALSE;
+}
+#else
+static gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer)
 {
 	const gchar *value;
 	GtkClipboard *clipboard;
@@ -685,8 +698,7 @@ static gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent,
 
 	return FALSE;
 }
-
-
+#endif
 
 static void bar_pane_exif_entry_write_config(GtkWidget *entry, GString *outstr, gint indent)
 {
@@ -752,10 +764,11 @@ GList * bar_pane_exif_list()
 		ped = static_cast<PaneExifData *>(g_object_get_data(G_OBJECT(pane), "pane_data"));
 
 		list = gtk_container_get_children(GTK_CONTAINER(ped->vbox));
-		while (list)
+		GList *work = list;
+		while (work)
 			{
-			entry = static_cast<GtkWidget *>(list->data);
-			list = list->next;
+			entry = static_cast<GtkWidget *>(work->data);
+			work = work->next;
 			ee = static_cast<ExifEntry *>(g_object_get_data(G_OBJECT(entry), "entry_data"));
 			exif_list = g_list_append(exif_list, g_strdup(ee->title));
 			exif_list = g_list_append(exif_list, g_strdup(ee->key));
@@ -766,17 +779,20 @@ GList * bar_pane_exif_list()
 	return exif_list;
 }
 
-//void bar_pane_exif_close(GtkWidget *widget)
-//{
-	//PaneExifData *ped;
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+void bar_pane_exif_close_unused(GtkWidget *widget)
+{
+	PaneExifData *ped;
 
-	//ped = g_object_get_data(G_OBJECT(widget), "pane_data");
-	//if (!ped) return;
+	ped = static_cast<PaneExifData *>(g_object_get_data(G_OBJECT(widget), "pane_data"));
+	if (!ped) return;
 
-	//gtk_widget_destroy(ped->vbox);
-//}
+	g_object_unref(ped->vbox);
+}
+#pragma GCC diagnostic pop
 
-static void bar_pane_exif_destroy(GtkWidget *UNUSED(widget), gpointer data)
+static void bar_pane_exif_destroy(GtkWidget *, gpointer data)
 {
 	auto ped = static_cast<PaneExifData *>(data);
 
@@ -787,16 +803,19 @@ static void bar_pane_exif_destroy(GtkWidget *UNUSED(widget), gpointer data)
 	g_free(ped);
 }
 
-//~ static void bar_pane_exif_size_request(GtkWidget *UNUSED(pane), GtkRequisition *requisition, gpointer data)
-//~ {
-	//~ PaneExifData *ped = static_cast<//~ *>(data);
-	//~ if (requisition->height < ped->min_height)
-		//~ {
-		//~ requisition->height = ped->min_height;
-		//~ }
-//~ }
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+static void bar_pane_exif_size_request_unused(GtkWidget *, GtkRequisition *requisition, gpointer data)
+{
+	PaneExifData *ped = static_cast<PaneExifData *>(data);
+	if (requisition->height < ped->min_height)
+		{
+		requisition->height = ped->min_height;
+		}
+}
+#pragma GCC diagnostic pop
 
-static void bar_pane_exif_size_allocate(GtkWidget *UNUSED(pane), GtkAllocation *alloc, gpointer data)
+static void bar_pane_exif_size_allocate(GtkWidget *, GtkAllocation *alloc, gpointer data)
 {
 	auto ped = static_cast<PaneExifData *>(data);
 	ped->min_height = alloc->height;
@@ -821,7 +840,7 @@ static GtkWidget *bar_pane_exif_new(const gchar *id, const gchar *title, gboolea
 	ped->size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 	ped->widget = gtk_event_box_new();
 	ped->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, PREF_PAD_GAP);
-	gtk_container_add(GTK_CONTAINER(ped->widget), ped->vbox);
+	gq_gtk_container_add(GTK_WIDGET(ped->widget), ped->vbox);
 	gtk_widget_show(ped->vbox);
 
 	ped->min_height = MIN_HEIGHT;
