@@ -24,16 +24,17 @@
 
 #include "collect.h"
 #include "collect-io.h"
+#include "editors.h"
 #include "filedata.h"
 #include "history-list.h"
 #include "layout.h"
 #include "layout-image.h"
-#include "utilops.h"
-#include "editors.h"
+#include "misc.h"
+#include "rcfile.h"
 #include "ui-bookmark.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
-#include "rcfile.h"
+#include "utilops.h"
 #include "window.h"
 
 
@@ -166,13 +167,13 @@ static void bar_sort_mode_cb(GtkWidget *combo, gpointer data)
 /* this takes control of src_list */
 static void bar_sort_undo_set(SortData *sd, GList *src_list, const gchar *dest)
 {
-	string_list_free(sd->undo_src_list);
+	g_list_free_full(sd->undo_src_list, g_free);
 	sd->undo_src_list = filelist_to_path_list(src_list);
 
 	if (src_list)
 		{
 		/* we should create the undo_dest_list to use it later... */
-		string_list_free(sd->undo_dest_list);
+		g_list_free_full(sd->undo_dest_list, g_free);
 		sd->undo_dest_list=nullptr;
 
 		GList *work = sd->undo_src_list;
@@ -291,7 +292,7 @@ static void bar_sort_undo_cb(GtkWidget *button, gpointer data)
 		}
 }
 
-static void bar_sort_bookmark_select_folder(SortData *sd, FileData *UNUSED(source), const gchar *path)
+static void bar_sort_bookmark_select_folder(SortData *sd, FileData *, const gchar *path)
 {
 	GList *orig_list;
 	GList *action_list;
@@ -420,7 +421,7 @@ static void bar_sort_set_filter_cb(GtkWidget *button, gpointer data)
 	bar_sort_set_action(sd, BAR_SORT_FILTER, key);
 }
 
-static void bar_filter_help_cb(GenericDialog *UNUSED(gd), gpointer UNUSED(data))
+static void bar_filter_help_cb(GenericDialog *, gpointer)
 {
 	help_window_show("GuidePluginsConfig.html#Geeqieextensions");
 }
@@ -431,15 +432,15 @@ static void bar_filter_help_dialog()
 
 	gd = generic_dialog_new(_("Sort Manager Operations"),
 				"sort_manager_operations", nullptr, TRUE, nullptr, nullptr);
-	generic_dialog_add_message(gd, GTK_STOCK_DIALOG_INFO,
+	generic_dialog_add_message(gd, GQ_ICON_DIALOG_INFO,
 				"Sort Manager Operations", _("Additional operations utilising plugins\nmay be included by setting:\n\nX-Geeqie-Filter=true\n\nin the plugin file."), TRUE);
-	generic_dialog_add_button(gd, GTK_STOCK_HELP, nullptr, bar_filter_help_cb, TRUE);
-	generic_dialog_add_button(gd, GTK_STOCK_OK, nullptr, nullptr, TRUE);
+	generic_dialog_add_button(gd, GQ_ICON_HELP, _("Help"), bar_filter_help_cb, TRUE);
+	generic_dialog_add_button(gd, GQ_ICON_OK, "OK", NULL, TRUE);
 
 	gtk_widget_show(gd->dialog);
 }
 
-static gboolean bar_filter_message_cb(GtkWidget *UNUSED(widget), GdkEventButton *event, gpointer UNUSED(data))
+static gboolean bar_filter_message_cb(GtkWidget *, GdkEventButton *event, gpointer)
 {
 	if (event->button != MOUSE_BUTTON_RIGHT) return FALSE;
 
@@ -448,7 +449,7 @@ static gboolean bar_filter_message_cb(GtkWidget *UNUSED(widget), GdkEventButton
 	return TRUE;
 }
 
-static void bar_sort_help_cb(gpointer UNUSED(data))
+static void bar_sort_help_cb(gpointer)
 {
 	bar_filter_help_dialog();
 }
@@ -482,10 +483,10 @@ static void bar_sort_add_close(SortData *sd)
 static void bar_sort_add_ok_cb(FileDialog *fd, gpointer data)
 {
 	auto sd = static_cast<SortData *>(data);
-	const gchar *name = gtk_entry_get_text(GTK_ENTRY(sd->dialog_name_entry));
+	const gchar *name = gq_gtk_entry_get_text(GTK_ENTRY(sd->dialog_name_entry));
 	gboolean empty_name = (name[0] == '\0');
 
-	name = gtk_entry_get_text(GTK_ENTRY(sd->dialog_name_entry));
+	name = gq_gtk_entry_get_text(GTK_ENTRY(sd->dialog_name_entry));
 	if (sd->mode == BAR_SORT_MODE_FOLDER)
 		{
 		if (empty_name)
@@ -513,7 +514,7 @@ static void bar_sort_add_ok_cb(FileDialog *fd, gpointer data)
 		if (isfile(path))
 			{
 			gchar *text = g_strdup_printf(_("The collection:\n%s\nalready exists."), filename);
-			file_util_warning_dialog(_("Collection exists"), text, GTK_STOCK_DIALOG_INFO, nullptr);
+			file_util_warning_dialog(_("Collection exists"), text, GQ_ICON_DIALOG_INFO, nullptr);
 			g_free(text);
 			}
 		else
@@ -529,7 +530,7 @@ static void bar_sort_add_ok_cb(FileDialog *fd, gpointer data)
 				{
 				gchar *text = g_strdup_printf(_("Failed to save the collection:\n%s"), path);
 				file_util_warning_dialog(_("Save Failed"), text,
-							 GTK_STOCK_DIALOG_ERROR, GENERIC_DIALOG(fd)->dialog);
+							 GQ_ICON_DIALOG_ERROR, GENERIC_DIALOG(fd)->dialog);
 				g_free(text);
 				}
 			collection_unref(cd);
@@ -542,7 +543,7 @@ static void bar_sort_add_ok_cb(FileDialog *fd, gpointer data)
 	bar_sort_add_close(sd);
 }
 
-static void bar_sort_add_cancel_cb(FileDialog *UNUSED(fd), gpointer data)
+static void bar_sort_add_cancel_cb(FileDialog *, gpointer data)
 {
 	auto sd = static_cast<SortData *>(data);
 
@@ -573,7 +574,7 @@ static void bar_sort_add_cb(GtkWidget *button, gpointer data)
 	sd->dialog = file_util_file_dlg(title,
 				       "add_bookmark", button,
 				       bar_sort_add_cancel_cb, sd);
-	file_dialog_add_button(sd->dialog, GTK_STOCK_OK, nullptr, bar_sort_add_ok_cb, TRUE);
+	file_dialog_add_button(sd->dialog, GQ_ICON_OK, "OK", bar_sort_add_ok_cb, TRUE);
 
 	generic_dialog_add_message(GENERIC_DIALOG(sd->dialog), nullptr, title, nullptr, FALSE);
 
@@ -587,7 +588,7 @@ static void bar_sort_add_cb(GtkWidget *button, gpointer data)
 	pref_label_new(hbox, _("Name:"));
 
 	sd->dialog_name_entry = gtk_entry_new();
-	gtk_box_pack_start(GTK_BOX(hbox), sd->dialog_name_entry, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(hbox), sd->dialog_name_entry, TRUE, TRUE, 0);
 	generic_dialog_attach_default(GENERIC_DIALOG(sd->dialog), sd->dialog_name_entry);
 	gtk_widget_show(sd->dialog_name_entry);
 
@@ -606,18 +607,18 @@ void bar_sort_close(GtkWidget *bar)
 	sd = static_cast<SortData *>(g_object_get_data(G_OBJECT(bar), "bar_sort_data"));
 	if (!sd) return;
 
-	gtk_widget_destroy(sd->vbox);
+	gq_gtk_widget_destroy(sd->vbox);
 }
 
-static void bar_sort_destroy(GtkWidget *UNUSED(widget), gpointer data)
+static void bar_sort_destroy(GtkWidget *, gpointer data)
 {
 	auto sd = static_cast<SortData *>(data);
 
 	bar_sort_add_close(sd);
 
 	g_free(sd->filter_key);
-	string_list_free(sd->undo_src_list);
-	string_list_free(sd->undo_dest_list);
+	g_list_free_full(sd->undo_src_list, g_free);
+	g_list_free_full(sd->undo_dest_list, g_free);
 	g_free(sd->undo_collection);
 	g_free(sd);
 }
@@ -666,11 +667,11 @@ static GtkWidget *bar_sort_new(LayoutWindow *lw, SortActionType action,
 
 	label = gtk_label_new(_("Sort Manager"));
 	pref_label_bold(label, TRUE, FALSE);
-	gtk_box_pack_start(GTK_BOX(sd->vbox), label, FALSE, FALSE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(sd->vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
 	combo = gtk_combo_box_text_new();
-	gtk_box_pack_start(GTK_BOX(sd->vbox), combo, FALSE, FALSE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(sd->vbox), combo, FALSE, FALSE, 0);
 	gtk_widget_show(combo);
 
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Folders"));
@@ -737,19 +738,19 @@ static GtkWidget *bar_sort_new(LayoutWindow *lw, SortActionType action,
 
 	sd->bookmarks = bookmark_list_new(SORT_KEY_FOLDERS, bar_sort_bookmark_select, sd);
 	DEBUG_NAME(sd->bookmarks);
-	gtk_box_pack_start(GTK_BOX(sd->vbox), sd->bookmarks, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(sd->vbox), sd->bookmarks, TRUE, TRUE, 0);
 	gtk_widget_show(sd->bookmarks);
 
-	tbar = pref_toolbar_new(sd->vbox, GTK_TOOLBAR_ICONS);
+	tbar = pref_toolbar_new(sd->vbox);
 	DEBUG_NAME(tbar);
 
-	sd->add_button = pref_toolbar_button(tbar, GTK_STOCK_ADD, nullptr, FALSE,
+	sd->add_button = pref_toolbar_button(tbar, GQ_ICON_ADD, _("Add"), FALSE,
 					     _("Add Bookmark"),
 					     G_CALLBACK(bar_sort_add_cb), sd);
-	sd->undo_button = pref_toolbar_button(tbar, GTK_STOCK_UNDO, nullptr, FALSE,
+	sd->undo_button = pref_toolbar_button(tbar, GQ_ICON_UNDO, _("Undo"), FALSE,
 					      _("Undo last image"),
 					      G_CALLBACK(bar_sort_undo_cb), sd);
-	sd->help_button = pref_toolbar_button(tbar, GTK_STOCK_HELP, nullptr, FALSE,
+	sd->help_button = pref_toolbar_button(tbar, GQ_ICON_HELP, _("Help"), FALSE,
 					      _("Functions additional to Copy and Move"),
 					      G_CALLBACK(bar_sort_help_cb), sd);
 
@@ -760,7 +761,7 @@ static GtkWidget *bar_sort_new(LayoutWindow *lw, SortActionType action,
 	return sd->vbox;
 }
 
-GtkWidget *bar_sort_new_from_config(LayoutWindow *lw, const gchar **UNUSED(attribute_names), const gchar **UNUSED(attribute_values))
+GtkWidget *bar_sort_new_from_config(LayoutWindow *lw, const gchar **, const gchar **)
 {
 	GtkWidget *bar;
 
