@@ -22,6 +22,9 @@
 #ifndef BAR_H
 #define BAR_H
 
+struct FileData;
+struct LayoutWindow;
+
 enum PaneType {
 	PANE_UNDEF = 0,
 	PANE_COMMENT,
@@ -71,7 +74,6 @@ gboolean bar_event(GtkWidget *bar, GdkEvent *event);
 GtkWidget *bar_pane_expander_title(const gchar *title);
 void bar_update_expander(GtkWidget *pane);
 gboolean bar_pane_translate_title(PaneType type, const gchar *id, gchar **title);
-const gchar *bar_pane_get_default_config(const gchar *id);
 
 #endif
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
