@@ -25,12 +25,12 @@
 #include "cache-loader.h"
 #include "filedata.h"
 #include "layout.h"
+#include "misc.h"
 #include "pixbuf-util.h"
 #include "thumb.h"
 #include "thumb-standard.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
-#include "ui-spinner.h"
 #include "ui-tabcomp.h"
 #include "ui-utildlg.h"
 #include "window.h"
@@ -60,18 +60,18 @@ struct CMData
 static gchar *cache_maintenance_path = nullptr;
 static GtkStatusIcon *status_icon;
 
-static void cache_maintenance_sim_stop_cb(gpointer UNUSED(data))
+static void cache_maintenance_sim_stop_cb(gpointer)
 {
 	exit(EXIT_SUCCESS);
 }
 
-static void cache_maintenance_render_stop_cb(gpointer UNUSED(data))
+static void cache_maintenance_render_stop_cb(gpointer)
 {
 	gtk_status_icon_set_tooltip_text(status_icon, _("Geeqie: Creating sim data..."));
 	cache_manager_sim_remote(cache_maintenance_path, TRUE, reinterpret_cast<GDestroyNotify *>(cache_maintenance_sim_stop_cb));
 }
 
-static void cache_maintenance_clean_stop_cb(gpointer UNUSED(data))
+static void cache_maintenance_clean_stop_cb(gpointer)
 {
 	gtk_status_icon_set_tooltip_text(status_icon, _("Geeqie: Creating thumbs..."));
 	cache_manager_render_remote(cache_maintenance_path, TRUE, options->thumbnails.cache_into_dirs, reinterpret_cast<GDestroyNotify *>(cache_maintenance_render_stop_cb));
@@ -82,7 +82,7 @@ static void cache_maintenance_user_cancel_cb()
 	exit(EXIT_FAILURE);
 }
 
-static void cache_maintenance_status_icon_activate_cb(GtkStatusIcon *UNUSED(status), gpointer UNUSED(data))
+static void cache_maintenance_status_icon_activate_cb(GtkStatusIcon *, gpointer)
 {
 	GtkWidget *menu;
 	GtkWidget *item;
@@ -149,7 +149,7 @@ static gboolean isempty(const gchar *path)
 		{
 		gchar *name = dir->d_name;
 
-		if (!(name[0] == '.' && (name[1] == '\0' || (name[1] == '.' && name[2] == '\0'))) )
+		if (name[0] != '.' || (name[1] != '\0' && (name[1] != '.' || name[2] != '\0')) )
 			{
 			closedir(dp);
 			return FALSE;
@@ -179,8 +179,8 @@ static void cache_maintain_home_stop(CMData *cm)
 
 	if (!cm->remote)
 		{
-		gtk_entry_set_text(GTK_ENTRY(cm->entry), _("done"));
-		spinner_set_interval(cm->spinner, -1);
+		gq_gtk_entry_set_text(GTK_ENTRY(cm->entry), _("done"));
+		gtk_spinner_stop(GTK_SPINNER(cm->spinner));
 
 		gtk_widget_set_sensitive(cm->button_stop, FALSE);
 		gtk_widget_set_sensitive(cm->button_close, TRUE);
@@ -310,13 +310,13 @@ static gboolean cache_maintain_home_cb(gpointer data)
 			{
 			buf = "...";
 			}
-		gtk_entry_set_text(GTK_ENTRY(cm->entry), buf);
+		gq_gtk_entry_set_text(GTK_ENTRY(cm->entry), buf);
 		}
 
 	return G_SOURCE_CONTINUE;
 }
 
-static void cache_maintain_home_close_cb(GenericDialog *UNUSED(gd), gpointer data)
+static void cache_maintain_home_close_cb(GenericDialog *, gpointer data)
 {
 	auto cm = static_cast<CMData *>(data);
 
@@ -325,7 +325,7 @@ static void cache_maintain_home_close_cb(GenericDialog *UNUSED(gd), gpointer dat
 	cache_maintain_home_close(cm);
 }
 
-static void cache_maintain_home_stop_cb(GenericDialog *UNUSED(gd), gpointer data)
+static void cache_maintain_home_stop_cb(GenericDialog *, gpointer data)
 {
 	auto cm = static_cast<CMData *>(data);
 
@@ -385,27 +385,28 @@ void cache_maintain_home(gboolean metadata, gboolean clear, GtkWidget *parent)
 				    parent, FALSE,
 				    nullptr, cm);
 	cm->gd->cancel_cb = cache_maintain_home_close_cb;
-	cm->button_close = generic_dialog_add_button(cm->gd, GTK_STOCK_CLOSE, nullptr,
+	cm->button_close = generic_dialog_add_button(cm->gd, GQ_ICON_CLOSE, _("Close"),
 						     cache_maintain_home_close_cb, FALSE);
 	gtk_widget_set_sensitive(cm->button_close, FALSE);
-	cm->button_stop = generic_dialog_add_button(cm->gd, GTK_STOCK_STOP, nullptr,
+	cm->button_stop = generic_dialog_add_button(cm->gd, GQ_ICON_STOP, _("Stop"),
 						    cache_maintain_home_stop_cb, FALSE);
 
 	generic_dialog_add_message(cm->gd, nullptr, msg, nullptr, FALSE);
 	gtk_window_set_default_size(GTK_WINDOW(cm->gd->dialog), PURGE_DIALOG_WIDTH, -1);
 
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_box_pack_start(GTK_BOX(cm->gd->vbox), hbox, FALSE, FALSE, 5);
+	gq_gtk_box_pack_start(GTK_BOX(cm->gd->vbox), hbox, FALSE, FALSE, 5);
 	gtk_widget_show(hbox);
 
 	cm->entry = gtk_entry_new();
 	gtk_widget_set_can_focus(cm->entry, FALSE);
 	gtk_editable_set_editable(GTK_EDITABLE(cm->entry), FALSE);
-	gtk_box_pack_start(GTK_BOX(hbox), cm->entry, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(hbox), cm->entry, TRUE, TRUE, 0);
 	gtk_widget_show(cm->entry);
 
-	cm->spinner = spinner_new(nullptr, SPINNER_SPEED);
-	gtk_box_pack_start(GTK_BOX(hbox), cm->spinner, FALSE, FALSE, 0);
+	cm->spinner = gtk_spinner_new();
+	gtk_spinner_start(GTK_SPINNER(cm->spinner));
+	gq_gtk_box_pack_start(GTK_BOX(hbox), cm->spinner, FALSE, FALSE, 0);
 	gtk_widget_show(cm->spinner);
 
 	gtk_widget_show(cm->gd->dialog);
@@ -573,7 +574,7 @@ static void cache_maint_copied(FileData *fd)
 	g_free(src_cache);
 }
 
-void cache_notify_cb(FileData *fd, NotifyType type, gpointer UNUSED(data))
+void cache_notify_cb(FileData *fd, NotifyType type, gpointer)
 {
 	if (!(type & NOTIFY_CHANGE) || !fd->change) return;
 
@@ -661,7 +662,7 @@ static void cache_manager_render_reset(CacheOpsData *cd)
 	cd->tl = nullptr;
 }
 
-static void cache_manager_render_close_cb(GenericDialog *UNUSED(fd), gpointer data)
+static void cache_manager_render_close_cb(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 
@@ -677,8 +678,8 @@ static void cache_manager_render_finish(CacheOpsData *cd)
 	cache_manager_render_reset(cd);
 	if (!cd->remote)
 		{
-		gtk_entry_set_text(GTK_ENTRY(cd->progress), _("done"));
-		spinner_set_interval(cd->spinner, -1);
+		gq_gtk_entry_set_text(GTK_ENTRY(cd->progress), _("done"));
+		gtk_spinner_stop(GTK_SPINNER(cd->spinner));
 
 		gtk_widget_set_sensitive(cd->group, TRUE);
 		gtk_widget_set_sensitive(cd->button_start, TRUE);
@@ -687,11 +688,11 @@ static void cache_manager_render_finish(CacheOpsData *cd)
 		}
 }
 
-static void cache_manager_render_stop_cb(GenericDialog *UNUSED(fd), gpointer data)
+static void cache_manager_render_stop_cb(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 
-	gtk_entry_set_text(GTK_ENTRY(cd->progress), _("stopped"));
+	gq_gtk_entry_set_text(GTK_ENTRY(cd->progress), _("stopped"));
 	cache_manager_render_finish(cd);
 }
 
@@ -718,7 +719,7 @@ static void cache_manager_render_folder(CacheOpsData *cd, FileData *dir_fd)
 
 static gboolean cache_manager_render_file(CacheOpsData *cd);
 
-static void cache_manager_render_thumb_done_cb(ThumbLoader *UNUSED(tl), gpointer data)
+static void cache_manager_render_thumb_done_cb(ThumbLoader *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 
@@ -749,7 +750,7 @@ static gboolean cache_manager_render_file(CacheOpsData *cd)
 			{
 			if (!cd->remote)
 				{
-				gtk_entry_set_text(GTK_ENTRY(cd->progress), fd->path);
+				gq_gtk_entry_set_text(GTK_ENTRY(cd->progress), fd->path);
 				cd->count_done = cd->count_done + 1;
 				gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(cd->progress_bar), static_cast<gdouble>(cd->count_done) / cd->count_total);
 				}
@@ -780,7 +781,7 @@ static gboolean cache_manager_render_file(CacheOpsData *cd)
 
 	if (!cd->remote)
 		{
-		gtk_entry_set_text(GTK_ENTRY(cd->progress), _("done"));
+		gq_gtk_entry_set_text(GTK_ENTRY(cd->progress), _("done"));
 		}
 	cache_manager_render_finish(cd);
 
@@ -792,7 +793,7 @@ static gboolean cache_manager_render_file(CacheOpsData *cd)
 	return FALSE;
 }
 
-static void cache_manager_render_start_cb(GenericDialog *UNUSED(fd), gpointer data)
+static void cache_manager_render_start_cb(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 	gchar *path;
@@ -803,7 +804,7 @@ static void cache_manager_render_start_cb(GenericDialog *UNUSED(fd), gpointer da
 		if (cd->list || !gtk_widget_get_sensitive(cd->button_start)) return;
 		}
 
-	path = remove_trailing_slash((gtk_entry_get_text(GTK_ENTRY(cd->entry))));
+	path = remove_trailing_slash((gq_gtk_entry_get_text(GTK_ENTRY(cd->entry))));
 	parse_out_relatives(path);
 
 	if (!isdir(path))
@@ -812,7 +813,7 @@ static void cache_manager_render_start_cb(GenericDialog *UNUSED(fd), gpointer da
 			{
 			warning_dialog(_("Invalid folder"),
 			_("The specified folder can not be found."),
-			GTK_STOCK_DIALOG_WARNING, cd->gd->dialog);
+			GQ_ICON_DIALOG_WARNING, cd->gd->dialog);
 			}
 		else
 			{
@@ -829,7 +830,7 @@ static void cache_manager_render_start_cb(GenericDialog *UNUSED(fd), gpointer da
 			gtk_widget_set_sensitive(cd->button_stop, TRUE);
 			gtk_widget_set_sensitive(cd->button_close, FALSE);
 
-			spinner_set_interval(cd->spinner, SPINNER_SPEED);
+			gtk_spinner_start(GTK_SPINNER(cd->spinner));
 			}
 		dir_fd = file_data_new_dir(path);
 		cache_manager_render_folder(cd, dir_fd);
@@ -885,11 +886,11 @@ static void cache_manager_render_dialog(GtkWidget *widget, const gchar *path)
 				    nullptr, cd);
 	gtk_window_set_default_size(GTK_WINDOW(cd->gd->dialog), PURGE_DIALOG_WIDTH, -1);
 	cd->gd->cancel_cb = cache_manager_render_close_cb;
-	cd->button_close = generic_dialog_add_button(cd->gd, GTK_STOCK_CLOSE, nullptr,
+	cd->button_close = generic_dialog_add_button(cd->gd, GQ_ICON_CLOSE, _("Close"),
 						     cache_manager_render_close_cb, FALSE);
-	cd->button_start = generic_dialog_add_button(cd->gd, GTK_STOCK_OK, _("S_tart"),
+	cd->button_start = generic_dialog_add_button(cd->gd, GQ_ICON_OK, _("S_tart"),
 						     cache_manager_render_start_cb, FALSE);
-	cd->button_stop = generic_dialog_add_button(cd->gd, GTK_STOCK_STOP, nullptr,
+	cd->button_stop = generic_dialog_add_button(cd->gd, GQ_ICON_STOP, _("Stop"),
 						    cache_manager_render_stop_cb, FALSE);
 	gtk_widget_set_sensitive(cd->button_stop, FALSE);
 
@@ -904,7 +905,7 @@ static void cache_manager_render_dialog(GtkWidget *widget, const gchar *path)
 
 	label = tab_completion_new(&cd->entry, path, nullptr, nullptr, nullptr, nullptr);
 	tab_completion_add_select_button(cd->entry,_("Select folder") , TRUE);
-	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 	gtk_widget_show(label);
 
 	pref_checkbox_new_int(cd->group, _("Include subfolders"), FALSE, &cd->recurse);
@@ -917,16 +918,16 @@ static void cache_manager_render_dialog(GtkWidget *widget, const gchar *path)
 	cd->progress = gtk_entry_new();
 	gtk_widget_set_can_focus(cd->progress, FALSE);
 	gtk_editable_set_editable(GTK_EDITABLE(cd->progress), FALSE);
-	gtk_entry_set_text(GTK_ENTRY(cd->progress), _("click start to begin"));
-	gtk_box_pack_start(GTK_BOX(hbox), cd->progress, TRUE, TRUE, 0);
+	gq_gtk_entry_set_text(GTK_ENTRY(cd->progress), _("click start to begin"));
+	gq_gtk_box_pack_start(GTK_BOX(hbox), cd->progress, TRUE, TRUE, 0);
 	gtk_widget_show(cd->progress);
 
 	cd->progress_bar = gtk_progress_bar_new();
-	gtk_box_pack_start(GTK_BOX(cd->gd->vbox), cd->progress_bar, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(cd->gd->vbox), cd->progress_bar, TRUE, TRUE, 0);
 	gtk_widget_show(cd->progress_bar);
 
-	cd->spinner = spinner_new(nullptr, -1);
-	gtk_box_pack_start(GTK_BOX(hbox), cd->spinner, FALSE, FALSE, 0);
+	cd->spinner = gtk_spinner_new();
+	gq_gtk_box_pack_start(GTK_BOX(hbox), cd->spinner, FALSE, FALSE, 0);
 	gtk_widget_show(cd->spinner);
 
 	cd->list = nullptr;
@@ -956,7 +957,7 @@ void cache_manager_render_remote(const gchar *path, gboolean recurse, gboolean l
 	cache_manager_render_start_render_remote(cd, path);
 }
 
-static void cache_manager_standard_clean_close_cb(GenericDialog *UNUSED(gd), gpointer data)
+static void cache_manager_standard_clean_close_cb(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 
@@ -992,7 +993,7 @@ static void cache_manager_standard_clean_done(CacheOpsData *cd)
 	cd->list = nullptr;
 }
 
-static void cache_manager_standard_clean_stop_cb(GenericDialog *UNUSED(gd), gpointer data)
+static void cache_manager_standard_clean_stop_cb(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 
@@ -1074,7 +1075,7 @@ static void cache_manager_standard_clean_valid_cb(const gchar *path, gboolean va
 		}
 }
 
-static void cache_manager_standard_clean_start(GenericDialog *UNUSED(gd), gpointer data)
+static void cache_manager_standard_clean_start(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 	GList *list;
@@ -1135,7 +1136,7 @@ static void cache_manager_standard_clean_start_cb(GenericDialog *gd, gpointer da
 static void cache_manager_standard_process(GtkWidget *widget, gboolean clear)
 {
 	CacheOpsData *cd;
-	const gchar *stock_id;
+	const gchar *icon_name;
 	const gchar *msg;
 
 	cd = g_new0(CacheOpsData, 1);
@@ -1144,12 +1145,12 @@ static void cache_manager_standard_process(GtkWidget *widget, gboolean clear)
 
 	if (clear)
 		{
-		stock_id = GTK_STOCK_DELETE;
+		icon_name = GQ_ICON_DELETE;
 		msg = _("Clearing thumbnails...");
 		}
 	else
 		{
-		stock_id = GTK_STOCK_CLEAR;
+		icon_name = GQ_ICON_CLEAR;
 		msg = _("Removing old thumbnails...");
 		}
 
@@ -1158,20 +1159,20 @@ static void cache_manager_standard_process(GtkWidget *widget, gboolean clear)
 				    widget, FALSE,
 				    nullptr, cd);
 	cd->gd->cancel_cb = cache_manager_standard_clean_close_cb;
-	cd->button_close = generic_dialog_add_button(cd->gd, GTK_STOCK_CLOSE, nullptr,
+	cd->button_close = generic_dialog_add_button(cd->gd, GQ_ICON_CLOSE, _("Close"),
 						     cache_manager_standard_clean_close_cb, FALSE);
-	cd->button_start = generic_dialog_add_button(cd->gd, GTK_STOCK_OK, _("S_tart"),
+	cd->button_start = generic_dialog_add_button(cd->gd, GQ_ICON_OK, _("S_tart"),
 						     cache_manager_standard_clean_start_cb, FALSE);
-	cd->button_stop = generic_dialog_add_button(cd->gd, GTK_STOCK_STOP, nullptr,
+	cd->button_stop = generic_dialog_add_button(cd->gd, GQ_ICON_STOP, _("Stop"),
 						    cache_manager_standard_clean_stop_cb, FALSE);
 	gtk_widget_set_sensitive(cd->button_stop, FALSE);
 
-	generic_dialog_add_message(cd->gd, stock_id, msg, nullptr, FALSE);
+	generic_dialog_add_message(cd->gd, icon_name, msg, NULL, FALSE);
 
 	cd->progress = gtk_progress_bar_new();
 	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(cd->progress), _("click start to begin"));
 	gtk_progress_bar_set_show_text(GTK_PROGRESS_BAR(cd->progress), TRUE);
-	gtk_box_pack_start(GTK_BOX(cd->gd->vbox), cd->progress, FALSE, FALSE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(cd->gd->vbox), cd->progress, FALSE, FALSE, 0);
 	gtk_widget_show(cd->progress);
 
 	cd->days = 30;
@@ -1195,29 +1196,29 @@ void cache_manager_standard_process_remote(gboolean clear)
 	cache_manager_standard_clean_start(nullptr, cd);
 }
 
-static void cache_manager_standard_clean_cb(GtkWidget *widget, gpointer UNUSED(data))
+static void cache_manager_standard_clean_cb(GtkWidget *widget, gpointer)
 {
 	cache_manager_standard_process(widget, FALSE);
 }
 
-static void cache_manager_standard_clear_cb(GtkWidget *widget, gpointer UNUSED(data))
+static void cache_manager_standard_clear_cb(GtkWidget *widget, gpointer)
 {
 	cache_manager_standard_process(widget, TRUE);
 }
 
 
-static void cache_manager_main_clean_cb(GtkWidget *widget, gpointer UNUSED(data))
+static void cache_manager_main_clean_cb(GtkWidget *widget, gpointer)
 {
 	cache_maintain_home(FALSE, FALSE, widget);
 }
 
 
-static void dummy_cancel_cb(GenericDialog *UNUSED(gd), gpointer UNUSED(data))
+static void dummy_cancel_cb(GenericDialog *, gpointer)
 {
 	/* no op, only so cancel button appears */
 }
 
-static void cache_manager_main_clear_ok_cb(GenericDialog *UNUSED(gd), gpointer UNUSED(data))
+static void cache_manager_main_clear_ok_cb(GenericDialog *, gpointer)
 {
 	cache_maintain_home(FALSE, TRUE, nullptr);
 }
@@ -1229,19 +1230,19 @@ void cache_manager_main_clear_confirm(GtkWidget *parent)
 	gd = generic_dialog_new(_("Clear cache"),
 				"clear_cache", parent, TRUE,
 				dummy_cancel_cb, nullptr);
-	generic_dialog_add_message(gd, GTK_STOCK_DIALOG_QUESTION, _("Clear cache"),
+	generic_dialog_add_message(gd, GQ_ICON_DIALOG_QUESTION, _("Clear cache"),
 				   _("This will remove all thumbnails and sim. files\nthat have been saved to disk, continue?"), TRUE);
-	generic_dialog_add_button(gd, GTK_STOCK_OK, nullptr, cache_manager_main_clear_ok_cb, TRUE);
+	generic_dialog_add_button(gd, GQ_ICON_OK, "OK", cache_manager_main_clear_ok_cb, TRUE);
 
 	gtk_widget_show(gd->dialog);
 }
 
-static void cache_manager_main_clear_cb(GtkWidget *widget, gpointer UNUSED(data))
+static void cache_manager_main_clear_cb(GtkWidget *widget, gpointer)
 {
 	cache_manager_main_clear_confirm(widget);
 }
 
-static void cache_manager_render_cb(GtkWidget *widget, gpointer UNUSED(data))
+static void cache_manager_render_cb(GtkWidget *widget, gpointer)
 {
 	const gchar *path = layout_get_path(nullptr);
 
@@ -1249,7 +1250,7 @@ static void cache_manager_render_cb(GtkWidget *widget, gpointer UNUSED(data))
 	cache_manager_render_dialog(widget, path);
 }
 
-static void cache_manager_metadata_clean_cb(GtkWidget *widget, gpointer UNUSED(data))
+static void cache_manager_metadata_clean_cb(GtkWidget *widget, gpointer)
 {
 	cache_maintain_home(TRUE, FALSE, widget);
 }
@@ -1257,7 +1258,7 @@ static void cache_manager_metadata_clean_cb(GtkWidget *widget, gpointer UNUSED(d
 
 static CacheManager *cache_manager = nullptr;
 
-static void cache_manager_close_cb(GenericDialog *gd, gpointer UNUSED(data))
+static void cache_manager_close_cb(GenericDialog *gd, gpointer)
 {
 	generic_dialog_close(gd);
 
@@ -1265,7 +1266,7 @@ static void cache_manager_close_cb(GenericDialog *gd, gpointer UNUSED(data))
 	cache_manager = nullptr;
 }
 
-static void cache_manager_help_cb(GenericDialog *UNUSED(gd), gpointer UNUSED(data))
+static void cache_manager_help_cb(GenericDialog *, gpointer)
 {
 	help_window_show("GuideReferenceManagement.html");
 }
@@ -1298,7 +1299,7 @@ static void cache_manager_sim_reset(CacheOpsData *cd)
 	cd->cl = nullptr;
 }
 
-static void cache_manager_sim_close_cb(GenericDialog *UNUSED(fd), gpointer data)
+static void cache_manager_sim_close_cb(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 
@@ -1314,7 +1315,7 @@ static void cache_manager_sim_finish(CacheOpsData *cd)
 	cache_manager_sim_reset(cd);
 	if (!cd->remote)
 		{
-		spinner_set_interval(cd->spinner, -1);
+		gtk_spinner_stop(GTK_SPINNER(cd->spinner));
 
 		gtk_widget_set_sensitive(cd->group, TRUE);
 		gtk_widget_set_sensitive(cd->button_start, TRUE);
@@ -1323,11 +1324,11 @@ static void cache_manager_sim_finish(CacheOpsData *cd)
 		}
 }
 
-static void cache_manager_sim_stop_cb(GenericDialog *UNUSED(fd), gpointer data)
+static void cache_manager_sim_stop_cb(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 
-	gtk_entry_set_text(GTK_ENTRY(cd->progress), _("stopped"));
+	gq_gtk_entry_set_text(GTK_ENTRY(cd->progress), _("stopped"));
 	cache_manager_sim_finish(cd);
 }
 
@@ -1352,7 +1353,7 @@ static void cache_manager_sim_folder(CacheOpsData *cd, FileData *dir_fd)
 	cd->list_dir = g_list_concat(list_d, cd->list_dir);
 }
 
-static void cache_manager_sim_file_done_cb(CacheLoader *UNUSED(cl), gint UNUSED(error), gpointer data)
+static void cache_manager_sim_file_done_cb(CacheLoader *, gint, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 
@@ -1421,7 +1422,7 @@ static gboolean cache_manager_sim_file(CacheOpsData *cd)
 
 		if (!cd->remote)
 			{
-			gtk_entry_set_text(GTK_ENTRY(cd->progress), fd->path);
+			gq_gtk_entry_set_text(GTK_ENTRY(cd->progress), fd->path);
 			}
 
 		file_data_unref(fd);
@@ -1448,7 +1449,7 @@ static gboolean cache_manager_sim_file(CacheOpsData *cd)
 
 		if (!cd->remote)
 			{
-			gtk_entry_set_text(GTK_ENTRY(cd->progress), _("done"));
+			gq_gtk_entry_set_text(GTK_ENTRY(cd->progress), _("done"));
 			}
 
 	cache_manager_sim_finish(cd);
@@ -1461,7 +1462,7 @@ static gboolean cache_manager_sim_file(CacheOpsData *cd)
 	return FALSE;
 }
 
-static void cache_manager_sim_start_cb(GenericDialog *UNUSED(fd), gpointer data)
+static void cache_manager_sim_start_cb(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 	gchar *path;
@@ -1472,7 +1473,7 @@ static void cache_manager_sim_start_cb(GenericDialog *UNUSED(fd), gpointer data)
 		if (cd->list || !gtk_widget_get_sensitive(cd->button_start)) return;
 		}
 
-	path = remove_trailing_slash((gtk_entry_get_text(GTK_ENTRY(cd->entry))));
+	path = remove_trailing_slash((gq_gtk_entry_get_text(GTK_ENTRY(cd->entry))));
 	parse_out_relatives(path);
 
 	if (!isdir(path))
@@ -1481,7 +1482,7 @@ static void cache_manager_sim_start_cb(GenericDialog *UNUSED(fd), gpointer data)
 			{
 			warning_dialog(_("Invalid folder"),
 			_("The specified folder can not be found."),
-			GTK_STOCK_DIALOG_WARNING, cd->gd->dialog);
+			GQ_ICON_DIALOG_WARNING, cd->gd->dialog);
 			}
 		else
 			{
@@ -1498,7 +1499,7 @@ static void cache_manager_sim_start_cb(GenericDialog *UNUSED(fd), gpointer data)
 			gtk_widget_set_sensitive(cd->button_stop, TRUE);
 			gtk_widget_set_sensitive(cd->button_close, FALSE);
 
-			spinner_set_interval(cd->spinner, SPINNER_SPEED);
+			gtk_spinner_start(GTK_SPINNER(cd->spinner));
 			}
 		dir_fd = file_data_new_dir(path);
 		cache_manager_sim_folder(cd, dir_fd);
@@ -1527,11 +1528,11 @@ static void cache_manager_sim_load_dialog(GtkWidget *widget, const gchar *path)
 	cd->gd = generic_dialog_new(_("Create sim. files"), "create_sim_files", widget, FALSE, nullptr, cd);
 	gtk_window_set_default_size(GTK_WINDOW(cd->gd->dialog), PURGE_DIALOG_WIDTH, -1);
 	cd->gd->cancel_cb = cache_manager_sim_close_cb;
-	cd->button_close = generic_dialog_add_button(cd->gd, GTK_STOCK_CLOSE, nullptr,
+	cd->button_close = generic_dialog_add_button(cd->gd, GQ_ICON_CLOSE, _("Close"),
 						     cache_manager_sim_close_cb, FALSE);
-	cd->button_start = generic_dialog_add_button(cd->gd, GTK_STOCK_OK, _("S_tart"),
+	cd->button_start = generic_dialog_add_button(cd->gd, GQ_ICON_OK, _("S_tart"),
 						     cache_manager_sim_start_cb, FALSE);
-	cd->button_stop = generic_dialog_add_button(cd->gd, GTK_STOCK_STOP, nullptr,
+	cd->button_stop = generic_dialog_add_button(cd->gd, GQ_ICON_STOP, _("Stop"),
 						    cache_manager_sim_stop_cb, FALSE);
 	gtk_widget_set_sensitive(cd->button_stop, FALSE);
 
@@ -1546,7 +1547,7 @@ static void cache_manager_sim_load_dialog(GtkWidget *widget, const gchar *path)
 
 	label = tab_completion_new(&cd->entry, path, nullptr, nullptr, nullptr, nullptr);
 	tab_completion_add_select_button(cd->entry,_("Select folder") , TRUE);
-	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 	gtk_widget_show(label);
 
 	pref_line(cd->gd->vbox, PREF_PAD_SPACE);
@@ -1555,16 +1556,16 @@ static void cache_manager_sim_load_dialog(GtkWidget *widget, const gchar *path)
 	cd->progress = gtk_entry_new();
 	gtk_widget_set_can_focus(cd->progress, FALSE);
 	gtk_editable_set_editable(GTK_EDITABLE(cd->progress), FALSE);
-	gtk_entry_set_text(GTK_ENTRY(cd->progress), _("click start to begin"));
-	gtk_box_pack_start(GTK_BOX(hbox), cd->progress, TRUE, TRUE, 0);
+	gq_gtk_entry_set_text(GTK_ENTRY(cd->progress), _("click start to begin"));
+	gq_gtk_box_pack_start(GTK_BOX(hbox), cd->progress, TRUE, TRUE, 0);
 	gtk_widget_show(cd->progress);
 
 	cd->progress_bar = gtk_progress_bar_new();
-	gtk_box_pack_start(GTK_BOX(cd->gd->vbox), cd->progress_bar, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(cd->gd->vbox), cd->progress_bar, TRUE, TRUE, 0);
 	gtk_widget_show(cd->progress_bar);
 
-	cd->spinner = spinner_new(nullptr, -1);
-	gtk_box_pack_start(GTK_BOX(hbox), cd->spinner, FALSE, FALSE, 0);
+	cd->spinner = gtk_spinner_new();
+	gq_gtk_box_pack_start(GTK_BOX(hbox), cd->spinner, FALSE, FALSE, 0);
 	gtk_widget_show(cd->spinner);
 
 	cd->list = nullptr;
@@ -1572,7 +1573,7 @@ static void cache_manager_sim_load_dialog(GtkWidget *widget, const gchar *path)
 	gtk_widget_show(cd->gd->dialog);
 }
 
-static void cache_manager_sim_load_cb(GtkWidget *widget, gpointer UNUSED(data))
+static void cache_manager_sim_load_cb(GtkWidget *widget, gpointer)
 {
 	const gchar *path = layout_get_path(nullptr);
 
@@ -1580,7 +1581,7 @@ static void cache_manager_sim_load_cb(GtkWidget *widget, gpointer UNUSED(data))
 	cache_manager_sim_load_dialog(widget, path);
 }
 
-static void cache_manager_cache_maintenance_close_cb(GenericDialog *UNUSED(fd), gpointer data)
+static void cache_manager_cache_maintenance_close_cb(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 
@@ -1591,7 +1592,7 @@ static void cache_manager_cache_maintenance_close_cb(GenericDialog *UNUSED(fd),
 	g_free(cd);
 }
 
-static void cache_manager_cache_maintenance_start_cb(GenericDialog *UNUSED(fd), gpointer data)
+static void cache_manager_cache_maintenance_start_cb(GenericDialog *, gpointer data)
 {
 	auto cd = static_cast<CacheOpsData *>(data);
 	gchar *path;
@@ -1602,7 +1603,7 @@ static void cache_manager_cache_maintenance_start_cb(GenericDialog *UNUSED(fd),
 		if (cd->list || !gtk_widget_get_sensitive(cd->button_start)) return;
 		}
 
-	path = remove_trailing_slash((gtk_entry_get_text(GTK_ENTRY(cd->entry))));
+	path = remove_trailing_slash((gq_gtk_entry_get_text(GTK_ENTRY(cd->entry))));
 	parse_out_relatives(path);
 
 	if (!isdir(path))
@@ -1611,7 +1612,7 @@ static void cache_manager_cache_maintenance_start_cb(GenericDialog *UNUSED(fd),
 			{
 			warning_dialog(_("Invalid folder"),
 			_("The specified folder can not be found."),
-			GTK_STOCK_DIALOG_WARNING, cd->gd->dialog);
+			GQ_ICON_DIALOG_WARNING, cd->gd->dialog);
 			}
 		else
 			{
@@ -1646,9 +1647,9 @@ static void cache_manager_cache_maintenance_load_dialog(GtkWidget *widget, const
 	cd->gd = generic_dialog_new(_("Background cache maintenance"), "background_cache_maintenance", widget, FALSE, nullptr, cd);
 	gtk_window_set_default_size(GTK_WINDOW(cd->gd->dialog), PURGE_DIALOG_WIDTH, -1);
 	cd->gd->cancel_cb = cache_manager_cache_maintenance_close_cb;
-	cd->button_close = generic_dialog_add_button(cd->gd, GTK_STOCK_CLOSE, nullptr,
+	cd->button_close = generic_dialog_add_button(cd->gd, GQ_ICON_CLOSE, _("Close"),
 						     cache_manager_cache_maintenance_close_cb, FALSE);
-	cd->button_start = generic_dialog_add_button(cd->gd, GTK_STOCK_OK, _("S_tart"),
+	cd->button_start = generic_dialog_add_button(cd->gd, GQ_ICON_OK, _("S_tart"),
 						     cache_manager_cache_maintenance_start_cb, FALSE);
 
 	generic_dialog_add_message(cd->gd, nullptr, _("Recursively delete orphaned thumbnails\nand .sim files, and create new\nthumbnails and .sim files"), nullptr, FALSE);
@@ -1662,7 +1663,7 @@ static void cache_manager_cache_maintenance_load_dialog(GtkWidget *widget, const
 
 	label = tab_completion_new(&cd->entry, path, nullptr, nullptr, nullptr, nullptr);
 	tab_completion_add_select_button(cd->entry,_("Select folder") , TRUE);
-	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 	gtk_widget_show(label);
 
 	cd->list = nullptr;
@@ -1670,7 +1671,7 @@ static void cache_manager_cache_maintenance_load_dialog(GtkWidget *widget, const
 	gtk_widget_show(cd->gd->dialog);
 }
 
-static void cache_manager_cache_maintenance_load_cb(GtkWidget *widget, gpointer UNUSED(data))
+static void cache_manager_cache_maintenance_load_cb(GtkWidget *widget, gpointer)
 {
 	const gchar *path = layout_get_path(nullptr);
 
@@ -1702,9 +1703,9 @@ void cache_manager_show()
 	gd = cache_manager->dialog;
 
 	gd->cancel_cb = cache_manager_close_cb;
-	generic_dialog_add_button(gd, GTK_STOCK_CLOSE, nullptr,
+	generic_dialog_add_button(gd, GQ_ICON_CLOSE, _("Close"),
 				  cache_manager_close_cb, FALSE);
-	generic_dialog_add_button(gd, GTK_STOCK_HELP, nullptr,
+	generic_dialog_add_button(gd, GQ_ICON_HELP, _("Help"),
 				  cache_manager_help_cb, FALSE);
 
 	generic_dialog_add_message(gd, nullptr, _("Cache and Data Maintenance"), nullptr, FALSE);
@@ -1717,15 +1718,15 @@ void cache_manager_show()
 
 	table = pref_table_new(group, 2, 2, FALSE, FALSE);
 
-	button = pref_table_button(table, 0, 0, GTK_STOCK_CLEAR, _("Clean up"), FALSE,
+	button = pref_table_button(table, 0, 0, GQ_ICON_CLEAR, _("Clean up"),
 				   G_CALLBACK(cache_manager_main_clean_cb), cache_manager);
 	gtk_size_group_add_widget(sizegroup, button);
-	pref_table_label(table, 1, 0, _("Remove orphaned or outdated thumbnails and sim. files."), 0.0);
+	pref_table_label(table, 1, 0, _("Remove orphaned or outdated thumbnails and sim. files."), GTK_ALIGN_START);
 
-	button = pref_table_button(table, 0, 1, GTK_STOCK_DELETE, _("Clear cache"), FALSE,
+	button = pref_table_button(table, 0, 1, GQ_ICON_DELETE, _("Clear cache"),
 				   G_CALLBACK(cache_manager_main_clear_cb), cache_manager);
 	gtk_size_group_add_widget(sizegroup, button);
-	pref_table_label(table, 1, 1, _("Delete all cached data."), 0.0);
+	pref_table_label(table, 1, 1, _("Delete all cached data."), GTK_ALIGN_START);
 
 
 	group = pref_group_new(gd->vbox, FALSE, _("Shared thumbnail cache"), GTK_ORIENTATION_VERTICAL);
@@ -1736,34 +1737,34 @@ void cache_manager_show()
 
 	table = pref_table_new(group, 2, 2, FALSE, FALSE);
 
-	button = pref_table_button(table, 0, 0, GTK_STOCK_CLEAR, _("Clean up"), FALSE,
+	button = pref_table_button(table, 0, 0, GQ_ICON_CLEAR, _("Clean up"),
 				   G_CALLBACK(cache_manager_standard_clean_cb), cache_manager);
 	gtk_size_group_add_widget(sizegroup, button);
-	pref_table_label(table, 1, 0, _("Remove orphaned or outdated thumbnails."), 0.0);
+	pref_table_label(table, 1, 0, _("Remove orphaned or outdated thumbnails."), GTK_ALIGN_START);
 
-	button = pref_table_button(table, 0, 1, GTK_STOCK_DELETE, _("Clear cache"), FALSE,
+	button = pref_table_button(table, 0, 1, GQ_ICON_DELETE, _("Clear cache"),
 				   G_CALLBACK(cache_manager_standard_clear_cb), cache_manager);
 	gtk_size_group_add_widget(sizegroup, button);
-	pref_table_label(table, 1, 1, _("Delete all cached thumbnails."), 0.0);
+	pref_table_label(table, 1, 1, _("Delete all cached thumbnails."), GTK_ALIGN_START);
 
 	group = pref_group_new(gd->vbox, FALSE, _("Create thumbnails"), GTK_ORIENTATION_VERTICAL);
 
 	table = pref_table_new(group, 2, 1, FALSE, FALSE);
 
-	button = pref_table_button(table, 0, 1, "system-run", _("Render"), FALSE,
+	button = pref_table_button(table, 0, 1, GQ_ICON_RUN, _("Render"),
 				   G_CALLBACK(cache_manager_render_cb), cache_manager);
 	gtk_size_group_add_widget(sizegroup, button);
-	pref_table_label(table, 1, 1, _("Render thumbnails for a specific folder."), 0.0);
+	pref_table_label(table, 1, 1, _("Render thumbnails for a specific folder."), GTK_ALIGN_START);
 	gtk_widget_set_sensitive(group, options->thumbnails.enable_caching);
 
 	group = pref_group_new(gd->vbox, FALSE, _("File similarity cache"), GTK_ORIENTATION_VERTICAL);
 
 	table = pref_table_new(group, 3, 2, FALSE, FALSE);
 
-	button = pref_table_button(table, 0, 0, GTK_STOCK_EXECUTE, _("Create"), FALSE,
+	button = pref_table_button(table, 0, 0, GQ_ICON_RUN, _("Create"),
 				   G_CALLBACK(cache_manager_sim_load_cb), cache_manager);
 	gtk_size_group_add_widget(sizegroup, button);
-	pref_table_label(table, 1, 0, _("Create sim. files recursively."), 0.0);
+	pref_table_label(table, 1, 0, _("Create sim. files recursively."), GTK_ALIGN_START);
 	gtk_widget_set_sensitive(group, options->thumbnails.enable_caching);
 
 	group = pref_group_new(gd->vbox, FALSE, _("Metadata"), GTK_ORIENTATION_VERTICAL);
@@ -1772,19 +1773,19 @@ void cache_manager_show()
 
 	table = pref_table_new(group, 2, 1, FALSE, FALSE);
 
-	button = pref_table_button(table, 0, 0, GTK_STOCK_CLEAR, _("Clean up"), FALSE,
+	button = pref_table_button(table, 0, 0, GQ_ICON_CLEAR, _("Clean up"),
 				   G_CALLBACK(cache_manager_metadata_clean_cb), cache_manager);
 	gtk_size_group_add_widget(sizegroup, button);
-	pref_table_label(table, 1, 0, _("Remove orphaned keywords and comments."), 0.0);
+	pref_table_label(table, 1, 0, _("Remove orphaned keywords and comments."), GTK_ALIGN_START);
 
 	group = pref_group_new(gd->vbox, FALSE, _("Background cache maintenance"), GTK_ORIENTATION_VERTICAL);
 
 	table = pref_table_new(group, 3, 2, FALSE, FALSE);
 
-	button = pref_table_button(table, 0, 0, GTK_STOCK_EXECUTE, _("Select"), FALSE,
+	button = pref_table_button(table, 0, 0, GQ_ICON_RUN, _("Select"),
 				   G_CALLBACK(cache_manager_cache_maintenance_load_cb), cache_manager);
 	gtk_size_group_add_widget(sizegroup, button);
-	pref_table_label(table, 1, 0, _("Run cache maintenance as a background job."), 0.0);
+	pref_table_label(table, 1, 0, _("Run cache maintenance as a background job."), GTK_ALIGN_START);
 	gtk_widget_set_sensitive(group, options->thumbnails.enable_caching);
 
 	gtk_widget_show(cache_manager->dialog->dialog);
