@@ -24,12 +24,53 @@
 
 #include "collect.h"
 
+struct CollectTable
+{
+	GtkWidget *scrolled;
+	GtkWidget *listview;
+	gint columns;
+	gint rows;
+
+	CollectionData *cd;
+
+	GList *selection;
+	CollectInfo *prev_selection;
+
+	CollectInfo *click_info;
+
+	GtkWidget *tip_window;
+	guint tip_delay_id; /**< event source id */
+	CollectInfo *tip_info;
+
+	GdkWindow *marker_window;
+	CollectInfo *marker_info;
+
+	GtkWidget *status_label;
+	GtkWidget *extra_label;
+
+	gint focus_row;
+	gint focus_column;
+	CollectInfo *focus_info;
+
+	GtkWidget *popup;
+	CollectInfo *drop_info;
+	GList *drop_list;
+
+	guint sync_idle_id; /**< event source id */
+	guint drop_idle_id; /**< event source id */
+
+	gboolean show_text;
+	gboolean show_stars;
+
+	GList *editmenu_fd_list; /**< file list for edit menu */
+};
+
 void collection_table_select_all(CollectTable *ct);
 void collection_table_unselect_all(CollectTable *ct);
 
 void collection_table_add_filelist(CollectTable *ct, GList *list);
 
-void collection_table_file_update(CollectTable *ct, CollectInfo *ci);
+void collection_table_file_update(CollectTable *ct, CollectInfo *info);
 void collection_table_file_add(CollectTable *ct, CollectInfo *ci);
 void collection_table_file_insert(CollectTable *ct, CollectInfo *ci);
 void collection_table_file_remove(CollectTable *ct, CollectInfo *ci);
