@@ -23,12 +23,13 @@
 #include "desktop-file.h"
 
 #include "editors.h"
-#include "ui-misc.h"
-#include "ui-fileops.h"
-#include "pixbuf-util.h"
-#include "window.h"
-#include "utilops.h"
 #include "layout-util.h"
+#include "misc.h"
+#include "pixbuf-util.h"
+#include "ui-fileops.h"
+#include "ui-misc.h"
+#include "utilops.h"
+#include "window.h"
 
 #define CONFIG_WINDOW_DEF_WIDTH		700
 #define CONFIG_WINDOW_DEF_HEIGHT	400
@@ -70,11 +71,11 @@ static gboolean editor_window_save(EditorWindow *ew)
 	GtkTextIter start, end;
 	GError *error = nullptr;
 	gboolean ret = TRUE;
-	const gchar *name = gtk_entry_get_text(GTK_ENTRY(ew->entry));
+	const gchar *name = gq_gtk_entry_get_text(GTK_ENTRY(ew->entry));
 
 	if (!name || !name[0])
 		{
-		file_util_warning_dialog(_("Can't save"), _("Please specify file name."), GTK_STOCK_DIALOG_ERROR, nullptr);
+		file_util_warning_dialog(_("Can't save"), _("Please specify file name."), GQ_ICON_DIALOG_ERROR, nullptr);
 		return FALSE;
 		}
 
@@ -86,13 +87,13 @@ static gboolean editor_window_save(EditorWindow *ew)
 
 	if (!recursive_mkdir_if_not_exists(dir, 0755))
 		{
-		file_util_warning_dialog(_("Can't save"), _("Could not create directory"), GTK_STOCK_DIALOG_ERROR, nullptr);
+		file_util_warning_dialog(_("Can't save"), _("Could not create directory"), GQ_ICON_DIALOG_ERROR, nullptr);
 		ret = FALSE;
 		}
 
 	if (ret && !g_file_set_contents(path, text, -1, &error))
 		{
-		file_util_warning_dialog(_("Can't save"), error->message, GTK_STOCK_DIALOG_ERROR, nullptr);
+		file_util_warning_dialog(_("Can't save"), error->message, GQ_ICON_DIALOG_ERROR, nullptr);
 		g_error_free(error);
 		ret = FALSE;
 		}
@@ -106,22 +107,22 @@ static gboolean editor_window_save(EditorWindow *ew)
 	return ret;
 }
 
-static void editor_window_close_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void editor_window_close_cb(GtkWidget *, gpointer data)
 {
 	auto ew = static_cast<EditorWindow *>(data);
 
 	g_free(ew->desktop_name);
-	gtk_widget_destroy(ew->window);
+	gq_gtk_widget_destroy(ew->window);
 	g_free(ew);
 }
 
-static gint editor_window_delete_cb(GtkWidget *w, GdkEventAny *UNUSED(event), gpointer data)
+static gint editor_window_delete_cb(GtkWidget *w, GdkEventAny *, gpointer data)
 {
 	editor_window_close_cb(w, data);
 	return TRUE;
 }
 
-static void editor_window_save_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void editor_window_save_cb(GtkWidget *, gpointer data)
 {
 	auto ew = static_cast<EditorWindow *>(data);
 
@@ -135,7 +136,7 @@ static void editor_window_save_cb(GtkWidget *UNUSED(widget), gpointer data)
 	ew->modified = FALSE;
 }
 
-static void editor_window_text_modified_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void editor_window_text_modified_cb(GtkWidget *, gpointer data)
 {
 	auto ew = static_cast<EditorWindow *>(data);
 
@@ -146,10 +147,10 @@ static void editor_window_text_modified_cb(GtkWidget *UNUSED(widget), gpointer d
 		}
 }
 
-static void editor_window_entry_changed_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void editor_window_entry_changed_cb(GtkWidget *, gpointer data)
 {
 	auto ew = static_cast<EditorWindow *>(data);
-	const gchar *content = gtk_entry_get_text(GTK_ENTRY(ew->entry));
+	const gchar *content = gq_gtk_entry_get_text(GTK_ENTRY(ew->entry));
 	gboolean modified = ew->modified;
 
 	if (!modified)
@@ -182,7 +183,7 @@ static void editor_window_new(const gchar *src_path, const gchar *desktop_name)
 	ew = g_new0(EditorWindow, 1);
 
 
-	ew->window = window_new(GTK_WINDOW_TOPLEVEL, "Desktop", PIXBUF_INLINE_ICON_CONFIG, nullptr, _("Desktop file"));
+	ew->window = window_new("Desktop", PIXBUF_INLINE_ICON_CONFIG, nullptr, _("Desktop file"));
 	DEBUG_NAME(ew->window);
 	gtk_window_set_type_hint(GTK_WINDOW(ew->window), GDK_WINDOW_TYPE_HINT_DIALOG);
 
@@ -194,41 +195,41 @@ static void editor_window_new(const gchar *src_path, const gchar *desktop_name)
 	gtk_container_set_border_width(GTK_CONTAINER(ew->window), PREF_PAD_BORDER);
 
 	win_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, PREF_PAD_SPACE);
-	gtk_container_add(GTK_CONTAINER(ew->window), win_vbox);
+	gq_gtk_container_add(GTK_WIDGET(ew->window), win_vbox);
 	gtk_widget_show(win_vbox);
 
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, PREF_PAD_SPACE);
-	gtk_box_pack_end(GTK_BOX(win_vbox), hbox, FALSE, FALSE, 0);
+	gq_gtk_box_pack_end(GTK_BOX(win_vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
 	ew->entry = gtk_entry_new();
-	gtk_box_pack_start(GTK_BOX(hbox), ew->entry, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(hbox), ew->entry, TRUE, TRUE, 0);
 	ew->desktop_name = nullptr;
 	if (desktop_name)
 		{
-		gtk_entry_set_text(GTK_ENTRY(ew->entry), desktop_name);
+		gq_gtk_entry_set_text(GTK_ENTRY(ew->entry), desktop_name);
 		ew->desktop_name = g_strdup(desktop_name);
 		}
 	gtk_widget_show(ew->entry);
 	g_signal_connect(G_OBJECT(ew->entry), "changed", G_CALLBACK(editor_window_entry_changed_cb), ew);
 
-	button_hbox = gtk_hbutton_box_new();
+	button_hbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(button_hbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing(GTK_BOX(button_hbox), PREF_PAD_BUTTON_GAP);
-	gtk_box_pack_end(GTK_BOX(hbox), button_hbox, FALSE, FALSE, 0);
+	gq_gtk_box_pack_end(GTK_BOX(hbox), button_hbox, FALSE, FALSE, 0);
 	gtk_widget_show(button_hbox);
 
-	ew->save_button = pref_button_new(nullptr, GTK_STOCK_SAVE, nullptr, FALSE,
+	ew->save_button = pref_button_new(nullptr, GQ_ICON_SAVE, _("Save"),
 				 G_CALLBACK(editor_window_save_cb), ew);
-	gtk_container_add(GTK_CONTAINER(button_hbox), ew->save_button);
+	gq_gtk_container_add(GTK_WIDGET(button_hbox), ew->save_button);
 	gtk_widget_set_can_default(ew->save_button, TRUE);
 	gtk_widget_set_sensitive(ew->save_button, FALSE);
 	gtk_widget_show(ew->save_button);
 	ct_button = ew->save_button;
 
-	button = pref_button_new(nullptr, GTK_STOCK_CLOSE, nullptr, FALSE,
+	button = pref_button_new(nullptr, GQ_ICON_CLOSE, _("Close"),
 				 G_CALLBACK(editor_window_close_cb), ew);
-	gtk_container_add(GTK_CONTAINER(button_hbox), button);
+	gq_gtk_container_add(GTK_WIDGET(button_hbox), button);
 	gtk_widget_set_can_default(button, TRUE);
 	gtk_widget_show(button);
 
@@ -238,15 +239,15 @@ static void editor_window_new(const gchar *src_path, const gchar *desktop_name)
 		}
 
 
-	scrolled = gtk_scrolled_window_new(nullptr, nullptr);
-	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled), GTK_SHADOW_IN);
+	scrolled = gq_gtk_scrolled_window_new(nullptr, nullptr);
+	gq_gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled), GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
 				       GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_box_pack_start(GTK_BOX(win_vbox), scrolled, TRUE, TRUE, 5);
+	gq_gtk_box_pack_start(GTK_BOX(win_vbox), scrolled, TRUE, TRUE, 5);
 	gtk_widget_show(scrolled);
 
 	text_view = gtk_text_view_new();
-	gtk_container_add(GTK_CONTAINER(scrolled), text_view);
+	gq_gtk_container_add(GTK_WIDGET(scrolled), text_view);
 	gtk_widget_show(text_view);
 
 	ew->buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_view));
@@ -262,14 +263,14 @@ static void editor_window_new(const gchar *src_path, const gchar *desktop_name)
 }
 
 
-static void editor_list_window_close_cb(GtkWidget *UNUSED(widget), gpointer UNUSED(data))
+static void editor_list_window_close_cb(GtkWidget *, gpointer)
 {
-	gtk_widget_destroy(editor_list_window->window);
+	gq_gtk_widget_destroy(editor_list_window->window);
 	g_free(editor_list_window);
 	editor_list_window = nullptr;
 }
 
-static gboolean editor_list_window_delete(GtkWidget *UNUSED(widget), GdkEventAny *UNUSED(event), gpointer UNUSED(data))
+static gboolean editor_list_window_delete(GtkWidget *, GdkEventAny *, gpointer)
 {
 	editor_list_window_close_cb(nullptr, nullptr);
 	return TRUE;
@@ -277,7 +278,7 @@ static gboolean editor_list_window_delete(GtkWidget *UNUSED(widget), GdkEventAny
 
 static void editor_list_window_delete_dlg_cancel(GenericDialog *gd, gpointer data);
 
-static void editor_list_window_delete_dlg_cancel(GenericDialog *UNUSED(gd), gpointer data)
+static void editor_list_window_delete_dlg_cancel(GenericDialog *, gpointer data)
 {
 	auto ewdl = static_cast<EditorWindowDel_Data *>(data);
 
@@ -293,7 +294,7 @@ static void editor_list_window_delete_dlg_ok_cb(GenericDialog *gd, gpointer data
 	if (!unlink_file(ewdl->path))
 		{
 		gchar *text = g_strdup_printf(_("Unable to delete file:\n%s"), ewdl->path);
-		warning_dialog(_("File deletion failed"), text, GTK_STOCK_DIALOG_WARNING, nullptr);
+		warning_dialog(_("File deletion failed"), text, GQ_ICON_DIALOG_WARNING, nullptr);
 		g_free(text);
 		}
 	else
@@ -307,7 +308,7 @@ static void editor_list_window_delete_dlg_ok_cb(GenericDialog *gd, gpointer data
 	editor_list_window_delete_dlg_cancel(gd, data);
 }
 
-static void editor_list_window_delete_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void editor_list_window_delete_cb(GtkWidget *, gpointer data)
 {
 	auto ewl = static_cast<EditorListWindow *>(data);
 	GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(ewl->view));
@@ -341,10 +342,10 @@ static void editor_list_window_delete_cb(GtkWidget *UNUSED(widget), gpointer dat
 					    nullptr, TRUE,
 					    editor_list_window_delete_dlg_cancel, ewdl);
 
-		generic_dialog_add_button(ewl->gd, GTK_STOCK_DELETE, nullptr, editor_list_window_delete_dlg_ok_cb, TRUE);
+		generic_dialog_add_button(ewl->gd, GQ_ICON_DELETE, "Delete", editor_list_window_delete_dlg_ok_cb, TRUE);
 
 		text = g_strdup_printf(_("About to delete the file:\n %s"), path);
-		generic_dialog_add_message(ewl->gd, GTK_STOCK_DIALOG_QUESTION,
+		generic_dialog_add_message(ewl->gd, GQ_ICON_DIALOG_QUESTION,
 					   _("Delete file"), text, TRUE);
 		g_free(text);
 
@@ -352,7 +353,7 @@ static void editor_list_window_delete_cb(GtkWidget *UNUSED(widget), gpointer dat
 		}
 }
 
-static void editor_list_window_edit_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void editor_list_window_edit_cb(GtkWidget *, gpointer data)
 {
 	auto ewl = static_cast<EditorListWindow *>(data);
 	GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(ewl->view));
@@ -373,17 +374,17 @@ static void editor_list_window_edit_cb(GtkWidget *UNUSED(widget), gpointer data)
 		}
 }
 
-static void editor_list_window_new_cb(GtkWidget *UNUSED(widget), gpointer UNUSED(data))
+static void editor_list_window_new_cb(GtkWidget *, gpointer)
 {
 	editor_window_new(desktop_file_template, _("new.desktop"));
 }
 
-static void editor_list_window_help_cb(GtkWidget *UNUSED(widget), gpointer UNUSED(data))
+static void editor_list_window_help_cb(GtkWidget *, gpointer)
 {
 	help_window_show("GuidePluginsConfig.html");
 }
 
-static void editor_list_window_selection_changed_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void editor_list_window_selection_changed_cb(GtkWidget *, gpointer data)
 {
 	auto ewl = static_cast<EditorListWindow *>(data);
 	GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(ewl->view));
@@ -464,7 +465,7 @@ static gint editor_list_window_sort_cb(GtkTreeModel *model, GtkTreeIter *a, GtkT
 	return ret;
 }
 
-static void plugin_disable_cb(GtkCellRendererToggle *UNUSED(renderer), gchar *path_str, gpointer data)
+static void plugin_disable_cb(GtkCellRendererToggle *, gchar *path_str, gpointer data)
 {
 	auto ewl = static_cast<EditorListWindow *>(data);
 	GtkTreePath *tpath;
@@ -508,8 +509,8 @@ static void plugin_disable_cb(GtkCellRendererToggle *UNUSED(renderer), gchar *pa
 	layout_editors_reload_finish();
 }
 
-static void plugin_disable_set_func(GtkTreeViewColumn *UNUSED(tree_column), GtkCellRenderer *cell,
-							GtkTreeModel *tree_model, GtkTreeIter *iter, gpointer UNUSED(data))
+static void plugin_disable_set_func(GtkTreeViewColumn *, GtkCellRenderer *cell,
+							GtkTreeModel *tree_model, GtkTreeIter *iter, gpointer)
 {
 	gboolean disabled;
 
@@ -540,7 +541,7 @@ static void editor_list_window_create()
 
 	editor_list_window = ewl = g_new0(EditorListWindow, 1);
 
-	ewl->window = window_new(GTK_WINDOW_TOPLEVEL, "editors", PIXBUF_INLINE_ICON_CONFIG, nullptr, _("Plugins"));
+	ewl->window = window_new("editors", PIXBUF_INLINE_ICON_CONFIG, nullptr, _("Plugins"));
 	DEBUG_NAME(ewl->window);
 	gtk_window_set_type_hint(GTK_WINDOW(ewl->window), GDK_WINDOW_TYPE_HINT_DIALOG);
 	g_signal_connect(G_OBJECT(ewl->window), "delete_event",
@@ -550,55 +551,54 @@ static void editor_list_window_create()
 	gtk_container_set_border_width(GTK_CONTAINER(ewl->window), PREF_PAD_BORDER);
 
 	win_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, PREF_PAD_SPACE);
-	gtk_container_add(GTK_CONTAINER(ewl->window), win_vbox);
+	gq_gtk_container_add(GTK_WIDGET(ewl->window), win_vbox);
 	gtk_widget_show(win_vbox);
 
-	hbox = gtk_hbutton_box_new();
+	hbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(hbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing(GTK_BOX(hbox), PREF_PAD_BUTTON_GAP);
-	gtk_box_pack_end(GTK_BOX(win_vbox), hbox, FALSE, FALSE, 0);
+	gq_gtk_box_pack_end(GTK_BOX(win_vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-
-	button = pref_button_new(nullptr, GTK_STOCK_HELP, nullptr, FALSE,
+	button = pref_button_new(nullptr, GQ_ICON_HELP, _("Help"),
 				 G_CALLBACK(editor_list_window_help_cb), ewl);
-	gtk_container_add(GTK_CONTAINER(hbox), button);
+	gq_gtk_container_add(GTK_WIDGET(hbox), button);
 	gtk_widget_set_can_default(button, TRUE);
 	gtk_widget_show(button);
 
-	button = pref_button_new(nullptr, GTK_STOCK_NEW, nullptr, FALSE,
+	button = pref_button_new(nullptr, GQ_ICON_NEW, _("New"),
 				 G_CALLBACK(editor_list_window_new_cb), ewl);
-	gtk_container_add(GTK_CONTAINER(hbox), button);
+	gq_gtk_container_add(GTK_WIDGET(hbox), button);
 	gtk_widget_set_can_default(button, TRUE);
 	gtk_widget_show(button);
 
-	button = pref_button_new(nullptr, GTK_STOCK_EDIT, nullptr, FALSE,
+	button = pref_button_new(nullptr, GQ_ICON_EDIT, _("Edit"),
 				 G_CALLBACK(editor_list_window_edit_cb), ewl);
-	gtk_container_add(GTK_CONTAINER(hbox), button);
+	gq_gtk_container_add(GTK_WIDGET(hbox), button);
 	gtk_widget_set_can_default(button, TRUE);
 	gtk_widget_set_sensitive(button, FALSE);
 	gtk_widget_show(button);
 	ewl->edit_button = button;
 
-	button = pref_button_new(nullptr, GTK_STOCK_DELETE, nullptr, FALSE,
+	button = pref_button_new(nullptr, GQ_ICON_DELETE, "Delete",
 				 G_CALLBACK(editor_list_window_delete_cb), ewl);
-	gtk_container_add(GTK_CONTAINER(hbox), button);
+	gq_gtk_container_add(GTK_WIDGET(hbox), button);
 	gtk_widget_set_can_default(button, TRUE);
 	gtk_widget_set_sensitive(button, FALSE);
 	gtk_widget_show(button);
 	ewl->delete_button = button;
 
-	button = pref_button_new(nullptr, GTK_STOCK_CLOSE, nullptr, FALSE,
+	button = pref_button_new(nullptr, GQ_ICON_CLOSE, _("Close"),
 				 G_CALLBACK(editor_list_window_close_cb), ewl);
-	gtk_container_add(GTK_CONTAINER(hbox), button);
+	gq_gtk_container_add(GTK_WIDGET(hbox), button);
 	gtk_widget_set_can_default(button, TRUE);
 	gtk_widget_show(button);
 
-	scrolled = gtk_scrolled_window_new(nullptr, nullptr);
-	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled), GTK_SHADOW_IN);
+	scrolled = gq_gtk_scrolled_window_new(nullptr, nullptr);
+	gq_gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled), GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
 				       GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_box_pack_start(GTK_BOX(win_vbox), scrolled, TRUE, TRUE, 5);
+	gq_gtk_box_pack_start(GTK_BOX(win_vbox), scrolled, TRUE, TRUE, 5);
 	gtk_widget_show(scrolled);
 
 	ewl->view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(desktop_file_list));
@@ -675,7 +675,7 @@ static void editor_list_window_create()
 	/* set initial sort order */
     gtk_tree_sortable_set_sort_column_id(sortable, DESKTOP_FILE_COLUMN_NAME, GTK_SORT_ASCENDING);
 
-	gtk_container_add(GTK_CONTAINER(scrolled), ewl->view);
+	gq_gtk_container_add(GTK_WIDGET(scrolled), ewl->view);
 	gtk_widget_show(ewl->view);
 
 	gtk_widget_show(ewl->window);
