@@ -26,7 +26,6 @@
 #include "filefilter.h"
 #include "pixbuf-util.h"
 #include "ui-fileops.h"
-#include "ui-spinner.h"
 #include "utilops.h"
 
 #define EDITOR_WINDOW_WIDTH 500
@@ -90,7 +89,7 @@ void editor_description_free(EditorDescription *editor)
 	g_free(editor->menu_path);
 	g_free(editor->hotkey);
 	g_free(editor->comment);
-	string_list_free(editor->ext_list);
+	g_list_free_full(editor->ext_list, g_free);
 	g_free(editor->file);
 	g_free(editor);
 }
@@ -99,7 +98,7 @@ static GList *editor_mime_types_to_extensions(gchar **mime_types)
 {
 	/** @FIXME this should be rewritten to use the shared mime database, as soon as we switch to gio */
 
-	static const gchar *conv_table[][2] = {
+	static constexpr const gchar *conv_table[][2] = {
 		{"image/*",		"*"},
 		{"image/bmp",		".bmp"},
 		{"image/gif",		".gif"},
@@ -153,18 +152,17 @@ static GList *editor_mime_types_to_extensions(gchar **mime_types)
 		{"image/x-xbitmap",	".xbm"},
 		{"image/x-xcf",		".xcf"},
 		{"image/x-xpixmap",	".xpm"},
-		{"image/x-x3f",		".x3f"},
 		{"application/x-navi-animation",		".ani"},
 		{"application/x-ptoptimizer-script",	".pto"},
-		{nullptr, nullptr}};
+	};
 
-	gint i, j;
+	gint i;
 	GList *list = nullptr;
 
 	for (i = 0; mime_types[i]; i++)
-		for (j = 0; conv_table[j][0]; j++)
-			if (strcmp(mime_types[i], conv_table[j][0]) == 0)
-				list = g_list_concat(list, filter_to_list(conv_table[j][1]));
+		for (const auto& c : conv_table)
+			if (strcmp(mime_types[i], c[0]) == 0)
+				list = g_list_concat(list, filter_to_list(c[1]));
 
 	return list;
 }
@@ -377,7 +375,7 @@ gboolean editor_read_desktop_file(const gchar *path)
 	return TRUE;
 }
 
-static gboolean editor_remove_desktop_file_cb(gpointer UNUSED(key), gpointer value, gpointer UNUSED(user_data))
+static gboolean editor_remove_desktop_file_cb(gpointer, gpointer value, gpointer)
 {
 	auto editor = static_cast<EditorDescription *>(value);
 	return editor->hidden || editor->ignored;
@@ -472,7 +470,7 @@ GList *editor_get_desktop_files()
 	return list;
 }
 
-static void editor_list_add_cb(gpointer UNUSED(key), gpointer value, gpointer data)
+static void editor_list_add_cb(gpointer, gpointer value, gpointer data)
 {
 	auto listp = static_cast<GList **>(data);
 	auto editor = static_cast<EditorDescription *>(value);
@@ -557,7 +555,7 @@ static void editor_verbose_window_close(GenericDialog *gd, gpointer data)
 	if (ed->pid == -1) editor_data_free(ed); /* the process has already terminated */
 }
 
-static void editor_verbose_window_stop(GenericDialog *UNUSED(gd), gpointer data)
+static void editor_verbose_window_stop(GenericDialog *, gpointer data)
 {
 	auto ed = static_cast<EditorData *>(data);
 	ed->stopping = TRUE;
@@ -569,7 +567,7 @@ static void editor_verbose_window_enable_close(EditorVerboseData *vd)
 {
 	vd->gd->cancel_cb = editor_verbose_window_close;
 
-	spinner_set_interval(vd->spinner, -1);
+	gtk_spinner_stop(GTK_SPINNER(vd->spinner));
 	gtk_widget_set_sensitive(vd->button_stop, FALSE);
 	gtk_widget_set_sensitive(vd->button_close, TRUE);
 }
@@ -589,41 +587,40 @@ static EditorVerboseData *editor_verbose_window(EditorData *ed, const gchar *tex
 	buf = g_strdup_printf(_("Output of %s"), text);
 	generic_dialog_add_message(vd->gd, nullptr, buf, nullptr, FALSE);
 	g_free(buf);
-	//~ vd->button_stop = generic_dialog_add_button(vd->gd, GTK_STOCK_STOP, NULL,
-						   //~ editor_verbose_window_stop, FALSE);
-	vd->button_stop = generic_dialog_add_button(vd->gd, "process-stop", nullptr,
+	vd->button_stop = generic_dialog_add_button(vd->gd, GQ_ICON_STOP, nullptr,
 						   editor_verbose_window_stop, FALSE);
 	gtk_widget_set_sensitive(vd->button_stop, FALSE);
-	vd->button_close = generic_dialog_add_button(vd->gd, GTK_STOCK_CLOSE, nullptr,
+	vd->button_close = generic_dialog_add_button(vd->gd, GQ_ICON_CLOSE, _("Close"),
 						    editor_verbose_window_close, TRUE);
 	gtk_widget_set_sensitive(vd->button_close, FALSE);
 
-	scrolled = gtk_scrolled_window_new(nullptr, nullptr);
-	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled), GTK_SHADOW_IN);
+	scrolled = gq_gtk_scrolled_window_new(nullptr, nullptr);
+	gq_gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled), GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
 				       GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_box_pack_start(GTK_BOX(vd->gd->vbox), scrolled, TRUE, TRUE, 5);
+	gq_gtk_box_pack_start(GTK_BOX(vd->gd->vbox), scrolled, TRUE, TRUE, 5);
 	gtk_widget_show(scrolled);
 
 	vd->text = gtk_text_view_new();
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(vd->text), FALSE);
 	gtk_widget_set_size_request(vd->text, EDITOR_WINDOW_WIDTH, EDITOR_WINDOW_HEIGHT);
-	gtk_container_add(GTK_CONTAINER(scrolled), vd->text);
+	gq_gtk_container_add(GTK_WIDGET(scrolled), vd->text);
 	gtk_widget_show(vd->text);
 
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_box_pack_start(GTK_BOX(vd->gd->vbox), hbox, FALSE, FALSE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(vd->gd->vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
 	vd->progress = gtk_progress_bar_new();
 	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(vd->progress), 0.0);
-	gtk_box_pack_start(GTK_BOX(hbox), vd->progress, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(hbox), vd->progress, TRUE, TRUE, 0);
 	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(vd->progress), "");
 	gtk_progress_bar_set_show_text(GTK_PROGRESS_BAR(vd->progress), TRUE);
 	gtk_widget_show(vd->progress);
 
-	vd->spinner = spinner_new(nullptr, SPINNER_SPEED);
-	gtk_box_pack_start(GTK_BOX(hbox), vd->spinner, FALSE, FALSE, 0);
+	vd->spinner = gtk_spinner_new();
+	gtk_spinner_start(GTK_SPINNER(vd->spinner));
+	gq_gtk_box_pack_start(GTK_BOX(hbox), vd->spinner, FALSE, FALSE, 0);
 	gtk_widget_show(vd->spinner);
 
 	gtk_widget_show(vd->gd->dialog);
@@ -704,14 +701,11 @@ enum PathType {
 
 static gchar *editor_command_path_parse(const FileData *fd, gboolean consider_sidecars, PathType type, const EditorDescription *editor)
 {
-	GString *string;
 	gchar *pathl;
 	const gchar *p = nullptr;
 
 	DEBUG_2("editor_command_path_parse: %s %d %d %s", fd->path, consider_sidecars, type, editor->key);
 
-	string = g_string_new("");
-
 	if (type == PATH_FILE || type == PATH_FILE_URL)
 		{
 		GList *work = editor->ext_list;
@@ -759,8 +753,8 @@ static gchar *editor_command_path_parse(const FileData *fd, gboolean consider_si
 		}
 
 	g_assert(p);
-	string = g_string_append(string, p);
 
+	GString *string = g_string_new(p);
 	if (type == PATH_FILE_URL) g_string_prepend(string, "file://");
 	pathl = path_from_utf8(string->str);
 	g_string_free(string, TRUE);
@@ -775,43 +769,84 @@ static gchar *editor_command_path_parse(const FileData *fd, gboolean consider_si
 	return pathl;
 }
 
-static GString *append_quoted(GString *str, const char *s, gboolean single_quotes, gboolean double_quotes)
+struct CommandBuilder
 {
-	const char *p;
+	~CommandBuilder()
+	{
+		if (!str) return;
 
-	if (!single_quotes)
-		{
-		if (!double_quotes)
-			g_string_append_c(str, '\'');
-		else
-			g_string_append(str, "\"'");
-		}
+		g_string_free(str, TRUE);
+	}
 
-	for (p = s; *p != '\0'; p++)
-		{
-		if (*p == '\'')
-			g_string_append(str, "'\\''");
-		else
-			g_string_append_c(str, *p);
-		}
+	void init()
+	{
+		if (str) return;
 
-	if (!single_quotes)
-		{
-		if (!double_quotes)
-			g_string_append_c(str, '\'');
-		else
-			g_string_append(str, "'\"");
-		}
+		str = g_string_new("");
+	}
 
-	return str;
-}
+	void append(const gchar *val)
+	{
+		if (!str) return;
+
+		str = g_string_append(str, val);
+	}
+
+	void append_c(gchar c)
+	{
+		if (!str) return;
+
+		str = g_string_append_c(str, c);
+	}
+
+	void append_quoted(const char *s, gboolean single_quotes, gboolean double_quotes)
+	{
+		if (!str) return;
+
+		if (!single_quotes)
+			{
+			if (!double_quotes)
+				str = g_string_append_c(str, '\'');
+			else
+				str = g_string_append(str, "\"'");
+			}
+
+		for (const char *p = s; *p != '\0'; p++)
+			{
+			if (*p == '\'')
+				str = g_string_append(str, "'\\''");
+			else
+				str = g_string_append_c(str, *p);
+			}
+
+		if (!single_quotes)
+			{
+			if (!double_quotes)
+				str = g_string_append_c(str, '\'');
+			else
+				str = g_string_append(str, "'\"");
+			}
+	}
+
+	gchar *get_command()
+	{
+		if (!str) return nullptr;
+
+		auto command = g_string_free(str, FALSE);
+		str = nullptr;
+		return command;
+	}
+
+private:
+	GString *str{nullptr};
+};
 
 
 EditorFlags editor_command_parse(const EditorDescription *editor, GList *list, gboolean consider_sidecars, gchar **output)
 {
-	auto  flags = static_cast<EditorFlags>(0);
+	auto flags = static_cast<EditorFlags>(0);
 	const gchar *p;
-	GString *result = nullptr;
+	CommandBuilder result;
 	gboolean escape = FALSE;
 	gboolean single_quotes = FALSE;
 	gboolean double_quotes = FALSE;
@@ -819,12 +854,14 @@ EditorFlags editor_command_parse(const EditorDescription *editor, GList *list, g
 	DEBUG_2("editor_command_parse: %s %d %d", editor->key, consider_sidecars, !!output);
 
 	if (output)
-		result = g_string_new("");
+		{
+		*output = nullptr;
+		result.init();
+		}
 
 	if (editor->exec == nullptr || editor->exec[0] == '\0')
 		{
-		flags = static_cast<EditorFlags>(flags | EDITOR_ERROR_EMPTY);
-		goto err;
+		return static_cast<EditorFlags>(flags | EDITOR_ERROR_EMPTY);
 		}
 
 	p = editor->exec;
@@ -838,16 +875,16 @@ EditorFlags editor_command_parse(const EditorDescription *editor, GList *list, g
 		if (escape)
 			{
 			escape = FALSE;
-			if (output) result = g_string_append_c(result, *p);
+			result.append_c(*p);
 			}
 		else if (*p == '\\')
 			{
 			if (!single_quotes) escape = TRUE;
-			if (output) result = g_string_append_c(result, *p);
+			result.append_c(*p);
 			}
 		else if (*p == '\'')
 			{
-			if (output) result = g_string_append_c(result, *p);
+			result.append_c(*p);
 			if (!single_quotes && !double_quotes)
 				single_quotes = TRUE;
 			else if (single_quotes)
@@ -855,7 +892,7 @@ EditorFlags editor_command_parse(const EditorDescription *editor, GList *list, g
 			}
 		else if (*p == '"')
 			{
-			if (output) result = g_string_append_c(result, *p);
+			result.append_c(*p);
 			if (!single_quotes && !double_quotes)
 				double_quotes = TRUE;
 			else if (double_quotes)
@@ -874,16 +911,14 @@ EditorFlags editor_command_parse(const EditorDescription *editor, GList *list, g
 					flags = static_cast<EditorFlags>(flags | EDITOR_FOR_EACH);
 					if (flags & EDITOR_SINGLE_COMMAND)
 						{
-						flags = static_cast<EditorFlags>(flags | EDITOR_ERROR_INCOMPATIBLE);
-						goto err;
+						return static_cast<EditorFlags>(flags | EDITOR_ERROR_INCOMPATIBLE);
 						}
 					if (list)
 						{
 						/* use the first file from the list */
 						if (!list->data)
 							{
-							flags = static_cast<EditorFlags>(flags | EDITOR_ERROR_NO_FILE);
-							goto err;
+							return static_cast<EditorFlags>(flags | EDITOR_ERROR_NO_FILE);
 							}
 						pathl = editor_command_path_parse(static_cast<FileData *>(list->data),
 										  consider_sidecars,
@@ -908,13 +943,9 @@ EditorFlags editor_command_parse(const EditorDescription *editor, GList *list, g
 
 						if (!pathl)
 							{
-							flags = static_cast<EditorFlags>(flags | EDITOR_ERROR_NO_FILE);
-							goto err;
-							}
-						if (output)
-							{
-							result = append_quoted(result, pathl, single_quotes, double_quotes);
+							return static_cast<EditorFlags>(flags | EDITOR_ERROR_NO_FILE);
 							}
+						result.append_quoted(pathl, single_quotes, double_quotes);
 						g_free(pathl);
 						}
 					break;
@@ -924,8 +955,7 @@ EditorFlags editor_command_parse(const EditorDescription *editor, GList *list, g
 					flags = static_cast<EditorFlags>(flags | EDITOR_SINGLE_COMMAND);
 					if (flags & (EDITOR_FOR_EACH | EDITOR_DEST))
 						{
-						flags = static_cast<EditorFlags>(flags | EDITOR_ERROR_INCOMPATIBLE);
-						goto err;
+						return static_cast<EditorFlags>(flags | EDITOR_ERROR_INCOMPATIBLE);
 						}
 
 					if (list)
@@ -942,48 +972,37 @@ EditorFlags editor_command_parse(const EditorDescription *editor, GList *list, g
 								{
 								ok = TRUE;
 
-								if (output)
+								if (work != list)
 									{
-									ok = TRUE;
-									if (work != list) g_string_append_c(result, ' ');
-									result = append_quoted(result, pathl, single_quotes, double_quotes);
+									result.append_c(' ');
 									}
+								result.append_quoted(pathl, single_quotes, double_quotes);
 								g_free(pathl);
 								}
 							work = work->next;
 							}
 						if (!ok)
 							{
-							flags = static_cast<EditorFlags>(flags | EDITOR_ERROR_NO_FILE);
-							goto err;
+							return static_cast<EditorFlags>(flags | EDITOR_ERROR_NO_FILE);
 							}
 						}
 					break;
 				case 'i':
 					if (editor->icon && *editor->icon)
 						{
-						if (output)
-							{
-							result = g_string_append(result, "--icon ");
-							result = append_quoted(result, editor->icon, single_quotes, double_quotes);
-							}
+						result.append("--icon ");
+						result.append_quoted(editor->icon, single_quotes, double_quotes);
 						}
 					break;
 				case 'c':
-					if (output)
-						{
-						result = append_quoted(result, editor->name, single_quotes, double_quotes);
-						}
+					result.append_quoted(editor->name, single_quotes, double_quotes);
 					break;
 				case 'k':
-					if (output)
-						{
-						result = append_quoted(result, editor->file, single_quotes, double_quotes);
-						}
+					result.append_quoted(editor->file, single_quotes, double_quotes);
 					break;
 				case '%':
 					/* %% = % escaping */
-					if (output) result = g_string_append_c(result, *p);
+					result.append_c(*p);
 					break;
 				case 'd':
 				case 'D':
@@ -994,13 +1013,12 @@ EditorFlags editor_command_parse(const EditorDescription *editor, GList *list, g
 					/* deprecated according to spec, ignore */
 					break;
 				default:
-					flags = static_cast<EditorFlags>(flags | EDITOR_ERROR_SYNTAX);
-					goto err;
+					return static_cast<EditorFlags>(flags | EDITOR_ERROR_SYNTAX);
 				}
 			}
 		else
 			{
-			if (output) result = g_string_append_c(result, *p);
+			result.append_c(*p);
 			}
 		p++;
 		}
@@ -1009,20 +1027,11 @@ EditorFlags editor_command_parse(const EditorDescription *editor, GList *list, g
 
 	if (output)
 		{
-		*output = g_string_free(result, FALSE);
+		*output = result.get_command();
 		DEBUG_3("Editor cmd: %s", *output);
 		}
 
 	return flags;
-
-
-err:
-	if (output)
-		{
-		g_string_free(result, TRUE);
-		*output = nullptr;
-		}
-	return flags;
 }
 
 
@@ -1329,7 +1338,7 @@ EditorFlags start_editor_from_filelist_full(const gchar *key, GList *list, const
 		{
 		gchar *text = g_strdup_printf(_("%s\n\"%s\""), editor_get_error_str(error), editor->file);
 
-		file_util_warning_dialog(_("Invalid editor command"), text, GTK_STOCK_DIALOG_ERROR, nullptr);
+		file_util_warning_dialog(_("Invalid editor command"), text, GQ_ICON_DIALOG_ERROR, nullptr);
 		g_free(text);
 		}
 
@@ -1426,12 +1435,16 @@ const gchar *editor_get_error_str(EditorFlags flags)
 	return _("Unknown error.");
 }
 
-//const gchar *editor_get_name(const gchar *key)
-//{
-	//EditorDescription *editor = g_hash_table_lookup(editors, key);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+const gchar *editor_get_name_unused(const gchar *key)
+{
+	EditorDescription *editor = static_cast<EditorDescription *>(g_hash_table_lookup(editors, key));
 
-	//if (!editor) return NULL;
+	if (!editor) return NULL;
+
+	return editor->name;
+}
+#pragma GCC diagnostic pop
 
-	//return editor->name;
-//}
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
