@@ -21,8 +21,9 @@
 
 #define _XOPEN_SOURCE
 
-#include <string.h>
-#include <math.h>
+#include <cmath>
+#include <cstdlib>
+#include <cstring>
 
 #ifdef HAVE_LCMS
 /*** color support enabled ***/
@@ -114,12 +115,11 @@ static gdouble get_crop_factor(ExifData *exif)
 
 	if (ratio < 0.5 || ratio > 2.0) return 0.0; /* reasonable ratio */
 
-	size = sqrt(xsize * xsize + ysize * ysize);
+	size = hypot(xsize, ysize);
 
 	if (size < 1.0 || size > 100.0) return 0.0; /* reasonable sensor size in mm */
 
-	return sqrt(36*36+24*24) / size;
-
+	return hypot(36, 24) / size;
 }
 
 static gboolean remove_suffix(gchar *str, const gchar *suffix, gint suffix_len)
@@ -399,7 +399,6 @@ static gchar *exif_build_formatted_Flash(ExifData *exif)
 {
 	/* grr, flash is a bitmask... */
 	GString *string;
-	gchar *text;
 	gint n;
 	gint v;
 
@@ -440,9 +439,7 @@ static gchar *exif_build_formatted_Flash(ExifData *exif)
 	/* red-eye (bit 6) */
 	if ((n >> 5) & 0x01) string = append_comma_text(string, _("red-eye reduction"));
 
-	text = string->str;
-	g_string_free(string, FALSE);
-	return text;
+	return g_string_free(string, FALSE);
 }
 
 static gchar *exif_build_formatted_Resolution(ExifData *exif)
@@ -528,7 +525,7 @@ static gchar *exif_build_formatted_ColorProfile(ExifData *exif)
 static gchar *exif_build_formatted_GPSPosition(ExifData *exif)
 {
 	GString *string;
-	gchar *text, *ref;
+	gchar *ref;
 	ExifRational *value;
 	ExifItem *item;
 	guint i;
@@ -573,10 +570,7 @@ static gchar *exif_build_formatted_GPSPosition(ExifData *exif)
 		g_string_append_printf(string, ", %0lu° %0lu' %0.2f\" %.1s", p1, p2, p3, ref);
 		} // if (item && ref)
 
-	text = string->str;
-	g_string_free(string, FALSE);
-
-	return text;
+	return g_string_free(string, FALSE);
 } // static gchar *exif_build_forma...
 
 static gchar *exif_build_formatted_GPSAltitude(ExifData *exif)
@@ -994,7 +988,7 @@ gchar *exif_get_data_as_text(ExifData *exif, const gchar *key)
 	if (key_valid) return text;
 
 	item = exif_get_item(exif, key);
-	if (item) return exif_item_get_data_as_text(item);
+	if (item) return exif_item_get_data_as_text(item, exif);
 
 	return nullptr;
 }
@@ -1174,7 +1168,7 @@ static gchar *mode_number(mode_t m)
 	return g_strdup_printf("%s (%d%d%d%d)", pbuf, mb, mu, mg, mo);
 }
 
-gchar *metadata_file_info(FileData *fd, const gchar *key, MetadataFormat UNUSED(format))
+gchar *metadata_file_info(FileData *fd, const gchar *key, MetadataFormat)
 {
 	gchar *page_n_of_m;
 
@@ -1226,7 +1220,7 @@ gchar *metadata_file_info(FileData *fd, const gchar *key, MetadataFormat UNUSED(
 }
 
 #ifdef HAVE_LUA
-gchar *metadata_lua_info(FileData *fd, const gchar *key, MetadataFormat UNUSED(format))
+gchar *metadata_lua_info(FileData *fd, const gchar *key, MetadataFormat)
 {
 	gchar *script_name;
 	gchar *script_name_utf8;
