@@ -70,8 +70,8 @@ struct ExifMarker
 	guint		tag;
 	ExifFormatType	format;
 	gint		components;
-	gchar		*key;
-	gchar		*description;
+	const gchar		*key;
+	const gchar		*description;
 	ExifTextList	*list;
 };
 
@@ -148,7 +148,7 @@ gint exif_parse_IFD_table(ExifData *exif,
 			  gint level,
 			  const ExifMarker *list);
 
-gint exif_tiff_directory_offset(guchar *data, const guint len,
+gint exif_tiff_directory_offset(guchar *data, guint len,
 				guint *offset, ExifByteOrder *bo);
 gint exif_tiff_parse(ExifData *exif, guchar *tiff, guint size, ExifMarker *list);
 
