@@ -22,6 +22,10 @@
 #ifndef __EXIF_H
 #define __EXIF_H
 
+struct ExifData;
+struct ExifItem;
+struct FileData;
+
 #define EXIF_FORMATTED() "formatted."
 #define EXIF_FORMATTED_LEN (sizeof(EXIF_FORMATTED()) - 1)
 
@@ -56,8 +60,6 @@ enum ExifFormatType {
  *-----------------------------------------------------------------------------
  */
 
-struct ExifItem;
-
 struct ExifRational
 {
 	guint32 num;
@@ -112,7 +114,7 @@ void exif_free_fd(FileData *fd, ExifData *exif);
  * this function gives access to the original data from the image.
  * original data are part of the processed data and should not be freed separately
  */
-ExifData *exif_get_original(ExifData *processed);
+ExifData *exif_get_original(ExifData *exif);
 
 
 gboolean exif_write(ExifData *exif);
@@ -136,7 +138,7 @@ gchar *exif_item_get_data(ExifItem *item, guint *data_len);
 gchar *exif_item_get_description(ExifItem *item);
 guint exif_item_get_format_id(ExifItem *item);
 const gchar *exif_item_get_format_name(ExifItem *item, gboolean brief);
-gchar *exif_item_get_data_as_text(ExifItem *item);
+gchar *exif_item_get_data_as_text(ExifItem *item, ExifData *exif);
 gint exif_item_get_integer(ExifItem *item, gint *value);
 ExifRational *exif_item_get_rational(ExifItem *item, gint *sign, guint n);
 
