@@ -57,10 +57,10 @@
 #include "main.h"
 #include "exif.h"
 
+#include "filedata.h"
 #include "filefilter.h"
-#include "ui-fileops.h"
-
 #include "misc.h"
+#include "ui-fileops.h"
 
 #if EXIV2_TEST_VERSION(0,28,0)
 #define AnyError Error
@@ -75,7 +75,7 @@ struct AltKey
 };
 
 /* this is a list of keys that should be converted, even with the older Exiv2 which does not support it directly */
-static const AltKey alt_keys[] = {
+static constexpr AltKey alt_keys[] = {
 	{"Xmp.tiff.Orientation",		"Exif.Image.Orientation", 	nullptr},
 	{"Xmp.dc.title",			nullptr,				"Iptc.Application2.ObjectName"		},
 	{"Xmp.photoshop.Urgency",		nullptr,				"Iptc.Application2.Urgency"		},
@@ -98,7 +98,6 @@ static const AltKey alt_keys[] = {
 	{"Xmp.dc.rights",			nullptr,				"Iptc.Application2.Copyright"		},
 	{"Xmp.dc.description",			nullptr,				"Iptc.Application2.Caption"		},
 	{"Xmp.photoshop.CaptionWriter",		nullptr,				"Iptc.Application2.Writer"		},
-	{nullptr, nullptr, nullptr}
 	};
 
 static void _debug_exception(const char* file,
@@ -123,7 +122,7 @@ struct ExifData
 
 	virtual ~ExifData() = default;
 
-	virtual void writeMetadata(gchar *UNUSED(path) = nullptr)
+	virtual void writeMetadata(gchar * = nullptr)
 	{
 		g_critical("Unsupported method of writing metadata");
 	}
@@ -189,7 +188,6 @@ public:
 		try
 			{
 			image_ = Exiv2::ImageFactory::open(pathl_);
-//			g_assert (image.get() != 0);
 			image_->readMetadata();
 
 #if EXIV2_TEST_VERSION(0,16,0)
@@ -269,7 +267,7 @@ public:
 		{
 			if (data_len) *data_len = cp_length_;
 #if GLIB_CHECK_VERSION(2,68,0)
-			return (unsigned char *) g_memdup2(cp_data_, cp_length_);
+			return static_cast<unsigned char *>(g_memdup2(cp_data_, cp_length_));
 #else
 			return static_cast<unsigned char *>(g_memdup(cp_data_, cp_length_));
 #endif
@@ -713,7 +711,6 @@ char *exif_item_get_description(ExifItem *item)
 		return utf8_validate_or_convert((reinterpret_cast<Exiv2::Metadatum *>(item))->tagLabel().c_str());
 	}
 	catch (std::exception& e) {
-//		debug_exception(e);
 		return nullptr;
 	}
 }
@@ -765,7 +762,7 @@ guint exif_item_get_format_id(ExifItem *item)
 	}
 }
 
-const char *exif_item_get_format_name(ExifItem *item, gboolean UNUSED(brief))
+const char *exif_item_get_format_name(ExifItem *item, gboolean)
 {
 	try {
 		if (!item) return nullptr;
@@ -778,13 +775,13 @@ const char *exif_item_get_format_name(ExifItem *item, gboolean UNUSED(brief))
 }
 
 
-gchar *exif_item_get_data_as_text(ExifItem *item)
+gchar *exif_item_get_data_as_text(ExifItem *item, ExifData *exif)
 {
 	try {
 		if (!item) return nullptr;
 		auto metadatum = reinterpret_cast<Exiv2::Metadatum *>(item);
 #if EXIV2_TEST_VERSION(0,17,0)
-		return utf8_validate_or_convert(metadatum->print().c_str());
+		return utf8_validate_or_convert(metadatum->print(&exif->exifData()).c_str());
 #else
 		std::stringstream str;
 		Exiv2::Exifdatum *exifdatum;
@@ -819,7 +816,7 @@ gchar *exif_item_get_string(ExifItem *item, int idx)
 #else
 		std::string str = em->toString(); /**< @FIXME ?? */
 #endif
-		if (idx == 0 && str == "") str = em->toString();
+		if (idx == 0 && str.empty()) str = em->toString();
 		if (str.length() > 5 && str.substr(0, 5) == "lang=")
 			{
 			std::string::size_type pos = str.find_first_of(' ');
@@ -899,13 +896,8 @@ gchar *exif_get_tag_description_by_key(const gchar *key)
 
 static const AltKey *find_alt_key(const gchar *xmp_key)
 {
-	gint i = 0;
-
-	while (alt_keys[i].xmp_key)
-		{
-		if (strcmp(xmp_key, alt_keys[i].xmp_key) == 0) return &alt_keys[i];
-		i++;
-		}
+	for (const auto& k : alt_keys)
+		if (strcmp(xmp_key, k.xmp_key) == 0) return &k;
 	return nullptr;
 }
 
@@ -1227,19 +1219,13 @@ guchar *exif_get_preview(ExifData *exif, guint *data_len, gint requested_width,
 
 			Exiv2::PreviewImage image = pm.getPreviewImage(*pos);
 
-			Exiv2::DataBuf buf = image.copy();
-
-#if EXIV2_TEST_VERSION(0,28,0)
-                       *data_len = buf.size();
-                       auto b = buf.data();
-                       buf.reset();
-                       return b;
-#else
-			std::pair<Exiv2::byte*, long> p = buf.release();
-
-			*data_len = p.second;
-			return p.first;
-#endif
+			// Let's not touch data_len until we finish copy.
+			// Just in case we run into OOM.
+			size_t img_sz = image.size();
+			Exiv2::byte* b = new Exiv2::byte[img_sz];
+			std::copy_n(image.pData(), img_sz, b);
+			*data_len = img_sz;
+			return b;
 			}
 		return nullptr;
 	}
