@@ -24,8 +24,8 @@
 #include "main.h"
 #include "filedata.h"
 
-typedef struct _FileCacheData FileCacheData;
-typedef void (*FileCacheReleaseFunc)(FileData *fd);
+struct FileCacheData;
+using FileCacheReleaseFunc = void (*)(FileData *);
 
 
 FileCacheData *file_cache_new(FileCacheReleaseFunc release, gulong max_size);
@@ -33,7 +33,6 @@ gboolean file_cache_get(FileCacheData *fc, FileData *fd);
 void file_cache_put(FileCacheData *fc, FileData *fd, gulong size);
 void file_cache_dump(FileCacheData *fc);
 void file_cache_set_size(FileCacheData *fc, gulong size);
-gulong file_cache_get_max_size(FileCacheData *fc);
 gulong file_cache_get_size(FileCacheData *fc);
 void file_cache_set_max_size(FileCacheData *fc, gulong size);
 
