@@ -22,6 +22,9 @@
 #ifndef FILEDATA_H
 #define FILEDATA_H
 
+struct ExifData;
+struct HistMap;
+
 #ifdef DEBUG
 #define DEBUG_FILEDATA
 #endif
@@ -32,6 +35,96 @@ gchar *text_from_size(gint64 size);
 gchar *text_from_size_abrev(gint64 size);
 const gchar *text_from_time(time_t t);
 
+enum FileDataChangeType {
+	FILEDATA_CHANGE_DELETE,
+	FILEDATA_CHANGE_MOVE,
+	FILEDATA_CHANGE_RENAME,
+	FILEDATA_CHANGE_COPY,
+	FILEDATA_CHANGE_UNSPECIFIED,
+	FILEDATA_CHANGE_WRITE_METADATA
+};
+
+enum NotifyPriority {
+	NOTIFY_PRIORITY_HIGH = 0,
+	NOTIFY_PRIORITY_MEDIUM,
+	NOTIFY_PRIORITY_LOW
+};
+
+enum SelectionType {
+	SELECTION_NONE		= 0,
+	SELECTION_SELECTED	= 1 << 0,
+	SELECTION_PRELIGHT	= 1 << 1,
+	SELECTION_FOCUS		= 1 << 2
+};
+
+struct FileDataChangeInfo {
+	FileDataChangeType type;
+	gchar *source;
+	gchar *dest;
+	gint error;
+	gboolean regroup_when_finished;
+};
+
+struct FileData {
+	guint magick;
+	gint type;
+	gchar *original_path; /**< key to file_data_pool hash table */
+	gchar *path;
+	const gchar *name;
+	const gchar *extension;
+	gchar *extended_extension;
+	FileFormatClass format_class;
+	gchar *format_name; /**< set by the image loader */
+	gchar *collate_key_name;
+	gchar *collate_key_name_nocase;
+	gchar *collate_key_name_natural;
+	gchar *collate_key_name_nocase_natural;
+	gint64 size;
+	time_t date;
+	time_t cdate;
+	mode_t mode; /**< this is needed at least for notification in view_dir because it is preserved after the file/directory is deleted */
+	gint sidecar_priority;
+
+	guint marks; /**< each bit represents one mark */
+	guint valid_marks; /**< zero bit means that the corresponding mark needs to be reread */
+
+
+	GList *sidecar_files;
+	FileData *parent; /**< parent file if this is a sidecar file, NULL otherwise */
+	FileDataChangeInfo *change; /**< for rename, move ... */
+	GdkPixbuf *thumb_pixbuf;
+
+	GdkPixbuf *pixbuf; /**< full-size image, only complete images, NULL during loading
+			      all FileData with non-NULL pixbuf are referenced by image_cache */
+
+	HistMap *histmap;
+
+	gboolean locked;
+	gint ref;
+	gint version; /**< increased when any field in this structure is changed */
+	gboolean disable_grouping;
+
+	gint user_orientation;
+	gint exif_orientation;
+
+	ExifData *exif;
+	time_t exifdate;
+	time_t exifdate_digitized;
+	GHashTable *modified_xmp; /**< hash table which contains unwritten xmp metadata in format: key->list of string values */
+	GList *cached_metadata;
+	gint rating;
+	gboolean metadata_in_idle_loaded;
+
+	gchar *owner;
+	gchar *group;
+	gchar *sym_link;
+
+	SelectionType selected;  /**< Used by view-file-icon. */
+
+	gint page_num;
+	gint page_total;
+};
+
 /**
  * @headerfile file_data_new_group
  * scan for sidecar files - expensive
@@ -79,9 +172,9 @@ void file_data_disable_grouping_list(GList *fd_list, gboolean disable);
 
 gint filelist_sort_compare_filedata(FileData *fa, FileData *fb);
 gint filelist_sort_compare_filedata_full(FileData *fa, FileData *fb, SortType method, gboolean ascend);
-GList *filelist_sort(GList *list, SortType method, gboolean ascend);
-GList *filelist_sort_full(GList *list, SortType method, gboolean ascend, GCompareFunc cb);
-GList *filelist_insert_sort_full(GList *list, gpointer data, SortType method, gboolean ascend, GCompareFunc cb);
+GList *filelist_sort(GList *list, SortType method, gboolean ascend, gboolean case_sensitive);
+GList *filelist_sort_full(GList *list, SortType method, gboolean ascend, gboolean case_sensitive, GCompareFunc cb);
+GList *filelist_insert_sort_full(GList *list, gpointer data, SortType method, gboolean ascend, gboolean case_sensitive, GCompareFunc cb);
 
 gboolean filelist_read(FileData *dir_fd, GList **files, GList **dirs);
 gboolean filelist_read_lstat(FileData *dir_fd, GList **files, GList **dirs);
@@ -94,7 +187,7 @@ GList *filelist_filter(GList *list, gboolean is_dir_list);
 
 GList *filelist_sort_path(GList *list);
 GList *filelist_recursive(FileData *dir_fd);
-GList *filelist_recursive_full(FileData *dir_fd, SortType method, gboolean ascend);
+GList *filelist_recursive_full(FileData *dir_fd, SortType method, gboolean ascend, gboolean case_sensitive);
 
 using FileDataGetMarkFunc = gboolean (*)(FileData *, gint, gpointer);
 using FileDataSetMarkFunc = gboolean (*)(FileData *, gint, gboolean, gpointer);
@@ -175,7 +268,7 @@ gboolean file_data_unregister_real_time_monitor(FileData *fd);
 void read_exif_time_data(FileData *file);
 void read_exif_time_digitized_data(FileData *file);
 
-gboolean marks_list_save(gchar *path, gboolean clear);
+gboolean marks_list_save(gchar *path, gboolean save);
 gboolean marks_list_load(const gchar *path);
 void marks_clear_all();
 void read_rating_data(FileData *file);
