@@ -40,7 +40,7 @@ struct ImageLoaderDDS {
 	gboolean abort;
 };
 
-static void free_buffer(guchar *pixels, gpointer UNUSED(data))
+static void free_buffer(guchar *pixels, gpointer)
 {
 	g_free(pixels);
 }
@@ -53,9 +53,12 @@ uint ddsGetWidth(unsigned const char * buffer) {
 	return (buffer[16] & 0xFF) | (buffer[17] & 0xFF) << 8 | (buffer[18] & 0xFF) << 16 | (buffer[19] & 0xFF) << 24;
 }
 
-//uint ddsGetMipmap(unsigned const char * buffer) {
-	//return (buffer[28] & 0xFF) | (buffer[29] & 0xFF) << 8 | (buffer[30] & 0xFF) << 16 | (buffer[31] & 0xFF) << 24;
-//}
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+uint ddsGetMipmap_unused(unsigned const char * buffer) {
+	return (buffer[28] & 0xFF) | (buffer[29] & 0xFF) << 8 | (buffer[30] & 0xFF) << 16 | (buffer[31] & 0xFF) << 24;
+}
+#pragma GCC diagnostic pop
 
 uint ddsGetPixelFormatFlags(unsigned const char * buffer) {
 	return (buffer[80] & 0xFF) | (buffer[81] & 0xFF) << 8 | (buffer[82] & 0xFF) << 16 | (buffer[83] & 0xFF) << 24;
@@ -524,7 +527,7 @@ guchar *ddsReadX8R8G8B8(uint width, uint height, const unsigned char *buffer) {
 	return reinterpret_cast<guchar *>(pixels);
 }
 
-static gboolean image_loader_dds_load (gpointer loader, const guchar *buf, gsize UNUSED(count), GError **UNUSED(error))
+static gboolean image_loader_dds_load (gpointer loader, const guchar *buf, gsize, GError **)
 {
 	auto ld = static_cast<ImageLoaderDDS *>(loader);
 	uint width = ddsGetWidth(buf);
@@ -580,17 +583,17 @@ static GdkPixbuf* image_loader_dds_get_pixbuf(gpointer loader)
 	return ld->pixbuf;
 }
 
-static gchar* image_loader_dds_get_format_name(gpointer UNUSED(loader))
+static gchar* image_loader_dds_get_format_name(gpointer)
 {
 	return g_strdup("dds");
 }
-static gchar** image_loader_dds_get_format_mime_types(gpointer UNUSED(loader))
+static gchar** image_loader_dds_get_format_mime_types(gpointer)
 {
 	static const gchar *mime[] = {"image/vnd-ms.dds", nullptr};
 	return g_strdupv(const_cast<gchar **>(mime));
 }
 
-static gboolean image_loader_dds_close(gpointer UNUSED(loader), GError **UNUSED(error))
+static gboolean image_loader_dds_close(gpointer, GError **)
 {
 	return TRUE;
 }
