@@ -21,29 +21,47 @@
 
 #include "main.h"
 #include "image-load.h"
-#include "image-load-cr3.h"
-#include "image-load-gdk.h"
-#include "image-load-jpeg.h"
-#include "image-load-tiff.h"
-#include "image-load-dds.h"
-#include "image-load-djvu.h"
-#include "image-load-external.h"
-#include "image-load-pdf.h"
-#include "image-load-psd.h"
-#include "image-load-heif.h"
-#include "image-load-ffmpegthumbnailer.h"
-#include "image-load-collection.h"
-#include "image-load-zxscr.h"
-#include "image-load-j2k.h"
-#include "image-load-jpegxl.h"
-#include "image-load-libraw.h"
-#include "image-load-svgz.h"
-#include "misc.h"
 
 #include "exif.h"
 #include "filedata.h"
-#include "ui-fileops.h"
 #include "gq-marshal.h"
+#include "image-load-collection.h"
+#include "image-load-dds.h"
+#include "image-load-external.h"
+#include "image-load-gdk.h"
+#include "image-load-libraw.h"
+#include "image-load-psd.h"
+#include "image-load-svgz.h"
+#include "image-load-webp.h"
+#include "image-load-zxscr.h"
+#include "misc.h"
+#include "ui-fileops.h"
+
+#ifdef HAVE_DJVU
+	#include "image-load-djvu.h"
+#endif
+#ifdef HAVE_FFMPEGTHUMBNAILER
+	#include "image-load-ffmpegthumbnailer.h"
+#endif
+#ifdef HAVE_HEIF
+	#include "image-load-heif.h"
+#endif
+#ifdef HAVE_J2K
+	#include "image-load-j2k.h"
+#endif
+#ifdef HAVE_JPEG
+	#include "image-load-cr3.h"
+	#include "image-load-jpeg.h"
+#endif
+#ifdef HAVE_JPEGXL
+	#include "image-load-jpegxl.h"
+#endif
+#ifdef HAVE_PDF
+	#include "image-load-pdf.h"
+#endif
+#ifdef HAVE_TIFF
+	#include "image-load-tiff.h"
+#endif
 
 #include <fcntl.h>
 #include <sys/mman.h>
@@ -88,12 +106,12 @@ GType image_loader_get_type()
 			static_cast<GInstanceInitFunc>(image_loader_init), /* instance_init */
 			nullptr	/* value_table */
 			};
-		type = g_type_register_static(G_TYPE_OBJECT, "ImageLoaderType", &info, GTypeFlags(0));
+		type = g_type_register_static(G_TYPE_OBJECT, "ImageLoaderType", &info, static_cast<GTypeFlags>(0));
 		}
 	return type;
 }
 
-static void image_loader_init(GTypeInstance *instance, gpointer UNUSED(g_class))
+static void image_loader_init(GTypeInstance *instance, gpointer)
 {
 	auto il = reinterpret_cast<ImageLoader *>(instance);
 
@@ -129,7 +147,7 @@ static void image_loader_init(GTypeInstance *instance, gpointer UNUSED(g_class))
 	DEBUG_1("new image loader %p, bufsize=%" G_GSIZE_FORMAT " idle_loop=%u", (void *)il, il->read_buffer_size, il->idle_read_loop_count);
 }
 
-static void image_loader_class_init_wrapper(void *data, void *UNUSED(user_data))
+static void image_loader_class_init_wrapper(void *data, void *)
 {
 	image_loader_class_init(static_cast<ImageLoaderClass *>(data));
 }
@@ -138,9 +156,6 @@ static void image_loader_class_init(ImageLoaderClass *loader_class)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (loader_class);
 
-//	gobject_class->set_property = image_loader_set_property;
-//	gobject_class->get_property = image_loader_get_property;
-
 	gobject_class->finalize = image_loader_finalize;
 
 
@@ -470,7 +485,7 @@ static void image_loader_sync_pixbuf(ImageLoader *il)
 	g_mutex_unlock(il->data_mutex);
 }
 
-static void image_loader_area_updated_cb(gpointer UNUSED(loader),
+static void image_loader_area_updated_cb(gpointer,
 				 guint x, guint y, guint w, guint h,
 				 gpointer data)
 {
@@ -672,6 +687,16 @@ static void image_loader_setup_loader(ImageLoader *il)
 		}
 	else
 #endif
+#ifdef HAVE_WEBP
+	if (il->bytes_total >= 12 &&
+		(memcmp(il->mapped_file, "RIFF", 4) == 0) &&
+		(memcmp(il->mapped_file + 8, "WEBP", 4) == 0))
+		{
+		DEBUG_1("Using custom webp loader");
+		image_loader_backend_set_webp(&il->backend);
+		}
+	else
+#endif
 #ifdef HAVE_DJVU
 	if (il->bytes_total >= 16 &&
 		(memcmp(il->mapped_file, "AT&TFORM", 8) == 0) &&
@@ -1003,7 +1028,7 @@ static gboolean image_loader_setup_source(ImageLoader *il)
 				{
 				/* Both exiv2 and libraw sometimes return a pointer to a file
 				 * section that is not a jpeg */
-				if (!(il->mapped_file[0] == 0xFF && il->mapped_file[1] == 0xD8))
+				if (il->mapped_file[0] != 0xFF || il->mapped_file[1] != 0xD8)
 					{
 					il->mapped_file = nullptr;
 					}
@@ -1023,7 +1048,7 @@ static gboolean image_loader_setup_source(ImageLoader *il)
 				{
 				/* Both exiv2 and libraw sometimes return a pointer to a file
 				 * section that is not a jpeg */
-				if (!(il->mapped_file[0] == 0xFF && il->mapped_file[1] == 0xD8))
+				if (il->mapped_file[0] != 0xFF || il->mapped_file[1] != 0xD8)
 					{
 					il->mapped_file = nullptr;
 					}
@@ -1141,9 +1166,8 @@ void image_loader_delay_area_ready(ImageLoader *il, gboolean enable)
 			work = work->next;
 
 			g_signal_emit(il, signals[SIGNAL_AREA_READY], 0, par->x, par->y, par->w, par->h);
-			g_free(par);
 			}
-		g_list_free(list);
+		g_list_free_full(list, g_free);
 		}
 	else
 		{
@@ -1227,7 +1251,7 @@ static void image_loader_thread_wait_high()
 }
 
 
-static void image_loader_thread_run(gpointer data, gpointer UNUSED(user_data))
+static void image_loader_thread_run(gpointer data, gpointer)
 {
 	auto il = static_cast<ImageLoader *>(data);
 	gboolean cont;
