@@ -22,6 +22,8 @@
 #ifndef IMAGE_LOAD_H
 #define IMAGE_LOAD_H
 
+struct FileData;
+
 #define TYPE_IMAGE_LOADER		(image_loader_get_type())
 
 using ImageLoaderBackendCbAreaPrepared = void (*)(gpointer, gpointer);
@@ -141,7 +143,7 @@ void image_loader_delay_area_ready(ImageLoader *il, gboolean enable);
  */
 void image_loader_set_requested_size(ImageLoader *il, gint width, gint height);
 
-void image_loader_set_buffer_size(ImageLoader *il, guint size);
+void image_loader_set_buffer_size(ImageLoader *il, guint count);
 
 /**
  * @headerfile image_loader_set_priority
