@@ -22,16 +22,18 @@
 #include "main.h"
 #include "image-overlay.h"
 
+#include "collect.h"
 #include "filedata.h"
 #include "histogram.h"
 #include "image.h"
+#include "image-load.h"
 #include "img-view.h"
 #include "layout.h"
 #include "osd.h"
 #include "pixbuf-renderer.h"
 #include "pixbuf-util.h"
+#include "slideshow.h"
 #include "ui-fileops.h"
-#include "image-load.h"
 
 /*
  *----------------------------------------------------------------------------
@@ -365,20 +367,20 @@ static GdkPixbuf *image_osd_info_render(OverlayStateData *osd)
 
 		if (active_marks > 0)
 			{
-			GString *buf = g_string_sized_new(FILEDATA_MARKS_SIZE * 2);
+			GString *buf = g_string_sized_new(strlen(text) + 1 + FILEDATA_MARKS_SIZE * 2);
+
+			if (*text)
+				{
+				g_string_append_printf(buf, "%s\n", text);
+				}
 
 			for (mark = 0; mark < FILEDATA_MARKS_SIZE; mark++)
 				{
 				g_string_append_printf(buf, file_data_get_mark(fd, mark) ? " <span background='#FF00FF'>%c</span>" : " %c", '1' + (mark < 9 ? mark : -1) );
 				}
 
-			if (*text)
-				text2 = g_strdup_printf("%s\n%s", text, buf->str);
-			else
-				text2 = g_strdup(buf->str);
-			g_string_free(buf, TRUE);
 			g_free(text);
-			text = text2;
+			text = g_string_free(buf, FALSE);
 			}
 
 		if (with_hist)
@@ -447,6 +449,23 @@ static GdkPixbuf *image_osd_info_render(OverlayStateData *osd)
 	return pixbuf;
 }
 
+/**
+ * @brief Create non-standard icons for the OSD
+ * @param flag
+ * @returns
+ *
+ * IMAGE_OSD_COLOR
+ * \image html image-osd-color.png
+ * IMAGE_OSD_FIRST
+ * \image html image-osd-first.png
+ * IMAGE_OSD_ICON
+ * \image html image-osd-icon.png
+ * IMAGE_OSD_LAST
+ * \image html image-osd-last.png
+ * IMAGE_OSD_ROTATE_AUTO
+ * \image html image-osd-rotate-auto.png
+ *
+ */
 static GdkPixbuf *image_osd_icon_pixbuf(ImageOSDFlag flag)
 {
 	static GdkPixbuf **icons = nullptr;
@@ -738,7 +757,7 @@ static void image_osd_timer_schedule(OverlayStateData *osd)
 		}
 }
 
-static void image_osd_state_cb(ImageWindow *UNUSED(imd), ImageState state, gpointer data)
+static void image_osd_state_cb(ImageWindow *, ImageState state, gpointer data)
 {
 	auto osd = static_cast<OverlayStateData *>(data);
 
@@ -784,7 +803,7 @@ static void image_osd_free(OverlayStateData *osd)
 	g_free(osd);
 }
 
-static void image_osd_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void image_osd_destroy_cb(GtkWidget *, gpointer data)
 {
 	auto osd = static_cast<OverlayStateData *>(data);
 
