@@ -379,7 +379,7 @@ static void view_step_to_end(ViewWindow *vw, gboolean last)
  *-----------------------------------------------------------------------------
  */
 
-static void view_window_press_cb(GtkWidget *UNUSED(widget), GdkEventButton *bevent, gpointer data)
+static void view_window_press_cb(GtkWidget *, GdkEventButton *bevent, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
@@ -668,7 +668,7 @@ static void button_cb(ImageWindow *imd, GdkEventButton *event, gpointer data)
 					}
 				else
 					{
-					warning_dialog(_("Cannot open archive file"), _("See the Log Window"), GTK_STOCK_DIALOG_WARNING, nullptr);
+					warning_dialog(_("Cannot open archive file"), _("See the Log Window"), GQ_ICON_DIALOG_WARNING, nullptr);
 					}
 				}
 	 		else if (options->image_l_click_video && options->image_l_click_video_editor && imd->image_fd->format_class == FORMAT_CLASS_VIDEO)
@@ -752,7 +752,7 @@ static void view_image_set_buttons(ViewWindow *vw, ImageWindow *imd)
 	image_set_scroll_func(imd, scroll_cb, vw);
 }
 
-static void view_fullscreen_stop_func(FullScreenData *UNUSED(fs), gpointer data)
+static void view_fullscreen_stop_func(FullScreenData *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
@@ -809,7 +809,7 @@ static void view_slideshow_prev(ViewWindow *vw)
 	if (vw->ss) slideshow_prev(vw->ss);
 }
 
-static void view_slideshow_stop_func(SlideShowData *UNUSED(fs), gpointer data)
+static void view_slideshow_stop_func(SlideShowData *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	GList *work;
@@ -866,7 +866,7 @@ static void view_slideshow_stop(ViewWindow *vw)
 	if (vw->ss) slideshow_free(vw->ss);
 }
 
-static void view_window_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_window_destroy_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
@@ -886,10 +886,10 @@ static void view_window_close(ViewWindow *vw)
 {
 	view_slideshow_stop(vw);
 	view_fullscreen_toggle(vw, TRUE);
-	gtk_widget_destroy(vw->window);
+	gq_gtk_widget_destroy(vw->window);
 }
 
-static gboolean view_window_delete_cb(GtkWidget *UNUSED(w), GdkEventAny *UNUSED(event), gpointer data)
+static gboolean view_window_delete_cb(GtkWidget *, GdkEventAny *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
@@ -908,7 +908,7 @@ static ViewWindow *real_view_window_new(FileData *fd, GList *list, CollectionDat
 
 	vw = g_new0(ViewWindow, 1);
 
-	vw->window = window_new(GTK_WINDOW_TOPLEVEL, "view", PIXBUF_INLINE_ICON_VIEW, nullptr, nullptr);
+	vw->window = window_new("view", PIXBUF_INLINE_ICON_VIEW, nullptr, nullptr);
 	DEBUG_NAME(vw->window);
 
 	geometry.min_width = DEFAULT_MINIMAL_WINDOW_SIZE;
@@ -931,7 +931,7 @@ static ViewWindow *real_view_window_new(FileData *fd, GList *list, CollectionDat
 	image_auto_refresh_enable(vw->imd, TRUE);
 	image_top_window_set_sync(vw->imd, TRUE);
 
-	gtk_container_add(GTK_CONTAINER(vw->window), vw->imd->widget);
+	gq_gtk_container_add(GTK_WIDGET(vw->window), vw->imd->widget);
 	gtk_widget_show(vw->imd->widget);
 
 	view_window_dnd_init(vw);
@@ -1016,7 +1016,7 @@ static ViewWindow *real_view_window_new(FileData *fd, GList *list, CollectionDat
 	return vw;
 }
 
-static void view_window_collection_unref_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_window_collection_unref_cb(GtkWidget *, gpointer data)
 {
 	auto cd = static_cast<CollectionData *>(data);
 
@@ -1139,7 +1139,7 @@ gboolean view_window_find_image(ImageWindow *imd, gint *index, gint *total)
  *-----------------------------------------------------------------------------
  */
 
-static void view_new_window_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_new_window_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	CollectionData *cd;
@@ -1187,35 +1187,35 @@ static void view_alter_cb(GtkWidget *widget, gpointer data)
 	image_alter_orientation(vw->imd, vw->imd->image_fd, type);
 }
 
-static void view_zoom_in_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_zoom_in_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
 	image_zoom_adjust(view_window_active_image(vw), get_zoom_increment());
 }
 
-static void view_zoom_out_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_zoom_out_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
 	image_zoom_adjust(view_window_active_image(vw), -get_zoom_increment());
 }
 
-static void view_zoom_1_1_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_zoom_1_1_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
 	image_zoom_set(view_window_active_image(vw), 1.0);
 }
 
-static void view_zoom_fit_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_zoom_fit_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
 	image_zoom_set(view_window_active_image(vw), 0.0);
 }
 
-static void view_copy_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_copy_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	ImageWindow *imd;
@@ -1224,7 +1224,7 @@ static void view_copy_cb(GtkWidget *UNUSED(widget), gpointer data)
 	file_util_copy(image_get_fd(imd), nullptr, nullptr, imd->widget);
 }
 
-static void view_move_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_move_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	ImageWindow *imd;
@@ -1233,7 +1233,7 @@ static void view_move_cb(GtkWidget *UNUSED(widget), gpointer data)
 	file_util_move(image_get_fd(imd), nullptr, nullptr, imd->widget);
 }
 
-static void view_rename_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_rename_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	ImageWindow *imd;
@@ -1242,7 +1242,7 @@ static void view_rename_cb(GtkWidget *UNUSED(widget), gpointer data)
 	file_util_rename(image_get_fd(imd), nullptr, imd->widget);
 }
 
-static void view_delete_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_delete_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	ImageWindow *imd;
@@ -1252,7 +1252,7 @@ static void view_delete_cb(GtkWidget *UNUSED(widget), gpointer data)
 	file_util_delete(image_get_fd(imd), nullptr, imd->widget);
 }
 
-static void view_move_to_trash_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_move_to_trash_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	ImageWindow *imd;
@@ -1262,7 +1262,7 @@ static void view_move_to_trash_cb(GtkWidget *UNUSED(widget), gpointer data)
 	file_util_delete(image_get_fd(imd), nullptr, imd->widget);
 }
 
-static void view_copy_path_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_copy_path_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	ImageWindow *imd;
@@ -1271,7 +1271,7 @@ static void view_copy_path_cb(GtkWidget *UNUSED(widget), gpointer data)
 	file_util_copy_path_to_clipboard(image_get_fd(imd), TRUE);
 }
 
-static void view_copy_path_unquoted_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_copy_path_unquoted_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	ImageWindow *imd;
@@ -1280,35 +1280,35 @@ static void view_copy_path_unquoted_cb(GtkWidget *UNUSED(widget), gpointer data)
 	file_util_copy_path_to_clipboard(image_get_fd(imd), FALSE);
 }
 
-static void view_fullscreen_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_fullscreen_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
 	view_fullscreen_toggle(vw, FALSE);
 }
 
-static void view_slideshow_start_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_slideshow_start_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
 	view_slideshow_start(vw);
 }
 
-static void view_slideshow_stop_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_slideshow_stop_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
 	view_slideshow_stop(vw);
 }
 
-static void view_slideshow_pause_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_slideshow_pause_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
 	slideshow_pause_toggle(vw->ss);
 }
 
-static void view_close_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_close_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 
@@ -1320,13 +1320,13 @@ static LayoutWindow *view_new_layout_with_fd(FileData *fd)
 	LayoutWindow *nw;
 
 	nw = layout_new(nullptr, nullptr);
-	layout_sort_set(nw, options->file_sort.method, options->file_sort.ascending);
+	layout_sort_set_files(nw, nw->options.file_view_list_sort.method, nw->options.file_view_list_sort.ascend, nw->options.file_view_list_sort.case_sensitive);
 	layout_set_fd(nw, fd);
 	return nw;
 }
 
 
-static void view_set_layout_path_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_set_layout_path_cb(GtkWidget *, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	LayoutWindow *lw;
@@ -1344,7 +1344,7 @@ static void view_set_layout_path_cb(GtkWidget *UNUSED(widget), gpointer data)
 	view_window_close(vw);
 }
 
-static void view_popup_menu_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void view_popup_menu_destroy_cb(GtkWidget *, gpointer data)
 {
 	auto editmenu_fd_list = static_cast<GList *>(data);
 
@@ -1403,10 +1403,10 @@ static GtkWidget *view_popup_menu(ViewWindow *vw)
 	g_object_set_data(G_OBJECT(menu), "window_keys", image_window_keys);
 	g_object_set_data(G_OBJECT(menu), "accel_group", accel_group);
 
-	menu_item_add_stock(menu, _("Zoom _in"), GTK_STOCK_ZOOM_IN, G_CALLBACK(view_zoom_in_cb), vw);
-	menu_item_add_stock(menu, _("Zoom _out"), GTK_STOCK_ZOOM_OUT, G_CALLBACK(view_zoom_out_cb), vw);
-	menu_item_add_stock(menu, _("Zoom _1:1"), GTK_STOCK_ZOOM_100, G_CALLBACK(view_zoom_1_1_cb), vw);
-	menu_item_add_stock(menu, _("Zoom to fit"), GTK_STOCK_ZOOM_FIT, G_CALLBACK(view_zoom_fit_cb), vw);
+	menu_item_add_icon(menu, _("Zoom _in"), GQ_ICON_ZOOM_IN, G_CALLBACK(view_zoom_in_cb), vw);
+	menu_item_add_icon(menu, _("Zoom _out"), GQ_ICON_ZOOM_OUT, G_CALLBACK(view_zoom_out_cb), vw);
+	menu_item_add_icon(menu, _("Zoom _1:1"), GQ_ICON_ZOOM_100, G_CALLBACK(view_zoom_1_1_cb), vw);
+	menu_item_add_icon(menu, _("Zoom to fit"), GQ_ICON_ZOOM_FIT, G_CALLBACK(view_zoom_fit_cb), vw);
 	menu_item_add_divider(menu);
 
  	editmenu_fd_list = view_window_get_fd_list(vw);
@@ -1417,24 +1417,24 @@ static GtkWidget *view_popup_menu(ViewWindow *vw)
 
 	submenu_add_alter(menu, G_CALLBACK(view_alter_cb), vw);
 
-	menu_item_add_stock(menu, _("View in _new window"), GTK_STOCK_NEW, G_CALLBACK(view_new_window_cb), vw);
+	menu_item_add_icon(menu, _("View in _new window"), GQ_ICON_NEW, G_CALLBACK(view_new_window_cb), vw);
 	item = menu_item_add(menu, _("_Go to directory view"), G_CALLBACK(view_set_layout_path_cb), vw);
 
 	menu_item_add_divider(menu);
-	menu_item_add_stock(menu, _("_Copy..."), GTK_STOCK_COPY, G_CALLBACK(view_copy_cb), vw);
+	menu_item_add_icon(menu, _("_Copy..."), GQ_ICON_COPY, G_CALLBACK(view_copy_cb), vw);
 	menu_item_add(menu, _("_Move..."), G_CALLBACK(view_move_cb), vw);
 	menu_item_add(menu, _("_Rename..."), G_CALLBACK(view_rename_cb), vw);
 	menu_item_add(menu, _("_Copy path"), G_CALLBACK(view_copy_path_cb), vw);
 	menu_item_add(menu, _("_Copy path unquoted"), G_CALLBACK(view_copy_path_unquoted_cb), vw);
 
 	menu_item_add_divider(menu);
-	menu_item_add_stock(menu,
+	menu_item_add_icon(menu,
 				options->file_ops.confirm_move_to_trash ? _("Move to Trash...") :
-					_("Move to Trash"), PIXBUF_INLINE_ICON_TRASH,
+					_("Move to Trash"), GQ_ICON_DELETE,
 				G_CALLBACK(view_move_to_trash_cb), vw);
-	menu_item_add_stock(menu,
+	menu_item_add_icon(menu,
 				options->file_ops.confirm_delete ? _("_Delete...") :
-					_("_Delete"), GTK_STOCK_DELETE,
+					_("_Delete"), GQ_ICON_DELETE_SHRED,
 				G_CALLBACK(view_delete_cb), vw);
 
 	menu_item_add_divider(menu);
@@ -1468,15 +1468,15 @@ static GtkWidget *view_popup_menu(ViewWindow *vw)
 
 	if (vw->fs)
 		{
-		menu_item_add(menu, _("Exit _full screen"), G_CALLBACK(view_fullscreen_cb), vw);
+		menu_item_add_icon(menu, _("Exit _full screen"), GQ_ICON_LEAVE_FULLSCREEN, G_CALLBACK(view_fullscreen_cb), vw);
 		}
 	else
 		{
-		menu_item_add(menu, _("_Full screen"), G_CALLBACK(view_fullscreen_cb), vw);
+		menu_item_add_icon(menu, _("_Full screen"), GQ_ICON_FULLSCREEN, G_CALLBACK(view_fullscreen_cb), vw);
 		}
 
 	menu_item_add_divider(menu);
-	menu_item_add_stock(menu, _("C_lose window"), GTK_STOCK_CLOSE, G_CALLBACK(view_close_cb), vw);
+	menu_item_add_icon(menu, _("C_lose window"), GQ_ICON_CLOSE, G_CALLBACK(view_close_cb), vw);
 
 	return menu;
 }
@@ -1492,7 +1492,7 @@ struct CViewConfirmD {
 	GList *list;
 };
 
-static void view_dir_list_cancel(GtkWidget *UNUSED(widget), gpointer UNUSED(data))
+static void view_dir_list_cancel(GtkWidget *, gpointer)
 {
 	/* do nothing */
 }
@@ -1556,25 +1556,25 @@ static void view_dir_list_do(ViewWindow *vw, GList *list, gboolean skip, gboolea
 		}
 }
 
-static void view_dir_list_add(GtkWidget *UNUSED(widget), gpointer data)
+static void view_dir_list_add(GtkWidget *, gpointer data)
 {
 	auto d = static_cast<CViewConfirmD *>(data);
 	view_dir_list_do(d->vw, d->list, FALSE, FALSE);
 }
 
-static void view_dir_list_recurse(GtkWidget *UNUSED(widget), gpointer data)
+static void view_dir_list_recurse(GtkWidget *, gpointer data)
 {
 	auto d = static_cast<CViewConfirmD *>(data);
 	view_dir_list_do(d->vw, d->list, FALSE, TRUE);
 }
 
-static void view_dir_list_skip(GtkWidget *UNUSED(widget), gpointer data)
+static void view_dir_list_skip(GtkWidget *, gpointer data)
 {
 	auto d = static_cast<CViewConfirmD *>(data);
 	view_dir_list_do(d->vw, d->list, TRUE, FALSE);
 }
 
-static void view_dir_list_destroy(GtkWidget *UNUSED(widget), gpointer data)
+static void view_dir_list_destroy(GtkWidget *, gpointer data)
 {
 	auto d = static_cast<CViewConfirmD *>(data);
 	filelist_free(d->list);
@@ -1594,13 +1594,13 @@ static GtkWidget *view_confirm_dir_list(ViewWindow *vw, GList *list)
 	g_signal_connect(G_OBJECT(menu), "destroy",
 			 G_CALLBACK(view_dir_list_destroy), d);
 
-	menu_item_add_stock(menu, _("Dropped list includes folders."), GTK_STOCK_DND_MULTIPLE, nullptr, nullptr);
+	menu_item_add_stock(menu, _("Dropped list includes folders."), GQ_ICON_DND, nullptr, nullptr);
 	menu_item_add_divider(menu);
-	menu_item_add_stock(menu, _("_Add contents"), GTK_STOCK_OK, G_CALLBACK(view_dir_list_add), d);
-	menu_item_add_stock(menu, _("Add contents _recursive"), GTK_STOCK_ADD, G_CALLBACK(view_dir_list_recurse), d);
-	menu_item_add_stock(menu, _("_Skip folders"), GTK_STOCK_REMOVE, G_CALLBACK(view_dir_list_skip), d);
+	menu_item_add_icon(menu, _("_Add contents"), GQ_ICON_OK, G_CALLBACK(view_dir_list_add), d);
+	menu_item_add_icon(menu, _("Add contents _recursive"), GQ_ICON_ADD, G_CALLBACK(view_dir_list_recurse), d);
+	menu_item_add_icon(menu, _("_Skip folders"), GQ_ICON_REMOVE, G_CALLBACK(view_dir_list_skip), d);
 	menu_item_add_divider(menu);
-	menu_item_add_stock(menu, _("Cancel"), GTK_STOCK_CANCEL, G_CALLBACK(view_dir_list_cancel), d);
+	menu_item_add_icon(menu, _("Cancel"), GQ_ICON_CANCEL, G_CALLBACK(view_dir_list_cancel), d);
 
 	return menu;
 }
@@ -1611,10 +1611,10 @@ static GtkWidget *view_confirm_dir_list(ViewWindow *vw, GList *list)
  *-----------------------------------------------------------------------------
  */
 
-static void view_window_get_dnd_data(GtkWidget *UNUSED(widget), GdkDragContext *context,
-				     gint UNUSED(x), gint UNUSED(y),
+static void view_window_get_dnd_data(GtkWidget *, GdkDragContext *context,
+				     gint, gint,
 				     GtkSelectionData *selection_data, guint info,
-				     guint UNUSED(time), gpointer data)
+				     guint, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	ImageWindow *imd;
@@ -1691,9 +1691,9 @@ static void view_window_get_dnd_data(GtkWidget *UNUSED(widget), GdkDragContext *
 		}
 }
 
-static void view_window_set_dnd_data(GtkWidget *UNUSED(widget), GdkDragContext *UNUSED(context),
-				     GtkSelectionData *selection_data, guint UNUSED(info),
-				     guint UNUSED(time), gpointer data)
+static void view_window_set_dnd_data(GtkWidget *, GdkDragContext *,
+				     GtkSelectionData *selection_data, guint,
+				     guint, gpointer data)
 {
 	auto vw = static_cast<ViewWindow *>(data);
 	FileData *fd;
