@@ -57,12 +57,14 @@ static void layout_image_animate_update_image(LayoutWindow *lw);
  * full screen overlay
  *----------------------------------------------------------------------------
  */
-
-//void layout_image_overlay_toggle(LayoutWindow *lw)
-//{
-	//if (!lw) return;
-	//image_osd_toggle(lw->image);
-//}
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+static void layout_image_overlay_toggle_unused(LayoutWindow *lw)
+{
+	if (!lw) return;
+	image_osd_toggle(lw->image);
+}
+#pragma GCC diagnostic pop
 
 /*
  *----------------------------------------------------------------------------
@@ -162,7 +164,7 @@ static void layout_image_slideshow_prev(LayoutWindow *lw)
 	if (lw->slideshow) slideshow_prev(lw->slideshow);
 }
 
-static void layout_image_slideshow_stop_func(SlideShowData *UNUSED(ss), gpointer data)
+static void layout_image_slideshow_stop_func(SlideShowData *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
@@ -282,6 +284,21 @@ static gboolean layout_image_slideshow_continue_check(LayoutWindow *lw)
  *----------------------------------------------------------------------------
  */
 
+struct AnimationData
+{
+	ImageWindow *iw;
+	LayoutWindow *lw;
+	GdkPixbufAnimation *gpa;
+	GdkPixbufAnimationIter *iter;
+	GdkPixbuf *gpb;
+	FileData *data_adr;
+	gint delay;
+	gboolean valid;
+	GCancellable *cancellable;
+	GFile *in_file;
+	GFileInputStream *gfstream;
+};
+
 static void image_animation_data_free(AnimationData *fd)
 {
 	if(!fd) return;
@@ -378,7 +395,7 @@ static void layout_image_animate_update_image(LayoutWindow *lw)
 }
 
 
-static void animation_async_ready_cb(GObject *UNUSED(source_object), GAsyncResult *res, gpointer data)
+static void animation_async_ready_cb(GObject *, GAsyncResult *res, gpointer data)
 {
 	GError *error = nullptr;
 	auto animation = static_cast<AnimationData *>(data);
@@ -479,27 +496,27 @@ void layout_image_animate_toggle(LayoutWindow *lw)
  *----------------------------------------------------------------------------
  */
 
-static void li_pop_menu_zoom_in_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_zoom_in_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
 	layout_image_zoom_adjust(lw, get_zoom_increment(), FALSE);
 }
 
-static void li_pop_menu_zoom_out_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_zoom_out_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	layout_image_zoom_adjust(lw, -get_zoom_increment(), FALSE);
 }
 
-static void li_pop_menu_zoom_1_1_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_zoom_1_1_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
 	layout_image_zoom_set(lw, 1.0, FALSE);
 }
 
-static void li_pop_menu_zoom_fit_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_zoom_fit_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
@@ -531,7 +548,7 @@ static void li_pop_menu_alter_cb(GtkWidget *widget, gpointer data)
 	image_alter_orientation(lw->image, lw->image->image_fd, type);
 }
 
-static void li_pop_menu_new_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_new_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
@@ -564,21 +581,27 @@ static void li_pop_menu_copy_cb(GtkWidget *widget, gpointer data)
 		       li_pop_menu_click_parent(widget, lw));
 }
 
-static void li_pop_menu_copy_path_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_copy_path_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
 	file_util_copy_path_to_clipboard(layout_image_get_fd(lw), TRUE);
 }
 
-static void li_pop_menu_copy_path_unquoted_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_copy_path_unquoted_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
 	file_util_copy_path_to_clipboard(layout_image_get_fd(lw), FALSE);
 }
 
-static void li_pop_menu_copy_image_cb(GtkWidget *UNUSED(widget), gpointer data)
+#ifdef HAVE_GTK4
+static void li_pop_menu_copy_image_cb(GtkWidget *, gpointer data)
+{
+/* @FIXME GTK4 stub */
+}
+#else
+static void li_pop_menu_copy_image_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	ImageWindow *imd = lw->image;
@@ -588,6 +611,7 @@ static void li_pop_menu_copy_image_cb(GtkWidget *UNUSED(widget), gpointer data)
 	if (!pixbuf) return;
 	gtk_clipboard_set_image(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD), pixbuf);
 }
+#endif
 
 static void li_pop_menu_move_cb(GtkWidget *widget, gpointer data)
 {
@@ -623,49 +647,49 @@ static void li_pop_menu_move_to_trash_cb(GtkWidget *widget, gpointer data)
 			 li_pop_menu_click_parent(widget, lw));
 }
 
-static void li_pop_menu_slide_start_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_slide_start_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
 	layout_image_slideshow_start(lw);
 }
 
-static void li_pop_menu_slide_stop_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_slide_stop_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
 	layout_image_slideshow_stop(lw);
 }
 
-static void li_pop_menu_slide_pause_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_slide_pause_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
 	layout_image_slideshow_pause_toggle(lw);
 }
 
-static void li_pop_menu_full_screen_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_full_screen_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
 	layout_image_full_screen_toggle(lw);
 }
 
-static void li_pop_menu_animate_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_animate_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
 	layout_image_animate_toggle(lw);
 }
 
-static void li_pop_menu_hide_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_pop_menu_hide_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 
 	layout_tools_hide_toggle(lw);
 }
 
-static void li_set_layout_path_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_set_layout_path_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	FileData *fd;
@@ -676,7 +700,7 @@ static void li_set_layout_path_cb(GtkWidget *UNUSED(widget), gpointer data)
 	if (fd) layout_set_fd(lw, fd);
 }
 
-static void li_open_archive_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void li_open_archive_cb(GtkWidget *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	LayoutWindow *lw_new;
@@ -693,7 +717,7 @@ static void li_open_archive_cb(GtkWidget *UNUSED(widget), gpointer data)
 		}
 	else
 		{
-		warning_dialog(_("Cannot open archive file"), _("See the Log Window"), GTK_STOCK_DIALOG_WARNING, nullptr);
+		warning_dialog(_("Cannot open archive file"), _("See the Log Window"), GQ_ICON_DIALOG_WARNING, nullptr);
 		}
 }
 
@@ -710,7 +734,7 @@ static gboolean li_check_if_current_path(LayoutWindow *lw, const gchar *path)
 	return ret;
 }
 
-static void layout_image_popup_menu_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void layout_image_popup_menu_destroy_cb(GtkWidget *, gpointer data)
 {
 	auto editmenu_fd_list = static_cast<GList *>(data);
 
@@ -774,10 +798,10 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 	g_object_set_data(G_OBJECT(menu), "window_keys", nullptr);
 	g_object_set_data(G_OBJECT(menu), "accel_group", accel_group);
 
-	menu_item_add_stock(menu, _("Zoom _in"), GTK_STOCK_ZOOM_IN, G_CALLBACK(li_pop_menu_zoom_in_cb), lw);
-	menu_item_add_stock(menu, _("Zoom _out"), GTK_STOCK_ZOOM_OUT, G_CALLBACK(li_pop_menu_zoom_out_cb), lw);
-	menu_item_add_stock(menu, _("Zoom _1:1"), GTK_STOCK_ZOOM_100, G_CALLBACK(li_pop_menu_zoom_1_1_cb), lw);
-	menu_item_add_stock(menu, _("Zoom to fit"), GTK_STOCK_ZOOM_FIT, G_CALLBACK(li_pop_menu_zoom_fit_cb), lw);
+	menu_item_add_icon(menu, _("Zoom _in"), GQ_ICON_ZOOM_IN, G_CALLBACK(li_pop_menu_zoom_in_cb), lw);
+	menu_item_add_icon(menu, _("Zoom _out"), GQ_ICON_ZOOM_OUT, G_CALLBACK(li_pop_menu_zoom_out_cb), lw);
+	menu_item_add_icon(menu, _("Zoom _1:1"), GQ_ICON_ZOOM_100, G_CALLBACK(li_pop_menu_zoom_1_1_cb), lw);
+	menu_item_add_icon(menu, _("Zoom to fit"), GQ_ICON_ZOOM_FIT, G_CALLBACK(li_pop_menu_zoom_fit_cb), lw);
 	menu_item_add_divider(menu);
 
 	editmenu_fd_list = layout_image_get_fd_list(lw);
@@ -788,13 +812,13 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 	menu_item_add_divider(submenu);
 	item = submenu_add_alter(menu, G_CALLBACK(li_pop_menu_alter_cb), lw);
 
-	item = menu_item_add_stock(menu, _("View in _new window"), GTK_STOCK_NEW, G_CALLBACK(li_pop_menu_new_cb), lw);
+	item = menu_item_add_icon(menu, _("View in _new window"), GQ_ICON_NEW, G_CALLBACK(li_pop_menu_new_cb), lw);
 	if (!path || fullscreen) gtk_widget_set_sensitive(item, FALSE);
 
 	item = menu_item_add(menu, _("_Go to directory view"), G_CALLBACK(li_set_layout_path_cb), lw);
 	if (!path || li_check_if_current_path(lw, path)) gtk_widget_set_sensitive(item, FALSE);
 
-	item = menu_item_add_stock(menu, _("Open archive"), GTK_STOCK_OPEN, G_CALLBACK(li_open_archive_cb), lw);
+	item = menu_item_add_icon(menu, _("Open archive"), GQ_ICON_OPEN, G_CALLBACK(li_open_archive_cb), lw);
 	if (!path || lw->image->image_fd->format_class != FORMAT_CLASS_ARCHIVE)
 		{
 		gtk_widget_set_sensitive(item, FALSE);
@@ -802,7 +826,7 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 
 	menu_item_add_divider(menu);
 
-	item = menu_item_add_stock(menu, _("_Copy..."), GTK_STOCK_COPY, G_CALLBACK(li_pop_menu_copy_cb), lw);
+	item = menu_item_add_icon(menu, _("_Copy..."), GQ_ICON_COPY, G_CALLBACK(li_pop_menu_copy_cb), lw);
 	if (!path) gtk_widget_set_sensitive(item, FALSE);
 	item = menu_item_add(menu, _("_Move..."), G_CALLBACK(li_pop_menu_move_cb), lw);
 	if (!path) gtk_widget_set_sensitive(item, FALSE);
@@ -814,14 +838,14 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 	if (!path) gtk_widget_set_sensitive(item, FALSE);
 	menu_item_add_divider(menu);
 
-	item = menu_item_add_stock(menu,
+	item = menu_item_add_icon(menu,
 				options->file_ops.confirm_move_to_trash ? _("Move to Trash...") :
-					_("Move to Trash"), PIXBUF_INLINE_ICON_TRASH,
+					_("Move to Trash"), GQ_ICON_DELETE,
 								G_CALLBACK(li_pop_menu_move_to_trash_cb), lw);
 	if (!path) gtk_widget_set_sensitive(item, FALSE);
-	item = menu_item_add_stock(menu,
+	item = menu_item_add_icon(menu,
 				options->file_ops.confirm_delete ? _("_Delete...") :
-					_("_Delete"), "edit-delete",
+					_("_Delete"), GQ_ICON_DELETE_SHRED,
 								G_CALLBACK(li_pop_menu_delete_cb), lw);
 	if (!path) gtk_widget_set_sensitive(item, FALSE);
 	menu_item_add_divider(menu);
@@ -854,11 +878,11 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 
 	if (!fullscreen)
 		{
-		menu_item_add(menu, _("_Full screen"), G_CALLBACK(li_pop_menu_full_screen_cb), lw);
+		menu_item_add_icon(menu, _("_Full screen"), GQ_ICON_FULLSCREEN, G_CALLBACK(li_pop_menu_full_screen_cb), lw);
 		}
 	else
 		{
-		menu_item_add(menu, _("Exit _full screen"), G_CALLBACK(li_pop_menu_full_screen_cb), lw);
+		menu_item_add_icon(menu, _("Exit _full screen"), GQ_ICON_LEAVE_FULLSCREEN, G_CALLBACK(li_pop_menu_full_screen_cb), lw);
 		}
 
 	menu_item_add_check(menu, _("GIF _animation"), lw->options.animate, G_CALLBACK(li_pop_menu_animate_cb), lw);
@@ -867,6 +891,8 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 
 	item = menu_item_add_check(menu, _("Hide file _list"), lw->options.tools_hidden,
 				   G_CALLBACK(li_pop_menu_hide_cb), lw);
+
+	item = menu_item_add_check(menu, _("Hide Selectable Bars"), lw->options.selectable_toolbars_hidden, G_CALLBACK(layout_selectable_toolbars_toggle), lw);
 	if (fullscreen) gtk_widget_set_sensitive(item, FALSE);
 
 	return menu;
@@ -886,10 +912,10 @@ void layout_image_menu_popup(LayoutWindow *lw)
  *----------------------------------------------------------------------------
  */
 
-static void layout_image_dnd_receive(GtkWidget *widget, GdkDragContext *UNUSED(context),
-				     gint UNUSED(x), gint UNUSED(y),
+static void layout_image_dnd_receive(GtkWidget *widget, GdkDragContext *,
+				     gint, gint,
 				     GtkSelectionData *selection_data, guint info,
-				     guint UNUSED(time), gpointer data)
+				     guint, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	gint i;
@@ -975,9 +1001,9 @@ static void layout_image_dnd_receive(GtkWidget *widget, GdkDragContext *UNUSED(c
 		}
 }
 
-static void layout_image_dnd_get(GtkWidget *widget, GdkDragContext *UNUSED(context),
-				 GtkSelectionData *selection_data, guint UNUSED(info),
-				 guint UNUSED(time), gpointer data)
+static void layout_image_dnd_get(GtkWidget *widget, GdkDragContext *,
+				 GtkSelectionData *selection_data, guint,
+				 guint, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	FileData *fd;
@@ -1012,7 +1038,7 @@ static void layout_image_dnd_get(GtkWidget *widget, GdkDragContext *UNUSED(conte
 		}
 }
 
-static void layout_image_dnd_end(GtkWidget *UNUSED(widget), GdkDragContext *context, gpointer data)
+static void layout_image_dnd_end(GtkWidget *, GdkDragContext *context, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	if (gdk_drag_context_get_selected_action(context) == GDK_ACTION_MOVE)
@@ -1331,12 +1357,16 @@ void layout_image_set_overunderexposed(LayoutWindow *lw, gboolean overunderexpos
 	image_set_overunderexposed(lw->image, overunderexposed);
 }
 
-//gboolean layout_image_get_overunderexposed(LayoutWindow *lw)
-//{
-	//if (!layout_valid(&lw)) return FALSE;
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+gboolean layout_image_get_overunderexposed_unused(LayoutWindow *lw)
+{
+	if (!layout_valid(&lw)) return FALSE;
 
-	//return image_get_overunderexposed(lw->image);
-//}
+//	return image_get_overunderexposed(lw->image);
+	return FALSE;
+}
+#pragma GCC diagnostic pop
 
 void layout_image_set_ignore_alpha(LayoutWindow *lw, gboolean ignore_alpha)
 {
@@ -1347,27 +1377,29 @@ void layout_image_set_ignore_alpha(LayoutWindow *lw, gboolean ignore_alpha)
 }
 
 /* stereo */
-/*
-gint layout_image_stereo_get(LayoutWindow *lw)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+gint layout_image_stereo_get_unused(LayoutWindow *lw)
 {
 	if (!layout_valid(&lw)) return 0;
 
-	return image_stereo_get(lw->image);
+//	return image_stereo_get(lw->image);
+	return 0;
 }
 
-void layout_image_stereo_set(LayoutWindow *lw, gint stereo_mode)
+void layout_image_stereo_set_unused(LayoutWindow *lw, gint stereo_mode)
 {
 	if (!layout_valid(&lw)) return;
 
 	image_stereo_set(lw->image, stereo_mode);
 }
-void layout_image_stereo_swap(LayoutWindow *lw)
+void layout_image_stereo_swap_unused(LayoutWindow *lw)
 {
 	if (!layout_valid(&lw)) return;
 
-	image_stereo_swap(lw->image);
+//	image_stereo_swap(lw->image);
 }
-*/
+#pragma GCC diagnostic pop
 
 gint layout_image_stereo_pixbuf_get(LayoutWindow *lw)
 {
@@ -1390,12 +1422,15 @@ const gchar *layout_image_get_path(LayoutWindow *lw)
 	return image_get_path(lw->image);
 }
 
-//const gchar *layout_image_get_name(LayoutWindow *lw)
-//{
-	//if (!layout_valid(&lw)) return NULL;
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+const gchar *layout_image_get_name_unused(LayoutWindow *lw)
+{
+	if (!layout_valid(&lw)) return NULL;
 
-	//return image_get_name(lw->image);
-//}
+	return image_get_name(lw->image);
+}
+#pragma GCC diagnostic pop
 
 FileData *layout_image_get_fd(LayoutWindow *lw)
 {
@@ -1449,8 +1484,7 @@ void layout_image_set_with_ahead(LayoutWindow *lw, FileData *fd, FileData *read_
 {
 	if (!layout_valid(&lw)) return;
 
-/*
-This should be handled at the caller: in vflist_select_image
+/** @FIXME This should be handled at the caller: in vflist_select_image
 	if (path)
 		{
 		const gchar *old_path;
@@ -1880,7 +1914,7 @@ static void layout_image_button_cb(ImageWindow *imd, GdkEventButton *event, gpoi
 					}
 				else
 					{
-					warning_dialog(_("Cannot open archive file"), _("See the Log Window"), GTK_STOCK_DIALOG_WARNING, nullptr);
+					warning_dialog(_("Cannot open archive file"), _("See the Log Window"), GQ_ICON_DIALOG_WARNING, nullptr);
 					}
 				}
 			else if (options->image_l_click_video && options->image_l_click_video_editor && imd-> image_fd && imd->image_fd->format_class == FORMAT_CLASS_VIDEO)
@@ -2133,7 +2167,7 @@ void layout_status_update_pixel_cb(PixbufRenderer *pr, gpointer data)
  *----------------------------------------------------------------------------
  */
 
-static void layout_image_update_cb(ImageWindow *UNUSED(imd), gpointer data)
+static void layout_image_update_cb(ImageWindow *, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	layout_status_update_image(lw);
@@ -2216,7 +2250,6 @@ void layout_image_activate(LayoutWindow *lw, gint i, gboolean force)
 
 	if (fd)
 		{
-//		layout_list_sync_path(lw, path);
 		layout_set_fd(lw, fd);
 		}
 	layout_status_update_image(lw);
@@ -2327,16 +2360,8 @@ GtkWidget *layout_image_setup_split_hv(LayoutWindow *lw, gboolean horizontal)
 	layout_image_setup_split_common(lw, 2);
 
 	/* horizontal split means vpaned and vice versa */
-	if (horizontal)
-		{
-		paned = gtk_vpaned_new();
-		DEBUG_NAME(paned);
-		}
-	else
-		{
-		paned = gtk_hpaned_new();
-		DEBUG_NAME(paned);
-		}
+	paned = gtk_paned_new(horizontal ? GTK_ORIENTATION_VERTICAL : GTK_ORIENTATION_HORIZONTAL);
+	DEBUG_NAME(paned);
 
 	gtk_paned_pack1(GTK_PANED(paned), lw->split_images[0]->widget, TRUE, TRUE);
 	gtk_paned_pack2(GTK_PANED(paned), lw->split_images[1]->widget, TRUE, TRUE);
@@ -2364,9 +2389,9 @@ static GtkWidget *layout_image_setup_split_triple(LayoutWindow *lw)
 
 	gtk_widget_get_allocation(lw->utility_paned, &allocation);
 
-	hpaned1 = gtk_hpaned_new();
+	hpaned1 = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
 	DEBUG_NAME(hpaned1);
-	hpaned2 = gtk_hpaned_new();
+	hpaned2 = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
 	DEBUG_NAME(hpaned2);
 
 	if (lw->bar && gtk_widget_get_visible(lw->bar))
@@ -2410,11 +2435,11 @@ GtkWidget *layout_image_setup_split_quad(LayoutWindow *lw)
 
 	layout_image_setup_split_common(lw, 4);
 
-	hpaned = gtk_hpaned_new();
+	hpaned = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
 	DEBUG_NAME(hpaned);
-	vpaned1 = gtk_vpaned_new();
+	vpaned1 = gtk_paned_new(GTK_ORIENTATION_VERTICAL);
 	DEBUG_NAME(vpaned1);
-	vpaned2 = gtk_vpaned_new();
+	vpaned2 = gtk_paned_new(GTK_ORIENTATION_VERTICAL);
 	DEBUG_NAME(vpaned2);
 
 	gtk_paned_pack1(GTK_PANED(vpaned1), lw->split_images[0]->widget, TRUE, TRUE);
