@@ -31,10 +31,17 @@ gchar *sort_type_get_text(SortType method);
 GtkWidget *submenu_add_sort(GtkWidget *menu, GCallback func, gpointer data,
 			    gboolean include_none, gboolean include_path,
 			    gboolean show_current, SortType type);
-
+GtkWidget *submenu_add_dir_sort(GtkWidget *menu, GCallback func, gpointer data,
+			    gboolean include_none, gboolean include_path,
+			    gboolean show_current, SortType type);
+GtkWidget *submenu_add_zoom(GtkWidget *menu, GCallback func, gpointer data,
+			    gboolean include_none, gboolean include_path,
+			    gboolean show_current, ZoomMode mode);
 gchar *alter_type_get_text(AlterType type);
 GtkWidget *submenu_add_alter(GtkWidget *menu, GCallback func, gpointer data);
 
-
+GtkWidget *submenu_add_collections(GtkWidget *menu, GtkWidget **menu_item,
+										GCallback func, gpointer data);
+void pop_menu_collections(GList *selection_list, gpointer data);
 #endif
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
