@@ -21,18 +21,30 @@
 #ifndef MISC_H
 #define MISC_H
 
-gdouble get_zoom_increment();
-gchar *utf8_validate_or_convert(const gchar *text);
-gint utf8_compare(const gchar *s1, const gchar *s2, gboolean case_sensitive);
-gchar *expand_tilde(const gchar *filename);
-int runcmd(const gchar *cmd);
-gchar *decode_geo_parameters(const gchar *input_text);
-gint date_get_first_day_of_week();
-gchar *date_get_abbreviated_day_name(gint day);
+struct FileData;
+
+const gchar *gq_gtk_entry_get_text(GtkEntry *entry);
 gchar *convert_rating_to_stars(gint rating);
+gchar *date_get_abbreviated_day_name(gint day);
+gchar *decode_geo_parameters(const gchar *input_text);
+gchar *expand_tilde(const gchar *filename);
 gchar *get_symbolic_link(const gchar *path_utf8);
+gchar *utf8_validate_or_convert(const gchar *text);
+gdouble get_zoom_increment();
+gint date_get_first_day_of_week();
 gint get_cpu_cores();
-void tree_path_free_wrapper(void *data, void *useradata);
+gint utf8_compare(const gchar *s1, const gchar *s2, gboolean case_sensitive);
+int runcmd(const gchar *cmd);
+void gq_gtk_entry_set_text(GtkEntry *entry, const gchar *text);
+void gq_gtk_grid_attach_default(GtkGrid *grid, GtkWidget *child, guint left_attach, guint right_attach, guint top_attach, guint bottom_attach);
+void gq_gtk_grid_attach(GtkGrid *grid, GtkWidget *child, guint left_attach, guint right_attach, guint top_attach, guint bottom_attach, GtkAttachOptions, GtkAttachOptions, guint, guint);
+
+#ifdef HAVE_GTK4
+void convert_gdkcolor_to_gdkrgba(gpointer gdk_color, GdkRGBA *gdk_rgba);
+#else
+void convert_gdkcolor_to_gdkrgba(gpointer gdk_color, GdkRGBA *gdk_rgba);
+#endif
+
 gchar *open_archive(FileData *fd);
 #endif /* MISC_H */
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
