@@ -21,7 +21,7 @@
 
 #include "pan-folder.h"
 
-#include <math.h>
+#include <cmath>
 
 #include "pan-item.h"
 #include "pan-util.h"
@@ -239,8 +239,8 @@ static FlowerGroup *pan_flower_group(PanWindow *pw, FileData *dir_fd, gint x, gi
 	if (!filelist_read(dir_fd, &f, &d)) return nullptr;
 	if (!f && !d) return nullptr;
 
-	f = filelist_sort(f, SORT_NAME, TRUE);
-	d = filelist_sort(d, SORT_NAME, TRUE);
+	f = filelist_sort(f, SORT_NAME, TRUE, TRUE);
+	d = filelist_sort(d, SORT_NAME, TRUE, TRUE);
 
 	pan_filter_fd_list(&f, pw->filter_ui->filter_elements, pw->filter_ui->filter_classes);
 
@@ -305,7 +305,7 @@ static FlowerGroup *pan_flower_group(PanWindow *pw, FileData *dir_fd, gint x, gi
 
 	group->width = pi_box->width;
 	group->height = pi_box->y + pi_box->height;
-	group->diameter = static_cast<gint>(sqrt(group->width * group->width + group->height * group->height));
+	group->diameter = static_cast<gint>(hypot(group->width, group->height));
 
 	group->children = nullptr;
 
@@ -327,18 +327,7 @@ static FlowerGroup *pan_flower_group(PanWindow *pw, FileData *dir_fd, gint x, gi
 
 	if (!f && !group->children)
 		{
-		work = group->items;
-		while (work)
-			{
-			PanItem *pi;
-
-			pi = static_cast<PanItem *>(work->data);
-			work = work->next;
-
-			pan_item_free(pi);
-			}
-
-		g_list_free(group->items);
+		g_list_free_full(group->items, reinterpret_cast<GDestroyNotify>(pan_item_free));
 		g_free(group);
 		group = nullptr;
 		}
@@ -385,8 +374,8 @@ static void pan_folder_tree_path(PanWindow *pw, FileData *dir_fd,
 	if (!filelist_read(dir_fd, &f, &d)) return;
 	if (!f && !d) return;
 
-	f = filelist_sort(f, SORT_NAME, TRUE);
-	d = filelist_sort(d, SORT_NAME, TRUE);
+	f = filelist_sort(f, SORT_NAME, TRUE, TRUE);
+	d = filelist_sort(d, SORT_NAME, TRUE, TRUE);
 
 	pan_filter_fd_list(&f, pw->filter_ui->filter_elements, pw->filter_ui->filter_classes);
 
