@@ -41,7 +41,7 @@ time_t pan_date_to_time(gint year, gint month, gint day);
 
 gboolean pan_is_link_loop(const gchar *s);
 gboolean pan_is_ignored(const gchar *s, gboolean ignore_symlinks);
-GList *pan_list_tree(FileData *dir_fd, SortType sort, gboolean ascend,
+GList *pan_list_tree(FileData *dir_fd, SortType sort, gboolean ascend, gboolean case_sensitive,
 		     gboolean ignore_symlinks);
 
 #endif
