@@ -25,29 +25,27 @@
 #include "main.h"
 #include "pan-types.h"
 
-typedef enum {
+enum PanViewFilterMode {
 	PAN_VIEW_FILTER_REQUIRE,
 	PAN_VIEW_FILTER_EXCLUDE,
 	PAN_VIEW_FILTER_INCLUDE,
 	PAN_VIEW_FILTER_GROUP
-} PanViewFilterMode;
+};
 
-typedef struct _PanViewFilterElement PanViewFilterElement;
-struct _PanViewFilterElement
+struct PanViewFilterElement
 {
 	PanViewFilterMode mode;
 	gchar *keyword;
 	GRegex *kw_regex;
 };
 
-typedef struct _PanFilterCallbackState PanFilterCallbackState;
-struct _PanFilterCallbackState
+struct PanFilterCallbackState
 {
 	PanWindow *pw;
 	GList *filter_element;
 };
 
-struct _PanViewFilterUi
+struct PanViewFilterUi
 {
 	GtkWidget *filter_box;
 	GtkWidget *filter_entry;
@@ -62,8 +60,6 @@ struct _PanViewFilterUi
 	gint filter_classes;
 };
 
-void pan_filter_toggle_visible(PanWindow *pw, gboolean enable);
-void pan_filter_activate(PanWindow *pw);
 void pan_filter_activate_cb(const gchar *text, gpointer data);
 void pan_filter_toggle_cb(GtkWidget *button, gpointer data);
 void pan_filter_toggle_button_cb(GtkWidget *button, gpointer data);
