@@ -19,9 +19,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <stdlib.h>
-#include <string.h>
-#include <math.h>
+#include <cmath>
+#include <cstdlib>
+#include <cstring>
 
 #include "main.h"
 #include "pixbuf-renderer.h"
@@ -143,12 +143,12 @@ static void pr_stereo_temp_disable(PixbufRenderer *pr, gboolean disable);
  *-------------------------------------------------------------------
  */
 
-static void pixbuf_renderer_class_init_wrapper(void *g_class, void *UNUSED(class_data))
+static void pixbuf_renderer_class_init_wrapper(void *g_class, void *)
 {
 	pixbuf_renderer_class_init(static_cast<PixbufRendererClass *>(g_class));
 }
 
-static void pixbuf_renderer_init_wrapper(PixbufRenderer *pr, void *UNUSED(class_data))
+static void pixbuf_renderer_init_wrapper(PixbufRenderer *pr, void *)
 {
 	pixbuf_renderer_init(pr);
 }
@@ -174,7 +174,7 @@ GType pixbuf_renderer_get_type()
 			};
 
 		pixbuf_renderer_type = g_type_register_static(GTK_TYPE_EVENT_BOX, "PixbufRenderer",
-							      &pixbuf_renderer_info, GTypeFlags(0));
+							      &pixbuf_renderer_info, static_cast<GTypeFlags>(0));
 		}
 
 	return pixbuf_renderer_type;
@@ -405,14 +405,6 @@ static void pixbuf_renderer_class_init(PixbufRendererClass *renderer_class)
 
 static RendererFuncs *pr_backend_renderer_new(PixbufRenderer *pr)
 {
-	//~ if (options->image.use_clutter_renderer && !options->disable_gpu)
-		//~ {
-//~ #ifdef HAVE_CLUTTER
-		//~ return renderer_clutter_new(pr);
-//~ #else
-		//~ log_printf("Warning: Geeqie is built without clutter renderer support");
-//~ #endif
-		//~ }
 	return renderer_tiles_new(pr);
 }
 
@@ -525,7 +517,6 @@ static void pixbuf_renderer_set_property(GObject *object, guint prop_id,
 			pr->complete = g_value_get_boolean(value);
 			break;
 		case PROP_CACHE_SIZE_DISPLAY:
-//			pr->tile_cache_max = g_value_get_uint(value);
 			break;
 		case PROP_CACHE_SIZE_TILES:
 			pr->source_tiles_cache_size = g_value_get_uint(value);
@@ -591,7 +582,6 @@ static void pixbuf_renderer_get_property(GObject *object, guint prop_id,
 			g_value_set_boolean(value, pr->complete);
 			break;
 		case PROP_CACHE_SIZE_DISPLAY:
-//			g_value_set_uint(value, pr->tile_cache_max);
 			break;
 		case PROP_CACHE_SIZE_TILES:
 			g_value_set_uint(value, pr->source_tiles_cache_size);
@@ -630,16 +620,19 @@ static void pixbuf_renderer_get_property(GObject *object, guint prop_id,
 static void widget_set_cursor(GtkWidget *widget, gint icon)
 {
 	GdkCursor *cursor;
+	GdkDisplay *display;
 
 	if (!gtk_widget_get_window(widget)) return;
 
+	display = gdk_display_get_default();
+
 	if (icon == -1)
 		{
 		cursor = nullptr;
 		}
 	else
 		{
-		cursor = gdk_cursor_new(static_cast<GdkCursorType>(icon));
+		cursor = gdk_cursor_new_for_display(display, static_cast<GdkCursorType>(icon));
 		}
 
 	gdk_window_set_cursor(gtk_widget_get_window(widget), cursor);
@@ -728,12 +721,15 @@ void pixbuf_renderer_set_parent(PixbufRenderer *pr, GtkWindow *window)
 	pr->parent_window = GTK_WIDGET(window);
 }
 
-//GtkWindow *pixbuf_renderer_get_parent(PixbufRenderer *pr)
-//{
-	//g_return_val_if_fail(IS_PIXBUF_RENDERER(pr), NULL);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+GtkWindow *pixbuf_renderer_get_parent_unused(PixbufRenderer *pr)
+{
+	g_return_val_if_fail(IS_PIXBUF_RENDERER(pr), NULL);
 
-	//return GTK_WINDOW(pr->parent_window);
-//}
+	return GTK_WINDOW(pr->parent_window);
+}
+#pragma GCC diagnostic pop
 
 
 /*
@@ -886,12 +882,7 @@ static void pr_scroller_start(PixbufRenderer *pr, gint x, gint y)
 		gint w, h;
 
 #ifdef GQ_BUILD
-		gchar *resource_path;
-
-		resource_path = g_build_filename(GQ_RESOURCE_PATH_ICONS, PIXBUF_INLINE_SCROLLER ".png", NULL);
-
-		pixbuf = gdk_pixbuf_new_from_resource(resource_path, nullptr);
-		g_free(resource_path);
+		pixbuf = gdk_pixbuf_new_from_resource(GQ_RESOURCE_PATH_ICONS "/" PIXBUF_INLINE_SCROLLER ".png", nullptr);
 #else
 		pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8, 32, 32);
 		gdk_pixbuf_fill(pixbuf, 0x000000ff);
@@ -927,7 +918,7 @@ static void pr_scroller_stop(PixbufRenderer *pr)
  *-------------------------------------------------------------------
  */
 
-void pixbuf_renderer_set_color(PixbufRenderer *pr, GdkColor *color)
+void pixbuf_renderer_set_color(PixbufRenderer *pr, GdkRGBA *color)
 {
 	g_return_if_fail(IS_PIXBUF_RENDERER(pr));
 
@@ -964,20 +955,7 @@ static void pr_source_tile_free(SourceTile *st)
 
 static void pr_source_tile_free_all(PixbufRenderer *pr)
 {
-	GList *work;
-
-	work = pr->source_tiles;
-	while (work)
-		{
-		SourceTile *st;
-
-		st = static_cast<SourceTile *>(work->data);
-		work = work->next;
-
-		pr_source_tile_free(st);
-		}
-
-	g_list_free(pr->source_tiles);
+	g_list_free_full(pr->source_tiles, reinterpret_cast<GDestroyNotify>(pr_source_tile_free));
 	pr->source_tiles = nullptr;
 }
 
@@ -993,19 +971,15 @@ static gboolean pr_source_tile_visible(PixbufRenderer *pr, SourceTile *st)
 
 	if (!st) return FALSE;
 
-//	x1 = ROUND_DOWN(pr->x_scroll, pr->tile_width);
-//	y1 = ROUND_DOWN(pr->y_scroll, pr->tile_height);
-//	x2 = ROUND_UP(pr->x_scroll + pr->vis_width, pr->tile_width);
-//	y2 = ROUND_UP(pr->y_scroll + pr->vis_height, pr->tile_height);
 	x1 = pr->x_scroll;
 	y1 = pr->y_scroll;
 	x2 = pr->x_scroll + pr->vis_width;
 	y2 = pr->y_scroll + pr->vis_height;
 
-	return !(static_cast<gdouble>(st->x) * pr->scale > static_cast<gdouble>(x2) ||
-		 static_cast<gdouble>(st->x + pr->source_tile_width) * pr->scale < static_cast<gdouble>(x1) ||
-		 static_cast<gdouble>(st->y) * pr->scale > static_cast<gdouble>(y2) ||
-		 static_cast<gdouble>(st->y + pr->source_tile_height) * pr->scale < static_cast<gdouble>(y1));
+	return static_cast<gdouble>(st->x) * pr->scale <= static_cast<gdouble>(x2) &&
+		 static_cast<gdouble>(st->x + pr->source_tile_width) * pr->scale >= static_cast<gdouble>(x1) &&
+		 static_cast<gdouble>(st->y) * pr->scale <= static_cast<gdouble>(y2) &&
+		 static_cast<gdouble>(st->y + pr->source_tile_height) * pr->scale >= static_cast<gdouble>(y1);
 }
 
 static SourceTile *pr_source_tile_new(PixbufRenderer *pr, gint x, gint y)
@@ -1433,7 +1407,6 @@ void pr_tile_coords_map_orientation(gint orientation,
 			/* The other values are out of range */
 			break;
 		}
-//	log_printf("tile coord y:%f, ih:%d, th:%f ry:%f\n", tile_y, image_h, tile_h, *res_x);
 }
 
 void pr_tile_region_map_orientation(gint orientation,
@@ -1496,7 +1469,6 @@ void pr_tile_region_map_orientation(gint orientation,
 			/* The other values are out of range */
 			break;
 		}
-//	log_printf("inside y:%d, th:%d, ah:%d ry:%d\n", area_y, tile_h, area_h, *res_x);
 }
 
 void pr_coords_map_orientation_reverse(gint orientation,
@@ -1942,7 +1914,7 @@ static void pr_size_sync(PixbufRenderer *pr, gint new_width, gint new_height)
 	pr_update_signal(pr);
 }
 
-static void pr_size_cb(GtkWidget *UNUSED(widget), GtkAllocation *allocation, gpointer data)
+static void pr_size_cb(GtkWidget *, GtkAllocation *allocation, gpointer data)
 {
 	auto pr = static_cast<PixbufRenderer *>(data);
 
@@ -2030,7 +2002,7 @@ void pixbuf_renderer_set_scroll_center(PixbufRenderer *pr, gdouble x, gdouble y)
  *-------------------------------------------------------------------
  */
 
-static gboolean pr_mouse_motion_cb(GtkWidget *widget, GdkEventMotion *event, gpointer UNUSED(data))
+static gboolean pr_mouse_motion_cb(GtkWidget *widget, GdkEventMotion *event, gpointer)
 {
 	PixbufRenderer *pr;
 	gint accel;
@@ -2099,7 +2071,7 @@ static gboolean pr_mouse_motion_cb(GtkWidget *widget, GdkEventMotion *event, gpo
 	return FALSE;
 }
 
-static gboolean pr_leave_notify_cb(GtkWidget *widget, GdkEventCrossing *UNUSED(cevent), gpointer UNUSED(data))
+static gboolean pr_leave_notify_cb(GtkWidget *widget, GdkEventCrossing *, gpointer)
 {
 	PixbufRenderer *pr;
 
@@ -2111,7 +2083,7 @@ static gboolean pr_leave_notify_cb(GtkWidget *widget, GdkEventCrossing *UNUSED(c
 	return FALSE;
 }
 
-static gboolean pr_mouse_press_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer UNUSED(data))
+static gboolean pr_mouse_press_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer)
 {
 	PixbufRenderer *pr;
 	GtkWidget *parent;
@@ -2151,7 +2123,7 @@ static gboolean pr_mouse_press_cb(GtkWidget *widget, GdkEventButton *bevent, gpo
 	return FALSE;
 }
 
-static gboolean pr_mouse_release_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer UNUSED(data))
+static gboolean pr_mouse_release_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer)
 {
 	PixbufRenderer *pr;
 
@@ -2187,7 +2159,7 @@ static gboolean pr_mouse_release_cb(GtkWidget *widget, GdkEventButton *bevent, g
 	return FALSE;
 }
 
-static gboolean pr_mouse_leave_cb(GtkWidget *widget, GdkEventCrossing *UNUSED(event), gpointer UNUSED(data))
+static gboolean pr_mouse_leave_cb(GtkWidget *widget, GdkEventCrossing *, gpointer)
 {
 	PixbufRenderer *pr;
 
@@ -2204,7 +2176,7 @@ static gboolean pr_mouse_leave_cb(GtkWidget *widget, GdkEventCrossing *UNUSED(ev
 	return FALSE;
 }
 
-static void pr_mouse_drag_cb(GtkWidget *widget, GdkDragContext *UNUSED(context), gpointer UNUSED(data))
+static void pr_mouse_drag_cb(GtkWidget *widget, GdkDragContext *, gpointer)
 {
 	PixbufRenderer *pr;
 
@@ -2545,11 +2517,14 @@ void pixbuf_renderer_set_orientation(PixbufRenderer *pr, gint orientation)
 	pr_zoom_sync(pr, pr->zoom, PR_ZOOM_FORCE, 0, 0);
 }
 
-//gint pixbuf_renderer_get_orientation(PixbufRenderer *pr)
-//{
-	//if (!pr) return 1;
-	//return pr->orientation;
-//}
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+gint pixbuf_renderer_get_orientation_unused(PixbufRenderer *pr)
+{
+	if (!pr) return 1;
+	return pr->orientation;
+}
+#pragma GCC diagnostic pop
 
 void pixbuf_renderer_set_stereo_data(PixbufRenderer *pr, StereoPixbufData stereo_data)
 {
@@ -2985,28 +2960,31 @@ gboolean pixbuf_renderer_get_visible_rect(PixbufRenderer *pr, GdkRectangle *rect
 	return TRUE;
 }
 
-//gboolean pixbuf_renderer_get_virtual_rect(PixbufRenderer *pr, GdkRectangle *rect)
-//{
-	//g_return_val_if_fail(IS_PIXBUF_RENDERER(pr), FALSE);
-	//g_return_val_if_fail(rect != NULL, FALSE);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+gboolean pixbuf_renderer_get_virtual_rect_unused(PixbufRenderer *pr, GdkRectangle *rect)
+{
+	g_return_val_if_fail(IS_PIXBUF_RENDERER(pr), FALSE);
+	g_return_val_if_fail(rect != NULL, FALSE);
 
-	//if ((!pr->pixbuf && !pr->source_tiles_enabled))
-		//{
-		//rect->x = 0;
-		//rect->y = 0;
-		//rect->width = 0;
-		//rect->height = 0;
-		//return FALSE;
-		//}
+	if ((!pr->pixbuf && !pr->source_tiles_enabled))
+		{
+		rect->x = 0;
+		rect->y = 0;
+		rect->width = 0;
+		rect->height = 0;
+		return FALSE;
+		}
 
-	//rect->x = pr->x_scroll;
-	//rect->y = pr->y_scroll;
-	//rect->width = pr->vis_width;
-	//rect->height = pr->vis_height;
-	//return TRUE;
-//}
+	rect->x = pr->x_scroll;
+	rect->y = pr->y_scroll;
+	rect->width = pr->vis_width;
+	rect->height = pr->vis_height;
+	return TRUE;
+}
+#pragma GCC diagnostic pop
 
-void pixbuf_renderer_set_size_early(PixbufRenderer *UNUSED(pr), guint UNUSED(width), guint UNUSED(height))
+void pixbuf_renderer_set_size_early(PixbufRenderer *, guint, guint)
 {
 #if 0
 	/** @FIXME this function does not consider the image orientation,
@@ -3019,12 +2997,6 @@ void pixbuf_renderer_set_size_early(PixbufRenderer *UNUSED(pr), guint UNUSED(wid
 	pr->image_height = height;
 
 	pr_zoom_clamp(pr, zoom, PR_ZOOM_FORCE, NULL);
-
-	//w = width;
-	//h = height;
-
-	//pr->width = width;
-	//pr->height = height;
 #endif
 }
 
