@@ -21,10 +21,12 @@
 
 #include "main.h"
 #include "pixbuf-util.h"
+
 #include "exif.h"
+#include "filedata.h"
 #include "ui-fileops.h"
 
-#include <math.h>
+#include <cmath>
 
 
 /*
@@ -58,33 +60,36 @@ gboolean pixbuf_to_file_as_png(GdkPixbuf *pixbuf, const gchar *filename)
  *-----------------------------------------------------------------------------
  */
 
-//gboolean pixbuf_to_file_as_jpg(GdkPixbuf *pixbuf, const gchar *filename, gint quality)
-//{
-	//GError *error = NULL;
-	//gchar *qbuf;
-	//gboolean ret;
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+gboolean pixbuf_to_file_as_jpg_unused(GdkPixbuf *pixbuf, const gchar *filename, gint quality)
+{
+	GError *error = NULL;
+	gchar *qbuf;
+	gboolean ret;
 
-	//if (!pixbuf || !filename) return FALSE;
+	if (!pixbuf || !filename) return FALSE;
 
-	//if (quality == -1) quality = 75;
-	//if (quality < 1 || quality > 100)
-		//{
-		//log_printf("Jpeg not saved, invalid quality %d\n", quality);
-		//return FALSE;
-		//}
+	if (quality == -1) quality = 75;
+	if (quality < 1 || quality > 100)
+		{
+		log_printf("Jpeg not saved, invalid quality %d\n", quality);
+		return FALSE;
+		}
 
-	//qbuf = g_strdup_printf("%d", quality);
-	//ret = gdk_pixbuf_save(pixbuf, filename, "jpeg", &error, "quality", qbuf, NULL);
-	//g_free(qbuf);
+	qbuf = g_strdup_printf("%d", quality);
+	ret = gdk_pixbuf_save(pixbuf, filename, "jpeg", &error, "quality", qbuf, NULL);
+	g_free(qbuf);
 
-	//if (error)
-		//{
-		//log_printf("Error saving jpeg to %s\n%s\n", filename, error->message);
-		//g_error_free(error);
-		//}
+	if (error)
+		{
+		log_printf("Error saving jpeg to %s\n%s\n", filename, error->message);
+		g_error_free(error);
+		}
 
-	//return ret;
-//}
+	return ret;
+}
+#pragma GCC diagnostic pop
 
 /*
  *-----------------------------------------------------------------------------
@@ -99,73 +104,91 @@ struct PixbufInline
 };
 
 static PixbufInline inline_pixbuf_data[] = {
-	{ PIXBUF_INLINE_ARCHIVE,	"gq-archive-file.png" },
-	{ PIXBUF_INLINE_BROKEN,	"gq-sheet-broken.png" },
-	{ PIXBUF_INLINE_COLLECTION,	"gq-collection.png" },
-	{ PIXBUF_INLINE_ICON,	"gqview-icon.png" },
-	{ PIXBUF_INLINE_ICON_180,	"gq-icon-rotate-180.png" },
-	{ PIXBUF_INLINE_ICON_BOOK,	"gq-icon-book.png" },
-	{ PIXBUF_INLINE_ICON_CCW,	"gq-icon-rotate-counter-clockwise.png" },
-	{ PIXBUF_INLINE_ICON_CONFIG,	"gq-icon-config.png" },
-	{ PIXBUF_INLINE_ICON_CW,	"gq-icon-rotate-clockwise.png" },
-	{ PIXBUF_INLINE_ICON_DRAW_RECTANGLE,	"gq-icon-draw-rectangle.png" },
-	{ PIXBUF_INLINE_ICON_EXIF,	"gq-icon-exif.png" },
-	{ PIXBUF_INLINE_ICON_EXPOSURE,	"gq-icon-exposure.png" },
-	{ PIXBUF_INLINE_ICON_FILE_FILTER,	"gq-icon-file-filter.png" },
-	{ PIXBUF_INLINE_ICON_FLIP,	"gq-icon-flip.png" },
-	{ PIXBUF_INLINE_ICON_FLOAT,	"gq-icon-float.png" },
-	{ PIXBUF_INLINE_ICON_GRAYSCALE,	"gq-icon-grayscale.png" },
-	{ PIXBUF_INLINE_ICON_HEIF,	"gq-icon-heic.png" },
-	{ PIXBUF_INLINE_ICON_HIDETOOLS,		"gq-icon-hidetools.png" },
-	{ PIXBUF_INLINE_ICON_INFO,	"gq-icon-info.png" },
-	{ PIXBUF_INLINE_ICON_MAINTENANCE,	"gq-icon-maintenance.png" },
-	{ PIXBUF_INLINE_ICON_MARKS,	"gq-icon-marks.png" },
-	{ PIXBUF_INLINE_ICON_MIRROR,	"gq-icon-mirror.png" },
-	{ PIXBUF_INLINE_ICON_MOVE,	"gq-icon-move.png" },
-	{ PIXBUF_INLINE_ICON_ORIGINAL,	"gq-icon-original.png" },
-	{ PIXBUF_INLINE_ICON_PANORAMA,	"gq-icon-panorama.png" },
-	{ PIXBUF_INLINE_ICON_PDF,	"gq-icon-pdf.png" },
-	{ PIXBUF_INLINE_ICON_RENAME,	"gq-icon-rename.png" },
-	{ PIXBUF_INLINE_ICON_SELECT_ALL,	"gq-icon-select-all.png" },
-	{ PIXBUF_INLINE_ICON_SELECT_INVERT,	"gq-icon-select-invert.png" },
-	{ PIXBUF_INLINE_ICON_SELECT_NONE,	"gq-icon-select-none.png" },
-	{ PIXBUF_INLINE_ICON_SELECT_RECTANGLE,	"gq-icon-select-rectangle.png" },
-	{ PIXBUF_INLINE_ICON_SORT,	"gq-icon-sort.png" },
-	{ PIXBUF_INLINE_ICON_THUMB,	"gq-icon-thumb.png" },
-	{ PIXBUF_INLINE_ICON_TOOLS,		"gq-icon-tools.png" },
-	{ PIXBUF_INLINE_ICON_TRASH,	"gq-icon-trash.png" },
-	{ PIXBUF_INLINE_ICON_VIEW,	"gq-icon-view.png" },
-	{ PIXBUF_INLINE_ICON_ZOOMFILLHOR,	"gq-icon-zoomfillhor.png" },
-	{ PIXBUF_INLINE_ICON_ZOOMFILLVERT,	"gq-icon-zoomfillvert.png" },
-	{ PIXBUF_INLINE_LOGO,	"geeqie-logo.png" },
-	{ PIXBUF_INLINE_METADATA,	"gq-sheet-metadata.png" },
-	{ PIXBUF_INLINE_SCROLLER,	"gq-scroller.png" },
-	{ PIXBUF_INLINE_SPLIT_PANE_SYNC, "gq-icon-split-pane-sync.png" },
-	{ PIXBUF_INLINE_UNKNOWN,	"gq-sheet-unknown.png" },
-	{ PIXBUF_INLINE_VIDEO,	"gq-sheet-video.png" },
-	{ nullptr, nullptr }
+	{  PIXBUF_INLINE_ARCHIVE,                "gq-icon-archive-file" },
+	{  PIXBUF_INLINE_BROKEN,                 "gq-icon-broken" },
+	{  PIXBUF_INLINE_COLLECTION,             "gq-icon-collection" },
+	{  PIXBUF_INLINE_ICON_180,               "gq-icon-rotate-180" },
+	{  PIXBUF_INLINE_ICON_BOOK,              "gq-icon-book" },
+	{  PIXBUF_INLINE_ICON_CONFIG,            "gq-icon-config" },
+	{  PIXBUF_INLINE_ICON_DRAW_RECTANGLE,    "gq-icon-draw-rectangle" },
+	{  PIXBUF_INLINE_ICON_EXIF,              "gq-icon-exif" },
+	{  PIXBUF_INLINE_ICON_EXPOSURE,          "gq-icon-exposure" },
+	{  PIXBUF_INLINE_ICON_FLOAT,             "gq-icon-float" },
+	{  PIXBUF_INLINE_ICON,                   "gqview-icon" },
+	{  PIXBUF_INLINE_ICON_GRAYSCALE,         "gq-icon-grayscale" },
+	{  PIXBUF_INLINE_ICON_HEIF,              "gq-icon-heic" },
+	{  PIXBUF_INLINE_ICON_HIDETOOLS,         "gq-icon-hidetools" },
+	{  PIXBUF_INLINE_ICON_MAINTENANCE,       "gq-icon-maintenance" },
+	{  PIXBUF_INLINE_ICON_MARKS,             "gq-icon-marks" },
+	{  PIXBUF_INLINE_ICON_MOVE,              "gq-icon-move" },
+	{  PIXBUF_INLINE_ICON_ORIGINAL,          "gq-icon-original" },
+	{  PIXBUF_INLINE_ICON_PANORAMA,          "gq-icon-panorama" },
+	{  PIXBUF_INLINE_ICON_PDF,               "gq-icon-pdf" },
+	{  PIXBUF_INLINE_ICON_PROPERTIES,        "gq-icon-properties" },
+	{  PIXBUF_INLINE_ICON_RENAME,            "gq-icon-rename" },
+	{  PIXBUF_INLINE_ICON_SELECT_ALL,        "gq-icon-select-all" },
+	{  PIXBUF_INLINE_ICON_SELECT_INVERT,     "gq-icon-select-invert" },
+	{  PIXBUF_INLINE_ICON_SELECT_NONE,       "gq-icon-select-none" },
+	{  PIXBUF_INLINE_ICON_SELECT_RECTANGLE,  "gq-icon-select-rectangle" },
+	{  PIXBUF_INLINE_ICON_SORT,              "gq-icon-sort" },
+	{  PIXBUF_INLINE_ICON_THUMB,             "gq-icon-thumb" },
+	{  PIXBUF_INLINE_ICON_TOOLS,             "gq-icon-tools" },
+	{  PIXBUF_INLINE_ICON_VIEW,              "gq-icon-view" },
+	{  PIXBUF_INLINE_ICON_ZOOMFILLHOR,       "gq-icon-zoomfillhor" },
+	{  PIXBUF_INLINE_ICON_ZOOMFILLVERT,      "gq-icon-zoomfillvert" },
+	{  PIXBUF_INLINE_LOGO,                   "geeqie-logo" },
+	{  PIXBUF_INLINE_METADATA,               "gq-icon-metadata" },
+	{  PIXBUF_INLINE_SCROLLER,               "gq-scroller" },
+	{  PIXBUF_INLINE_SPLIT_PANE_SYNC,        "gq-icon-split-pane-sync" },
+	{  PIXBUF_INLINE_UNKNOWN,                "gq-icon-unknown" },
+	{  PIXBUF_INLINE_VIDEO,                  "gq-icon-video" },
+	{  nullptr,                              nullptr }
 };
 
 GdkPixbuf *pixbuf_inline(const gchar *key)
 {
+	gboolean dark = FALSE;
+	gchar *file_name = nullptr;
+	gchar *path;
+	gchar *theme_name;
+	GdkPixbuf *icon_pixbuf;
 	GError *error = nullptr;
 	GInputStream *in_stream;
-	GdkPixbuf *icon_pixbuf;
-	gchar *path;
 	gint i;
+	GtkSettings *settings;
 
 	if (!key) return nullptr;
 
+	settings = gtk_settings_get_default();
+	g_object_get(settings, "gtk-theme-name", &theme_name, nullptr);
+	dark = g_str_has_suffix(theme_name, "dark");
+	g_free(theme_name);
+
 	i = 0;
 	while (inline_pixbuf_data[i].key)
 		{
 		if (strcmp(inline_pixbuf_data[i].key, key) == 0)
 			{
-			path = g_build_filename(GQ_RESOURCE_PATH_ICONS, inline_pixbuf_data[i].data, NULL);
+			file_name = g_strconcat(inline_pixbuf_data[i].data, dark ? "-dark" : "", ".png", nullptr);
+			path = g_build_filename(GQ_RESOURCE_PATH_ICONS, file_name, nullptr);
+			g_free(file_name);
 
 			in_stream = g_resources_open_stream(path, G_RESOURCE_LOOKUP_FLAGS_NONE, &error);
 			g_free(path);
 
+			if (error)
+				{
+				g_error_free(error);
+				error = nullptr;
+
+				file_name = g_strconcat(inline_pixbuf_data[i].data, ".png", nullptr);
+				path = g_build_filename(GQ_RESOURCE_PATH_ICONS, file_name, nullptr);
+				g_free(file_name);
+
+				in_stream = g_resources_open_stream(path, G_RESOURCE_LOOKUP_FLAGS_NONE, &error);
+				g_free(path);
+				}
+
 			if (error)
 				{
 				log_printf("warning: inline pixbuf error: %s", error->message);
@@ -696,20 +719,23 @@ void pixbuf_draw_rect_fill(GdkPixbuf *pb,
 		}
 }
 
-//void pixbuf_draw_rect(GdkPixbuf *pb,
-		      //gint x, gint y, gint w, gint h,
-		      //gint r, gint g, gint b, gint a,
-		      //gint left, gint right, gint top, gint bottom)
-//{
-	//pixbuf_draw_rect_fill(pb, x + left, y, w - left - right, top,
-			      //r, g, b ,a);
-	//pixbuf_draw_rect_fill(pb, x + w - right, y, right, h,
-			      //r, g, b ,a);
-	//pixbuf_draw_rect_fill(pb, x + left, y + h - bottom, w - left - right, bottom,
-			      //r, g, b ,a);
-	//pixbuf_draw_rect_fill(pb, x, y, left, h,
-			      //r, g, b ,a);
-//}
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+void pixbuf_draw_rect_unused(GdkPixbuf *pb,
+		      gint x, gint y, gint w, gint h,
+		      gint r, gint g, gint b, gint a,
+		      gint left, gint right, gint top, gint bottom)
+{
+	pixbuf_draw_rect_fill(pb, x + left, y, w - left - right, top,
+			      r, g, b ,a);
+	pixbuf_draw_rect_fill(pb, x + w - right, y, right, h,
+			      r, g, b ,a);
+	pixbuf_draw_rect_fill(pb, x + left, y + h - bottom, w - left - right, bottom,
+			      r, g, b ,a);
+	pixbuf_draw_rect_fill(pb, x, y, left, h,
+			      r, g, b ,a);
+}
+#pragma GCC diagnostic pop
 
 void pixbuf_set_rect_fill(GdkPixbuf *pb,
 			  gint x, gint y, gint w, gint h,
@@ -867,7 +893,7 @@ static void pixbuf_copy_font(GdkPixbuf *src, gint sx, gint sy,
 		}
 }
 
-void pixbuf_draw_layout(GdkPixbuf *pixbuf, PangoLayout *layout, GtkWidget *UNUSED(widget),
+void pixbuf_draw_layout(GdkPixbuf *pixbuf, PangoLayout *layout, GtkWidget *,
 			gint x, gint y,
 			guint8 r, guint8 g, guint8 b, guint8 a)
 {
@@ -1303,7 +1329,7 @@ static void pixbuf_draw_fade_linear(guchar *p_pix, gint prs, gboolean has_alpha,
 static void pixbuf_draw_fade_radius(guchar *p_pix, gint prs, gboolean has_alpha,
 				    gint sx, gint sy, gint border,
 				    gint x1, gint y1, gint x2, gint y2,
-				    guint8 UNUSED(r), guint8 g, guint8 b, guint8 a)
+				    guint8, guint8 g, guint8 b, guint8 a)
 {
 	guchar *pp;
 	gint p_step;
@@ -1318,7 +1344,7 @@ static void pixbuf_draw_fade_radius(guchar *p_pix, gint prs, gboolean has_alpha,
 			guint8 n;
 			gint r;
 
-			r = MIN(border, (gint)sqrt((i-sx)*(i-sx) + (j-sy)*(j-sy)));
+			r = MIN(border, (gint)hypot(i - sx, j - sy));
 			n = a - a * r / border;
 			*pp = (r * n + *pp * (256-n)) >> 8;
 			pp++;
