@@ -22,11 +22,15 @@
 #ifndef PREFERENCES_H
 #define PREFERENCES_H
 
+struct LayoutWindow;
 
-void show_config_window(void);
-void show_about_window(void);
+void show_config_window(LayoutWindow *lw);
+void show_about_window(LayoutWindow *lw);
 
-/* reusable helper functions */
+/**
+ * @headerfile config_entry_to_option
+ * reusable helper functions
+ */
 void config_entry_to_option(GtkWidget *entry, gchar **option, gchar *(*func)(const gchar *));
 
 
