@@ -22,10 +22,13 @@
 #ifndef PRINT_H
 #define PRINT_H
 
+struct FileData;
 
-/* do not free selection or list, the print window takes control of them */
+/**
+ * @headerfile print_window_new
+ * do not free selection or list, the print window takes control of them
+ */
 void print_window_new(FileData *fd, GList *selection, GList *list, GtkWidget *parent);
 
-
 #endif
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
