@@ -53,7 +53,7 @@ void write_indent(GString *str, gint indent)
 	g_string_append_printf(str, "\n%*s", indent * 4, "");
 }
 
-void write_char_option(GString *str, gint UNUSED(indent), const gchar *label, const gchar *text)
+void write_char_option(GString *str, gint, const gchar *label, const gchar *text)
 {
 	/* this is needed for overlay string, because g_markup_escape_text does not handle \n and such,
 	   ideas for improvement are welcome
@@ -99,18 +99,11 @@ gboolean read_char_option(const gchar *option, const gchar *label, const gchar *
 	return TRUE;
 }
 
-/* Since gdk_color_to_string() is only available since gtk 2.12
- * here is an equivalent stub function. */
-static gchar *color_to_string(GdkColor *color)
-{
-	return g_strdup_printf("#%04X%04X%04X", color->red, color->green, color->blue);
-}
-
-void write_color_option(GString *str, gint indent, const gchar *label, GdkColor *color)
+void write_color_option(GString *str, gint indent, const gchar *label, GdkRGBA *color)
 {
 	if (color)
 		{
-		gchar *colorstring = color_to_string(color);
+		gchar *colorstring = gdk_rgba_to_string(color);
 
 		write_char_option(str, indent, label, colorstring);
 		g_free(colorstring);
@@ -119,17 +112,45 @@ void write_color_option(GString *str, gint indent, const gchar *label, GdkColor
 		write_char_option(str, indent, label, "");
 }
 
-gboolean read_color_option(const gchar *option, const gchar *label, const gchar *value, GdkColor *color)
+/**
+ * @brief Read color option
+ * @param option
+ * @param label
+ * @param value
+ * @param color Returned RGBA value
+ * @returns
+ *
+ * The change from GdkColor to GdkRGBA requires a color format change.
+ * If the value string starts with #, it is a value stored as GdkColor,
+ * which is "#666666666666".
+ * The GdkRGBA style is "rgba(192,97,203,0)"
+ */
+gboolean read_color_option(const gchar *option, const gchar *label, const gchar *value, GdkRGBA *color)
 {
+	guint64 color_from_hex_string;
+
 	if (g_ascii_strcasecmp(option, label) != 0) return FALSE;
 	if (!color) return FALSE;
 
 	if (!*value) return FALSE;
-	gdk_color_parse(value, color);
+
+	/* Convert from GTK3 compatible GdkColor to GTK4 compatible GdkRGBA */
+	if (g_str_has_prefix(value, "#"))
+		{
+		color_from_hex_string = g_ascii_strtoll(value + 1, nullptr, 16);
+		color->red = (gdouble)((color_from_hex_string & 0xffff00000000) >> 32) / 65535;
+		color->green = (gdouble)((color_from_hex_string & 0x0000ffff0000) >> 16) / 65535;
+		color->blue = (gdouble)(color_from_hex_string & 0x00000000ffff) / 65535;
+		}
+	else
+		{
+		gdk_rgba_parse(color, value);
+		}
+
 	return TRUE;
 }
 
-void write_int_option(GString *str, gint UNUSED(indent), const gchar *label, gint n)
+void write_int_option(GString *str, gint, const gchar *label, gint n)
 {
 	g_string_append_printf(str, "%s = \"%d\" ", label, n);
 }
@@ -154,10 +175,13 @@ gboolean read_int_option(const gchar *option, const gchar *label, const gchar *v
 	return TRUE;
 }
 
-//void write_ushort_option(GString *str, gint UNUSED(indent), const gchar *label, guint16 n)
-//{
-	//g_string_append_printf(str, "%s = \"%uh\" ", label, n);
-//}
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+void write_ushort_option_unused(GString *str, gint, const gchar *label, guint16 n)
+{
+	g_string_append_printf(str, "%s = \"%uh\" ", label, n);
+}
+#pragma GCC diagnostic pop
 
 gboolean read_ushort_option(const gchar *option, const gchar *label, const gchar *value, guint16 *n)
 {
@@ -179,7 +203,7 @@ gboolean read_ushort_option(const gchar *option, const gchar *label, const gchar
 	return TRUE;
 }
 
-void write_uint_option(GString *str, gint UNUSED(indent), const gchar *label, guint n)
+void write_uint_option(GString *str, gint, const gchar *label, guint n)
 {
 	g_string_append_printf(str, "%s = \"%u\" ", label, n);
 }
@@ -225,7 +249,7 @@ gboolean read_int_option_clamp(const gchar *option, const gchar *label, const gc
 	return ret;
 }
 
-void write_int_unit_option(GString *str, gint UNUSED(indent), const gchar *label, gint n, gint subunits)
+void write_int_unit_option(GString *str, gint, const gchar *label, gint n, gint subunits)
 {
 	gint l, r;
 
@@ -274,7 +298,7 @@ gboolean read_int_unit_option(const gchar *option, const gchar *label, const gch
 	return TRUE;
 }
 
-void write_bool_option(GString *str, gint UNUSED(indent), const gchar *label, gint n)
+void write_bool_option(GString *str, gint, const gchar *label, gint n)
 {
 	g_string_append_printf(str, "%s = \"%s\" ", label, n ? "true" : "false");
 }
@@ -343,6 +367,7 @@ static void write_global_attributes(GString *outstr, gint indent)
 	WRITE_NL(); WRITE_BOOL(*options, save_dialog_window_positions);
 	WRITE_NL(); WRITE_BOOL(*options, show_window_ids);
 	WRITE_NL(); WRITE_BOOL(*options, expand_menu_toolbar);
+	WRITE_NL(); WRITE_BOOL(*options, hamburger_menu);
 
 	WRITE_NL(); WRITE_UINT(*options, log_window_lines);
 	WRITE_NL(); WRITE_BOOL(*options, log_window.timer_data);
@@ -357,9 +382,14 @@ static void write_global_attributes(GString *outstr, gint indent)
 	WRITE_NL(); WRITE_CHAR(*options, external_preview.extract);
 
 	WRITE_NL(); WRITE_BOOL(*options, with_rename);
+	WRITE_NL(); WRITE_BOOL(*options, collections_duplicates);
 	WRITE_NL(); WRITE_BOOL(*options, collections_on_top);
 	WRITE_NL(); WRITE_BOOL(*options, hide_window_in_fullscreen);
 
+	WRITE_NL(); WRITE_BOOL(*options, selectable_bars.menu_bar);
+	WRITE_NL(); WRITE_BOOL(*options, selectable_bars.status_bar);
+	WRITE_NL(); WRITE_BOOL(*options, selectable_bars.tool_bar);
+
 	/* File operations Options */
 	WRITE_NL(); WRITE_BOOL(*options, file_ops.enable_in_place_rename);
 	WRITE_NL(); WRITE_BOOL(*options, file_ops.confirm_delete);
@@ -399,7 +429,6 @@ static void write_global_attributes(GString *outstr, gint indent)
 	WRITE_NL(); WRITE_COLOR(*options, image.border_color);
 	WRITE_NL(); WRITE_COLOR(*options, image.alpha_color_1);
 	WRITE_NL(); WRITE_COLOR(*options, image.alpha_color_2);
-	//~ WRITE_NL(); WRITE_BOOL(*options, image.use_clutter_renderer);
 	WRITE_NL(); WRITE_INT(*options, image.tile_size);
 
 	/* Thumbnails Options */
@@ -414,13 +443,9 @@ static void write_global_attributes(GString *outstr, gint indent)
 	WRITE_NL(); WRITE_BOOL(*options, thumbnails.use_color_management);
 	WRITE_NL(); WRITE_BOOL(*options, thumbnails.use_ft_metadata);
 	WRITE_NL(); WRITE_INT(*options, thumbnails.collection_preview);
-// 	WRITE_NL(); WRITE_BOOL(*options, thumbnails.use_ft_metadata_small);
 
 	/* File sorting Options */
-	WRITE_NL(); WRITE_INT(*options, file_sort.method);
-	WRITE_NL(); WRITE_BOOL(*options, file_sort.ascending);
 	WRITE_NL(); WRITE_BOOL(*options, file_sort.case_sensitive);
-	WRITE_NL(); WRITE_BOOL(*options, file_sort.natural);
 
 	/* Fullscreen Options */
 	WRITE_NL(); WRITE_INT(*options, fullscreen.screen);
@@ -535,6 +560,11 @@ static void write_global_attributes(GString *outstr, gint indent)
 	/* GPU - see main.cc */
 	WRITE_NL(); WRITE_BOOL(*options, override_disable_gpu);
 	WRITE_SEPARATOR();
+
+	/* Alternate similarity algorithm */
+	WRITE_NL(); WRITE_BOOL(*options, alternate_similarity_algorithm.enabled);
+	WRITE_NL(); WRITE_BOOL(*options, alternate_similarity_algorithm.grayscale);
+	WRITE_SEPARATOR();
 }
 
 static void write_color_profile(GString *outstr, gint indent)
@@ -655,11 +685,10 @@ gboolean save_config_to_file(const gchar *utf8_path, ConfOptions *options, Layou
 		return FALSE;
 		}
 
-	outstr = g_string_new("");
-	g_string_append_printf(outstr, "<!--\n");
-	g_string_append_printf(outstr, "######################################################################\n");
+	outstr = g_string_new("<!--\n");
+	g_string_append(outstr, "######################################################################\n");
 	g_string_append_printf(outstr, "# %30s config file	  version %-10s #\n", GQ_APPNAME, VERSION);
-	g_string_append_printf(outstr, "######################################################################\n");
+	g_string_append(outstr, "######################################################################\n");
 	WRITE_SEPARATOR();
 
 	WRITE_STRING("# Note: This file is autogenerated. Options can be changed here,\n");
@@ -739,7 +768,7 @@ gboolean save_config_to_file(const gchar *utf8_path, ConfOptions *options, Layou
 	return TRUE;
 }
 
-gboolean save_default_layout_options_to_file(const gchar *utf8_path, ConfOptions *UNUSED(options), LayoutWindow *lw)
+gboolean save_default_layout_options_to_file(const gchar *utf8_path, ConfOptions *, LayoutWindow *lw)
 {
 	SecureSaveInfo *ssi;
 	gchar *rc_pathl;
@@ -755,11 +784,10 @@ gboolean save_default_layout_options_to_file(const gchar *utf8_path, ConfOptions
 		return FALSE;
 		}
 
-	outstr = g_string_new("");
-	g_string_append_printf(outstr, "<!--\n");
-	g_string_append_printf(outstr, "######################################################################\n");
+	outstr = g_string_new("<!--\n");
+	g_string_append(outstr, "######################################################################\n");
 	g_string_append_printf(outstr, "# %8s default layout file	  version %-10s #\n", GQ_APPNAME, VERSION);
-	g_string_append_printf(outstr, "######################################################################\n");
+	g_string_append(outstr, "######################################################################\n");
 	WRITE_SEPARATOR();
 
 	WRITE_STRING("# Note: This file is autogenerated. Options can be changed here,\n");
@@ -845,6 +873,7 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		if (READ_BOOL(*options, save_dialog_window_positions)) continue;
 		if (READ_BOOL(*options, show_window_ids)) continue;
 		if (READ_BOOL(*options, expand_menu_toolbar)) continue;
+		if (READ_BOOL(*options, hamburger_menu)) continue;
 
 		if (READ_INT(*options, log_window_lines)) continue;
 		if (READ_BOOL(*options, log_window.timer_data)) continue;
@@ -858,9 +887,14 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		if (READ_CHAR(*options, external_preview.select)) continue;
 		if (READ_CHAR(*options, external_preview.extract)) continue;
 
+		if (READ_BOOL(*options, collections_duplicates)) continue;
 		if (READ_BOOL(*options, collections_on_top)) continue;
 		if (READ_BOOL(*options, hide_window_in_fullscreen)) continue;
 
+		if (READ_BOOL(*options, selectable_bars.menu_bar)) continue;
+		if (READ_BOOL(*options, selectable_bars.status_bar)) continue;
+		if (READ_BOOL(*options, selectable_bars.tool_bar)) continue;
+
 		/* Properties dialog options */
 		if (READ_CHAR(*options, properties.tabs_order)) continue;
 
@@ -889,7 +923,6 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		if (READ_COLOR(*options, image.border_color)) continue;
 		if (READ_COLOR(*options, image.alpha_color_1)) continue;
 		if (READ_COLOR(*options, image.alpha_color_2)) continue;
-		//~ if (READ_BOOL(*options, image.use_clutter_renderer)) continue;
 		if (READ_INT(*options, image.tile_size)) continue;
 
 		/* Thumbnails options */
@@ -905,13 +938,9 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		if (READ_BOOL(*options, thumbnails.use_color_management)) continue;
 		if (READ_INT(*options, thumbnails.collection_preview)) continue;
 		if (READ_BOOL(*options, thumbnails.use_ft_metadata)) continue;
-// 		if (READ_BOOL(*options, thumbnails.use_ft_metadata_small)) continue;
 
 		/* File sorting options */
-		if (READ_UINT_ENUM(*options, file_sort.method)) continue;
-		if (READ_BOOL(*options, file_sort.ascending)) continue;
 		if (READ_BOOL(*options, file_sort.case_sensitive)) continue;
-		if (READ_BOOL(*options, file_sort.natural)) continue;
 
 		/* File operations *options */
 		if (READ_BOOL(*options, file_ops.enable_in_place_rename)) continue;
@@ -1028,6 +1057,10 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		/* GPU - see main.cc */
 		if (READ_BOOL(*options, override_disable_gpu)) continue;
 
+		/* Alternative similarity algorithm */
+		if (READ_BOOL(*options, alternate_similarity_algorithm.enabled)) continue;
+		if (READ_BOOL(*options, alternate_similarity_algorithm.grayscale)) continue;
+
 		/* Dummy options */
 		if (READ_DUMMY(*options, image.dither_quality, "deprecated since 2012-08-13")) continue;
 
@@ -1038,7 +1071,7 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 	return TRUE;
 }
 
-static void options_load_color_profiles(GQParserData *UNUSED(parser_data), GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
+static void options_load_color_profiles(GQParserData *, GMarkupParseContext *, const gchar *, const gchar **attribute_names, const gchar **attribute_values, gpointer, GError **)
 {
 	while (*attribute_names)
 		{
@@ -1057,7 +1090,7 @@ static void options_load_color_profiles(GQParserData *UNUSED(parser_data), GMark
 
 }
 
-static void options_load_profile(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
+static void options_load_profile(GQParserData *parser_data, GMarkupParseContext *, const gchar *, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **)
 {
 	gint i = GPOINTER_TO_INT(data);
 	if (i < 0 || i >= COLOR_PROFILE_INPUTS) return;
@@ -1076,7 +1109,7 @@ static void options_load_profile(GQParserData *parser_data, GMarkupParseContext
 
 }
 
-static void options_load_marks_tooltips(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
+static void options_load_marks_tooltips(GQParserData *parser_data, GMarkupParseContext *, const gchar *, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **)
 {
 	gint i = GPOINTER_TO_INT(data);
 	if (i < 0 || i >= FILEDATA_MARKS_SIZE) return;
@@ -1093,7 +1126,7 @@ static void options_load_marks_tooltips(GQParserData *parser_data, GMarkupParseC
 
 }
 
-static void options_load_disabled_plugins(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
+static void options_load_disabled_plugins(GQParserData *parser_data, GMarkupParseContext *, const gchar *, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **)
 {
 	gint i = GPOINTER_TO_INT(data);
 	struct {
@@ -1142,7 +1175,7 @@ static const gchar *options_get_id(const gchar **attribute_names, const gchar **
 }
 
 
-void options_parse_leaf(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **UNUSED(attribute_names), const gchar **UNUSED(attribute_values), gpointer UNUSED(data), GError **UNUSED(error))
+void options_parse_leaf(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **, const gchar **, gpointer, GError **)
 {
 	log_printf("unexpected: %s\n", element_name);
 	options_parse_func_push(parser_data, options_parse_leaf, nullptr, nullptr);
@@ -1238,7 +1271,7 @@ static void class_filter_load_filter_type(const gchar **attribute_names, const g
 		}
 }
 
-static void options_parse_class_filter(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
+static void options_parse_class_filter(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer, GError **)
 {
 	if (g_ascii_strcasecmp(element_name, "filter_type") == 0)
 		{
@@ -1266,7 +1299,7 @@ static void options_parse_disabled_plugins(GQParserData *parser_data, GMarkupPar
 		}
 }
 
-static void options_parse_filter(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
+static void options_parse_filter(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer, GError **)
 {
 	if (g_ascii_strcasecmp(element_name, "file_type") == 0)
 		{
@@ -1280,20 +1313,20 @@ static void options_parse_filter(GQParserData *parser_data, GMarkupParseContext
 		}
 }
 
-static void options_parse_filter_end(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), gpointer UNUSED(data), GError **UNUSED(error))
+static void options_parse_filter_end(GQParserData *parser_data, GMarkupParseContext *, const gchar *, gpointer, GError **)
 {
 	if (parser_data->startup) filter_add_defaults();
 	filter_rebuild();
 }
 
-static void options_parse_keyword_end(GQParserData *UNUSED(parser_data), GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), gpointer data, GError **UNUSED(error))
+static void options_parse_keyword_end(GQParserData *, GMarkupParseContext *, const gchar *, gpointer data, GError **)
 {
 	auto iter_ptr = static_cast<GtkTreeIter *>(data);
 	gtk_tree_iter_free(iter_ptr);
 }
 
 
-static void options_parse_keyword(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
+static void options_parse_keyword(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **)
 {
 	auto iter_ptr = static_cast<GtkTreeIter *>(data);
 	if (g_ascii_strcasecmp(element_name, "keyword") == 0)
@@ -1310,7 +1343,7 @@ static void options_parse_keyword(GQParserData *parser_data, GMarkupParseContext
 
 
 
-static void options_parse_keyword_tree(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
+static void options_parse_keyword_tree(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer, GError **)
 {
 	if (g_ascii_strcasecmp(element_name, "keyword") == 0)
 		{
@@ -1362,7 +1395,7 @@ static void options_parse_global(GQParserData *parser_data, GMarkupParseContext
 		}
 }
 
-static void options_parse_global_end(GQParserData *UNUSED(parser_data), GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), gpointer UNUSED(data), GError **UNUSED(error))
+static void options_parse_global_end(GQParserData *, GMarkupParseContext *, const gchar *, gpointer, GError **)
 {
 #ifndef HAVE_EXIV2
 	/* some options do not work without exiv2 */
@@ -1373,7 +1406,7 @@ static void options_parse_global_end(GQParserData *UNUSED(parser_data), GMarkupP
 #endif
 }
 
-static void options_parse_pane_exif(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
+static void options_parse_pane_exif(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **)
 {
 	auto pane = static_cast<GtkWidget *>(data);
 	if (g_ascii_strcasecmp(element_name, "entry") == 0)
@@ -1388,7 +1421,7 @@ static void options_parse_pane_exif(GQParserData *parser_data, GMarkupParseConte
 		}
 }
 
-static void options_parse_pane_keywords(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
+static void options_parse_pane_keywords(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **)
 {
 	auto pane = static_cast<GtkWidget *>(data);
 
@@ -1404,7 +1437,7 @@ static void options_parse_pane_keywords(GQParserData *parser_data, GMarkupParseC
 		}
 }
 
-static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
+static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **)
 {
 	auto bar = static_cast<GtkWidget *>(data);
 	if (g_ascii_strcasecmp(element_name, "pane_comment") == 0)
@@ -1438,7 +1471,7 @@ static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *UN
 				pane = bar_pane_gps_new_from_config(attribute_names, attribute_values);
 				bar_add(bar, pane);
 				}
-			options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
+			options_parse_func_push(parser_data, options_parse_leaf, nullptr, nullptr);
 			}
 		}
 #endif
@@ -1511,7 +1544,7 @@ static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *UN
 		}
 }
 
-static void options_parse_toolbar(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
+static void options_parse_toolbar(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	if (g_ascii_strcasecmp(element_name, "toolitem") == 0)
@@ -1531,7 +1564,7 @@ static void options_parse_toolbar(GQParserData *parser_data, GMarkupParseContext
 		}
 }
 
-static void options_parse_statusbar(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
+static void options_parse_statusbar(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	if (g_ascii_strcasecmp(element_name, "toolitem") == 0)
@@ -1551,7 +1584,7 @@ static void options_parse_statusbar(GQParserData *parser_data, GMarkupParseConte
 		}
 }
 
-static void options_parse_dialogs(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
+static void options_parse_dialogs(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer, GError **)
 {
 	if (g_ascii_strcasecmp(element_name, "window") == 0)
 		{
@@ -1565,7 +1598,7 @@ static void options_parse_dialogs(GQParserData *parser_data, GMarkupParseContext
 		}
 }
 
-static void options_parse_layout(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
+static void options_parse_layout(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
 	if (g_ascii_strcasecmp(element_name, "bar") == 0)
@@ -1606,15 +1639,13 @@ static void options_parse_layout(GQParserData *parser_data, GMarkupParseContext
 		}
 }
 
-static void options_parse_layout_end(GQParserData *UNUSED(parser_data), GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), gpointer data, GError **UNUSED(error))
+static void options_parse_layout_end(GQParserData *, GMarkupParseContext *, const gchar *, gpointer data, GError **)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
-	//~ LayoutWindow *lw = (LayoutWindow *)data;
-	//~ LayoutWindow *lw = data;
 	layout_util_sync(lw);
 }
 
-static void options_parse_toplevel(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
+static void options_parse_toplevel(GQParserData *parser_data, GMarkupParseContext *, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer, GError **)
 {
 	if (g_ascii_strcasecmp(element_name, "gq") == 0)
 		{
@@ -1739,14 +1770,13 @@ gboolean load_config_from_buf(const gchar *buf, gsize size, gboolean startup)
 {
 	GMarkupParseContext *context;
 	gboolean ret = TRUE;
-	GQParserData *parser_data;
 
-	parser_data = g_new0(GQParserData, 1);
+	auto parser_data = g_new0(GQParserData, 1);
 
 	parser_data->startup = startup;
 	options_parse_func_push(parser_data, options_parse_toplevel, nullptr, nullptr);
 
-	context = g_markup_parse_context_new(&parser, GMarkupParseFlags(0), parser_data, nullptr);
+	context = g_markup_parse_context_new(&parser, static_cast<GMarkupParseFlags>(0), parser_data, nullptr);
 
 	if (g_markup_parse_context_parse(context, buf, size, nullptr) == FALSE)
 		{
