@@ -19,9 +19,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <stdlib.h>
-#include <string.h>
-#include <math.h>
+#include <cmath>
+#include <cstdlib>
+#include <cstring>
 
 #include "main.h"
 #include "renderer-tiles.h"
@@ -204,7 +204,7 @@ static void rt_border_draw(RendererTiles *rt, gint x, gint y, gint w, gint h)
 				   pr->viewport_width, pr->viewport_height,
 				   &rx, &ry, &rw, &rh))
 			{
-			cairo_set_source_rgb(cr, static_cast<double>(pr->color.red)/65535, static_cast<double>(pr->color.green)/65535, static_cast<double>(pr->color.blue)/65535);
+			cairo_set_source_rgb(cr, static_cast<double>(pr->color.red), static_cast<double>(pr->color.green), static_cast<double>(pr->color.blue));
 			cairo_rectangle(cr, rx + rt->stereo_off_x, ry + rt->stereo_off_y, rw, rh);
 			cairo_fill(cr);
 			rt_overlay_draw(rt, rx, ry, rw, rh, nullptr);
@@ -221,7 +221,7 @@ static void rt_border_draw(RendererTiles *rt, gint x, gint y, gint w, gint h)
 				   pr->x_offset, pr->viewport_height,
 				   &rx, &ry, &rw, &rh))
 			{
-			cairo_set_source_rgb(cr, static_cast<double>(pr->color.red)/65535, static_cast<double>(pr->color.green)/65535, static_cast<double>(pr->color.blue)/65535);
+			cairo_set_source_rgb(cr, static_cast<double>(pr->color.red), static_cast<double>(pr->color.green), static_cast<double>(pr->color.blue));
 			cairo_rectangle(cr, rx + rt->stereo_off_x, ry + rt->stereo_off_y, rw, rh);
 			cairo_fill(cr);
 			rt_overlay_draw(rt, rx, ry, rw, rh, nullptr);
@@ -232,7 +232,7 @@ static void rt_border_draw(RendererTiles *rt, gint x, gint y, gint w, gint h)
 				   pr->viewport_width - pr->vis_width - pr->x_offset, pr->viewport_height,
 				   &rx, &ry, &rw, &rh))
 			{
-			cairo_set_source_rgb(cr, static_cast<double>(pr->color.red)/65535, static_cast<double>(pr->color.green)/65535, static_cast<double>(pr->color.blue)/65535);
+			cairo_set_source_rgb(cr, static_cast<double>(pr->color.red), static_cast<double>(pr->color.green), static_cast<double>(pr->color.blue));
 			cairo_rectangle(cr, rx + rt->stereo_off_x, ry + rt->stereo_off_y, rw, rh);
 			cairo_fill(cr);
 			rt_overlay_draw(rt, rx, ry, rw, rh, nullptr);
@@ -246,7 +246,7 @@ static void rt_border_draw(RendererTiles *rt, gint x, gint y, gint w, gint h)
 				   pr->vis_width, pr->y_offset,
 				   &rx, &ry, &rw, &rh))
 			{
-			cairo_set_source_rgb(cr, static_cast<double>(pr->color.red)/65535, static_cast<double>(pr->color.green)/65535, static_cast<double>(pr->color.blue)/65535);
+			cairo_set_source_rgb(cr, static_cast<double>(pr->color.red), static_cast<double>(pr->color.green), static_cast<double>(pr->color.blue));
 			cairo_rectangle(cr, rx + rt->stereo_off_x, ry + rt->stereo_off_y, rw, rh);
 			cairo_fill(cr);
 			rt_overlay_draw(rt, rx, ry, rw, rh, nullptr);
@@ -257,7 +257,7 @@ static void rt_border_draw(RendererTiles *rt, gint x, gint y, gint w, gint h)
 				   pr->vis_width, pr->viewport_height - pr->vis_height - pr->y_offset,
 				   &rx, &ry, &rw, &rh))
 			{
-			cairo_set_source_rgb(cr, static_cast<double>(pr->color.red)/65535, static_cast<double>(pr->color.green)/65535, static_cast<double>(pr->color.blue)/65535);
+			cairo_set_source_rgb(cr, static_cast<double>(pr->color.red), static_cast<double>(pr->color.green), static_cast<double>(pr->color.blue));
 			cairo_rectangle(cr, rx + rt->stereo_off_x, ry + rt->stereo_off_y, rw, rh);
 			cairo_fill(cr);
 			rt_overlay_draw(rt, rx, ry, rw, rh, nullptr);
@@ -281,9 +281,7 @@ static void rt_border_clear(RendererTiles *rt)
 
 static ImageTile *rt_tile_new(gint x, gint y, gint width, gint height)
 {
-	ImageTile *it;
-
-	it = g_new0(ImageTile, 1);
+	auto it = g_new0(ImageTile, 1);
 
 	it->x = x;
 	it->y = y;
@@ -307,20 +305,7 @@ static void rt_tile_free(ImageTile *it)
 
 static void rt_tile_free_all(RendererTiles *rt)
 {
-	GList *work;
-
-	work = rt->tiles;
-	while (work)
-		{
-		ImageTile *it;
-
-		it = static_cast<ImageTile *>(work->data);
-		work = work->next;
-
-		rt_tile_free(it);
-		}
-
-	g_list_free(rt->tiles);
+	g_list_free_full(rt->tiles, reinterpret_cast<GDestroyNotify>(rt_tile_free));
 	rt->tiles = nullptr;
 	rt->tile_cache_size = 0;
 }
@@ -475,12 +460,8 @@ static ImageTile *rt_tile_get(RendererTiles *rt, gint x, gint y, gboolean only_e
 	return rt_tile_add(rt, x, y);
 }
 
-static gint pixmap_calc_size(cairo_surface_t *UNUSED(surface))
+static gint pixmap_calc_size(cairo_surface_t *)
 {
-//	gint w, h, d;
-
-//	d = gdk_drawable_get_depth(pixmap);
-//	gdk_drawable_get_size(pixmap, &w, &h);
 	return options->image.tile_size * options->image.tile_size * 4 / 8;
 }
 
@@ -744,7 +725,6 @@ gint renderer_tiles_overlay_add(void *renderer, GdkPixbuf *pixbuf, gint x, gint
 {
 	auto rt = static_cast<RendererTiles *>(renderer);
 	PixbufRenderer *pr = rt->pr;
-	OverlayData *od;
 	gint id;
 
 	g_return_val_if_fail(IS_PIXBUF_RENDERER(pr), -1);
@@ -753,7 +733,7 @@ gint renderer_tiles_overlay_add(void *renderer, GdkPixbuf *pixbuf, gint x, gint
 	id = 1;
 	while (rt_overlay_find(rt, id)) id++;
 
-	od = g_new0(OverlayData, 1);
+	auto od = g_new0(OverlayData, 1);
 	od->id = id;
 	od->pixbuf = pixbuf;
 	g_object_ref(G_OBJECT(od->pixbuf));
@@ -789,9 +769,7 @@ static void rt_overlay_list_clear(RendererTiles *rt)
 {
 	while (rt->overlay_list)
 		{
-		OverlayData *od;
-
-		od = static_cast<OverlayData *>(rt->overlay_list->data);
+		auto od = static_cast<OverlayData *>(rt->overlay_list->data);
 		rt_overlay_free(rt, od);
 		}
 }
@@ -813,7 +791,7 @@ static void rt_overlay_list_reset_window(RendererTiles *rt)
 		}
 }
 
-void renderer_tiles_overlay_set(void *renderer, gint id, GdkPixbuf *pixbuf, gint UNUSED(x), gint UNUSED(y))
+void renderer_tiles_overlay_set(void *renderer, gint id, GdkPixbuf *pixbuf, gint, gint)
 {
 	auto rc = static_cast<RendererTiles *>(renderer);
 	PixbufRenderer *pr = rc->pr;
@@ -856,7 +834,7 @@ gboolean renderer_tiles_overlay_get(void *renderer, gint id, GdkPixbuf **pixbuf,
 	return TRUE;
 }
 
-static void rt_hierarchy_changed_cb(GtkWidget *UNUSED(widget), GtkWidget *UNUSED(previous_toplevel), gpointer data)
+static void rt_hierarchy_changed_cb(GtkWidget *, GtkWidget *, gpointer data)
 {
 	auto rt = static_cast<RendererTiles *>(data);
 	rt_overlay_list_reset_window(rt);
@@ -1109,7 +1087,7 @@ static void rt_tile_apply_orientation(RendererTiles *rt, gint orientation, GdkPi
 
 static gboolean rt_source_tile_render(RendererTiles *rt, ImageTile *it,
 				      gint x, gint y, gint w, gint h,
-				      gboolean UNUSED(new_data), gboolean fast)
+				      gboolean, gboolean fast)
 {
 	PixbufRenderer *pr = rt->pr;
 	GList *list;
@@ -1261,6 +1239,14 @@ static void rt_tile_get_region(gboolean has_alpha, gboolean ignore_alpha,
 	gint c;
 	guchar *psrc;
 	guchar *pdst;
+	guint32 red_1;
+	guint32 green_1;
+	guint32 blue_1;
+	guint32 red_2;
+	guint32 green_2;
+	guint32 blue_2;
+	guint32 alpha_1;
+	guint32 alpha_2;
 
 	if (!has_alpha)
 		{
@@ -1304,6 +1290,15 @@ static void rt_tile_get_region(gboolean has_alpha, gboolean ignore_alpha,
 		}
 	else
 		{
+		red_1=static_cast<guint32>(options->image.alpha_color_1.red * 255) << 16 & 0x00FF0000;
+		green_1=static_cast<guint32>(options->image.alpha_color_1.green * 255) << 8 & 0x0000FF00;
+		blue_1=static_cast<guint32>(options->image.alpha_color_1.blue * 255) & 0x000000FF;
+		red_2=static_cast<guint32>(options->image.alpha_color_2.red * 255) << 16 & 0x00FF0000;
+		green_2=static_cast<guint32>(options->image.alpha_color_2.green * 255) << 8 & 0x0000FF00;
+		blue_2=static_cast<guint32>(options->image.alpha_color_2.blue * 255) & 0x000000FF;
+		alpha_1 = red_1 + green_1 + blue_1;
+		alpha_2 = red_2 + green_2 + blue_2;
+
 		if (ignore_alpha)
 			{
 			tmppixbuf = gdk_pixbuf_add_alpha(src, FALSE, 0, 0, 0);
@@ -1318,12 +1313,8 @@ static void rt_tile_get_region(gboolean has_alpha, gboolean ignore_alpha,
 					(scale_x == 1.0 && scale_y == 1.0) ? GDK_INTERP_NEAREST : interp_type,
 					255, check_x, check_y,
 					PR_ALPHA_CHECK_SIZE,
-					((options->image.alpha_color_1.red << 8 & 0x00FF0000) +
-					(options->image.alpha_color_1.green & 0x00FF00) +
-					(options->image.alpha_color_1.blue >> 8 & 0x00FF)),
-					((options->image.alpha_color_2.red << 8 & 0x00FF0000) +
-					(options->image.alpha_color_2.green & 0x00FF00) +
-					(options->image.alpha_color_2.blue >> 8 & 0x00FF)));
+					alpha_1,
+					alpha_2);
 			g_object_unref(tmppixbuf);
 			}
 		else
@@ -1336,12 +1327,8 @@ static void rt_tile_get_region(gboolean has_alpha, gboolean ignore_alpha,
 					(scale_x == 1.0 && scale_y == 1.0) ? GDK_INTERP_NEAREST : interp_type,
 					255, check_x, check_y,
 					PR_ALPHA_CHECK_SIZE,
-					((options->image.alpha_color_1.red << 8 & 0x00FF0000) +
-					(options->image.alpha_color_1.green & 0x00FF00) +
-					(options->image.alpha_color_1.blue >> 8 & 0x00FF)),
-					((options->image.alpha_color_2.red << 8 & 0x00FF0000) +
-					(options->image.alpha_color_2.green & 0x00FF00) +
-					(options->image.alpha_color_2.blue >> 8 & 0x00FF)));
+					alpha_1,
+					alpha_2);
 			}
 		}
 }
@@ -1508,8 +1495,6 @@ static void rt_tile_expose(RendererTiles *rt, ImageTile *it,
 			   gboolean new_data, gboolean fast)
 {
 	PixbufRenderer *pr = rt->pr;
-	//~ GtkWidget *box;
-	//~ GdkWindow *window;
 	cairo_t *cr;
 
 	/* clamp to visible */
@@ -1536,9 +1521,6 @@ static void rt_tile_expose(RendererTiles *rt, ImageTile *it,
 
 	rt_tile_render(rt, it, x, y, w, h, new_data, fast);
 
-	//~ box = GTK_WIDGET(pr);
-	//~ window = gtk_widget_get_window(box);
-
 	cr = cairo_create(rt->surface);
 	cairo_set_source_surface(cr, it->surface, pr->x_offset + (it->x - rt->x_scroll) + rt->stereo_off_x, pr->y_offset + (it->y - rt->y_scroll) + rt->stereo_off_y);
 	cairo_rectangle (cr, pr->x_offset + (it->x - rt->x_scroll) + x + rt->stereo_off_x, pr->y_offset + (it->y - rt->y_scroll) + y + rt->stereo_off_y, w, h);
@@ -1846,15 +1828,13 @@ static gboolean rt_queue_to_tiles(RendererTiles *rt, gint x, gint y, gint w, gin
 					   j > rt->y_scroll + pr->vis_height)));
 			if (it)
 				{
-				QueueData *qd;
-
 				if ((render == TILE_RENDER_ALL && it->render_done != TILE_RENDER_ALL) ||
 				    (render == TILE_RENDER_AREA && it->render_todo != TILE_RENDER_ALL))
 					{
 					it->render_todo = render;
 					}
 
-				qd = g_new(QueueData, 1);
+				auto qd = g_new(QueueData, 1);
 				qd->it = it;
 				qd->new_data = new_data;
 
@@ -2063,7 +2043,7 @@ static void renderer_redraw(RendererTiles *rt, gint x, gint y, gint w, gint h,
 		 clamp, render, new_data, only_existing);
 }
 
-static void renderer_update_pixbuf(void *renderer, gboolean UNUSED(lazy))
+static void renderer_update_pixbuf(void *renderer, gboolean)
 {
 	rt_queue_clear(static_cast<RendererTiles *>(renderer));
 }
@@ -2154,7 +2134,7 @@ static gboolean rt_realize_cb(GtkWidget *widget, gpointer data)
 		rt->surface = gdk_window_create_similar_surface(gtk_widget_get_window(widget), CAIRO_CONTENT_COLOR, gtk_widget_get_allocated_width(widget), gtk_widget_get_allocated_height(widget));
 
 		cr = cairo_create(rt->surface);
-		cairo_set_source_rgb(cr, static_cast<gdouble>(rt->pr->color.red) / 65535, static_cast<gdouble>(rt->pr->color.green) / 65535, static_cast<gdouble>(rt->pr->color.blue) / 65535);
+		cairo_set_source_rgb(cr, static_cast<gdouble>(rt->pr->color.red), static_cast<gdouble>(rt->pr->color.green), static_cast<gdouble>(rt->pr->color.blue));
 		cairo_paint(cr);
 		cairo_destroy(cr);
 		}
@@ -2175,7 +2155,7 @@ static gboolean rt_size_allocate_cb(GtkWidget *widget,  GdkRectangle *allocation
 
 		cr = cairo_create(rt->surface);
 
-		cairo_set_source_rgb(cr, static_cast<gdouble>(options->image.border_color.red) / 65535, static_cast<gdouble>(options->image.border_color.green) / 65535, static_cast<gdouble>(options->image.border_color.blue) / 65535);
+		cairo_set_source_rgb(cr, static_cast<gdouble>(options->image.border_color.red), static_cast<gdouble>(options->image.border_color.green), static_cast<gdouble>(options->image.border_color.blue));
 		cairo_paint(cr);
 		cairo_set_source_surface(cr, old_surface, 0, 0);
 		cairo_paint(cr);
@@ -2188,7 +2168,7 @@ static gboolean rt_size_allocate_cb(GtkWidget *widget,  GdkRectangle *allocation
 	return FALSE;
 }
 
-static gboolean rt_draw_cb(GtkWidget *UNUSED(widget), cairo_t *cr, gpointer data)
+static gboolean rt_draw_cb(GtkWidget *, cairo_t *cr, gpointer data)
 {
 	auto rt = static_cast<RendererTiles *>(data);
 	GList *work;
@@ -2197,7 +2177,7 @@ static gboolean rt_draw_cb(GtkWidget *UNUSED(widget), cairo_t *cr, gpointer data
 	if (rt->stereo_mode & (PR_STEREO_HORIZ | PR_STEREO_VERT))
 		{
 		cairo_push_group(cr);
-		cairo_set_source_rgb(cr, static_cast<double>(rt->pr->color.red) / 65535, static_cast<double>(rt->pr->color.green) / 65535, static_cast<double>(rt->pr->color.blue) / 65535);
+		cairo_set_source_rgb(cr, static_cast<double>(rt->pr->color.red), static_cast<double>(rt->pr->color.green), static_cast<double>(rt->pr->color.blue));
 
 		if (rt->stereo_mode & PR_STEREO_HORIZ)
 			{
