@@ -19,9 +19,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <string.h>
-#include <sys/types.h>
+#include <cstring>
 #include <dirent.h>
+#include <sys/types.h>
 
 #include "main.h"
 #include "ui-tabcomp.h"
@@ -29,7 +29,6 @@
 #include "history-list.h"
 #include "misc.h"	/* expand_tilde() */
 #include "ui-fileops.h"
-#include "ui-spinner.h"
 #include "ui-utildlg.h"
 
 /* define this to enable a pop-up menu that shows possible matches
@@ -88,20 +87,10 @@ static gint tab_completion_do(TabCompData *td);
 
 static void tab_completion_free_list(TabCompData *td)
 {
-	GList *list;
-
 	g_free(td->dir_path);
 	td->dir_path = nullptr;
 
-	list = td->file_list;
-
-	while (list)
-		{
-		g_free(list->data);
-		list = list->next;
-		}
-
-	g_list_free(td->file_list);
+	g_list_free_full(td->file_list, g_free);
 	td->file_list = nullptr;
 }
 
@@ -150,7 +139,7 @@ static void tab_completion_read_dir(TabCompData *td, const gchar *path)
 	g_free(pathl);
 }
 
-static void tab_completion_destroy(GtkWidget *UNUSED(widget), gpointer data)
+static void tab_completion_destroy(GtkWidget *, gpointer data)
 {
 	auto td = static_cast<TabCompData *>(data);
 
@@ -170,7 +159,7 @@ static gchar *tab_completion_get_text(TabCompData *td)
 {
 	gchar *text;
 
-	text = g_strdup(gtk_entry_get_text(GTK_ENTRY(td->entry)));
+	text = g_strdup(gq_gtk_entry_get_text(GTK_ENTRY(td->entry)));
 
 	if (text[0] == '~')
 		{
@@ -215,7 +204,7 @@ void tab_completion_iter_menu_items(GtkWidget *widget, gpointer data)
 	child = gtk_bin_get_child(GTK_BIN(widget));
 	if (GTK_IS_LABEL(child)) {
 		const gchar *text = gtk_label_get_text(GTK_LABEL(child));
-		const gchar *entry_text = gtk_entry_get_text(GTK_ENTRY(td->entry));
+		const gchar *entry_text = gq_gtk_entry_get_text(GTK_ENTRY(td->entry));
 		const gchar *prefix = filename_from_path(entry_text);
 		guint prefix_len = strlen(prefix);
 
@@ -277,7 +266,7 @@ static void tab_completion_popup_cb(GtkWidget *widget, gpointer data)
 	if (!td) return;
 
 	buf = g_build_filename(td->dir_path, name, NULL);
-	gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
+	gq_gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
 	gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
 	g_free(buf);
 
@@ -335,7 +324,7 @@ static gint simple_sort(gconstpointer a, gconstpointer b)
 
 static gboolean tab_completion_do(TabCompData *td)
 {
-	const gchar *entry_text = gtk_entry_get_text(GTK_ENTRY(td->entry));
+	const gchar *entry_text = gq_gtk_entry_get_text(GTK_ENTRY(td->entry));
 	const gchar *entry_file;
 	gchar *entry_dir;
 	gchar *ptr;
@@ -344,7 +333,7 @@ static gboolean tab_completion_do(TabCompData *td)
 	if (entry_text[0] == '\0')
 		{
 		entry_dir = g_strdup(G_DIR_SEPARATOR_S); /** @FIXME root directory win32 */
-		gtk_entry_set_text(GTK_ENTRY(td->entry), entry_dir);
+		gq_gtk_entry_set_text(GTK_ENTRY(td->entry), entry_dir);
 		gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(entry_dir));
 		g_free(entry_dir);
 		return FALSE;
@@ -365,7 +354,7 @@ static gboolean tab_completion_do(TabCompData *td)
 		{
 		if (home_exp)
 			{
-			gtk_entry_set_text(GTK_ENTRY(td->entry), entry_dir);
+			gq_gtk_entry_set_text(GTK_ENTRY(td->entry), entry_dir);
 			gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(entry_dir));
 			}
 		g_free(entry_dir);
@@ -381,7 +370,7 @@ static gboolean tab_completion_do(TabCompData *td)
 			{
 			if (home_exp)
 				{
-				gtk_entry_set_text(GTK_ENTRY(td->entry), entry_dir);
+				gq_gtk_entry_set_text(GTK_ENTRY(td->entry), entry_dir);
 				gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(entry_dir));
 				}
 
@@ -400,7 +389,7 @@ static gboolean tab_completion_do(TabCompData *td)
 					g_free(buf);
 					buf = tmp;
 					}
-				gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
+				gq_gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
 				gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
 				g_free(buf);
 				}
@@ -419,7 +408,7 @@ static gboolean tab_completion_do(TabCompData *td)
 		else
 			{
 			gchar *buf = g_strconcat(entry_dir, G_DIR_SEPARATOR_S, NULL);
-			gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
+			gq_gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
 			gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
 			g_free(buf);
 			g_free(entry_dir);
@@ -467,7 +456,7 @@ static gboolean tab_completion_do(TabCompData *td)
 				gchar *buf;
 
 				buf = g_build_filename(entry_dir, file, NULL);
-				gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
+				gq_gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
 				gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
 				g_free(buf);
 				g_list_free(poss);
@@ -503,7 +492,7 @@ static gboolean tab_completion_do(TabCompData *td)
 					file = g_strdup(test_file);
 					file[c] = '\0';
 					buf = g_build_filename(entry_dir, file, NULL);
-					gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
+					gq_gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
 					gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
 
 #ifdef TAB_COMPLETION_ENABLE_POPUP_MENU
@@ -567,7 +556,7 @@ static gboolean tab_completion_key_pressed(GtkWidget *widget, GdkEventKey *event
 	return (stop_signal);
 }
 
-static void tab_completion_button_pressed(GtkWidget *UNUSED(widget), gpointer data)
+static void tab_completion_button_pressed(GtkWidget *, gpointer data)
 {
 	TabCompData *td;
 	auto entry = static_cast<GtkWidget *>(data);
@@ -608,23 +597,14 @@ static void tab_completion_button_size_allocate(GtkWidget *button, GtkAllocation
 static GtkWidget *tab_completion_create_complete_button(GtkWidget *entry, GtkWidget *parent)
 {
 	GtkWidget *button;
-	GtkWidget *icon;
-	GdkPixbuf *pixbuf;
 
-	button = gtk_button_new();
+	button = gtk_button_new_from_icon_name(GQ_ICON_GO_LAST, GTK_ICON_SIZE_BUTTON);
 	gtk_widget_set_can_focus(button, FALSE);
 	g_signal_connect(G_OBJECT(button), "size_allocate",
 			 G_CALLBACK(tab_completion_button_size_allocate), parent);
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(tab_completion_button_pressed), entry);
 
-	pixbuf = gdk_pixbuf_new_from_inline(-1, icon_tabcomp, FALSE, nullptr);
-	icon = gtk_image_new_from_pixbuf(pixbuf);
-	g_object_unref(pixbuf);
-
-	gtk_container_add(GTK_CONTAINER(button), icon);
-	gtk_widget_show(icon);
-
 	return button;
 }
 
@@ -649,13 +629,13 @@ GtkWidget *tab_completion_new_with_history(GtkWidget **entry, const gchar *text,
 	box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
 	combo = gtk_combo_box_text_new_with_entry();
-	gtk_box_pack_start(GTK_BOX(box), combo, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(box), combo, TRUE, TRUE, 0);
 	gtk_widget_show(combo);
 
 	combo_entry = gtk_bin_get_child(GTK_BIN(combo));
 
 	button = tab_completion_create_complete_button(combo_entry, combo);
-	gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
 	tab_completion_add_to_entry(combo_entry, enter_func, nullptr, nullptr, data);
@@ -680,7 +660,7 @@ GtkWidget *tab_completion_new_with_history(GtkWidget **entry, const gchar *text,
 
 	if (text)
 		{
-		gtk_entry_set_text(GTK_ENTRY(combo_entry), text);
+		gq_gtk_entry_set_text(GTK_ENTRY(combo_entry), text);
 		}
 	else if (n > 0)
 		{
@@ -701,7 +681,7 @@ const gchar *tab_completion_set_to_last_history(GtkWidget *entry)
 	buf = history_list_find_last_path_by_key(td->history_key);
 	if (buf)
 		{
-		gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
+		gq_gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
 		}
 
 	return buf;
@@ -750,12 +730,12 @@ GtkWidget *tab_completion_new(GtkWidget **entry, const gchar *text,
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
 	newentry = gtk_entry_new();
-	if (text) gtk_entry_set_text(GTK_ENTRY(newentry), text);
-	gtk_box_pack_start(GTK_BOX(hbox), newentry, TRUE, TRUE, 0);
+	if (text) gq_gtk_entry_set_text(GTK_ENTRY(newentry), text);
+	gq_gtk_box_pack_start(GTK_BOX(hbox), newentry, TRUE, TRUE, 0);
 	gtk_widget_show(newentry);
 
 	button = tab_completion_create_complete_button(newentry, newentry);
-	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
 	tab_completion_add_to_entry(newentry, enter_func, filter, filter_desc, data);
@@ -833,7 +813,7 @@ static void tab_completion_select_ok_cb(FileDialog *fd, gpointer data)
 {
 	auto td = static_cast<TabCompData *>(data);
 
-	gtk_entry_set_text(GTK_ENTRY(td->entry), gtk_entry_get_text(GTK_ENTRY(fd->entry)));
+	gq_gtk_entry_set_text(GTK_ENTRY(td->entry), gq_gtk_entry_get_text(GTK_ENTRY(fd->entry)));
 
 	tab_completion_select_cancel_cb(fd, data);
 
@@ -856,7 +836,7 @@ static void tab_completion_select_show(TabCompData *td)
 	title = (td->fd_title) ? td->fd_title : _("Select path");
 	td->fd = file_dialog_new(title, "select_path", td->entry,
 				 tab_completion_select_cancel_cb, td);
-	file_dialog_add_button(td->fd, GTK_STOCK_OK, nullptr,
+	file_dialog_add_button(td->fd, GQ_ICON_OK, "OK",
 				 tab_completion_select_ok_cb, TRUE);
 
 	generic_dialog_add_message(GENERIC_DIALOG(td->fd), nullptr, title, nullptr, FALSE);
@@ -878,7 +858,7 @@ static void tab_completion_select_show(TabCompData *td)
 		filter_desc = _("All files");
 		}
 
-	path = gtk_entry_get_text(GTK_ENTRY(td->entry));
+	path = gq_gtk_entry_get_text(GTK_ENTRY(td->entry));
 	if (strlen(path) == 0) path = nullptr;
 	if (td->fd_folders_only)
 		{
@@ -892,7 +872,7 @@ static void tab_completion_select_show(TabCompData *td)
 	gtk_widget_show(GENERIC_DIALOG(td->fd)->dialog);
 }
 
-static void tab_completion_select_pressed(GtkWidget *UNUSED(widget), gpointer data)
+static void tab_completion_select_pressed(GtkWidget *, gpointer data)
 {
 	auto td = static_cast<TabCompData *>(data);
 
@@ -926,7 +906,7 @@ void tab_completion_add_select_button(GtkWidget *entry, const gchar *title, gboo
 	g_signal_connect(G_OBJECT(td->fd_button), "clicked",
 			 G_CALLBACK(tab_completion_select_pressed), td);
 
-	gtk_box_pack_start(GTK_BOX(hbox), td->fd_button, FALSE, FALSE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(hbox), td->fd_button, FALSE, FALSE, 0);
 
 	gtk_widget_show(td->fd_button);
 }
