@@ -19,9 +19,11 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <string.h>
+#include <cstring>
 
 #include "main.h"
+
+#include "misc.h"
 #include "ui-tree-edit.h"
 
 /*
@@ -36,7 +38,7 @@ static void tree_edit_close(TreeEditData *ted)
 	gdk_keyboard_ungrab(GDK_CURRENT_TIME);
 	gdk_pointer_ungrab(GDK_CURRENT_TIME);
 
-	gtk_widget_destroy(ted->window);
+	g_object_unref(ted->window);
 
 	g_free(ted->old_name);
 	g_free(ted->new_name);
@@ -47,7 +49,7 @@ static void tree_edit_close(TreeEditData *ted)
 
 static void tree_edit_do(TreeEditData *ted)
 {
-	ted->new_name = g_strdup(gtk_entry_get_text(GTK_ENTRY(ted->entry)));
+	ted->new_name = g_strdup(gq_gtk_entry_get_text(GTK_ENTRY(ted->entry)));
 
 	if (strcmp(ted->new_name, ted->old_name) != 0)
 		{
@@ -61,7 +63,7 @@ static void tree_edit_do(TreeEditData *ted)
 		}
 }
 
-static gboolean tree_edit_click_end_cb(GtkWidget *UNUSED(widget), GdkEventButton *UNUSED(event), gpointer data)
+static gboolean tree_edit_click_end_cb(GtkWidget *, GdkEventButton *, gpointer data)
 {
 	auto ted = static_cast<TreeEditData *>(data);
 
@@ -71,7 +73,7 @@ static gboolean tree_edit_click_end_cb(GtkWidget *UNUSED(widget), GdkEventButton
 	return TRUE;
 }
 
-static gboolean tree_edit_click_cb(GtkWidget *UNUSED(widget), GdkEventButton *event, gpointer data)
+static gboolean tree_edit_click_cb(GtkWidget *, GdkEventButton *event, gpointer data)
 {
 	auto ted = static_cast<TreeEditData *>(data);
 	GdkWindow *window = gtk_widget_get_window(ted->window);
@@ -98,7 +100,7 @@ static gboolean tree_edit_click_cb(GtkWidget *UNUSED(widget), GdkEventButton *ev
 	return FALSE;
 }
 
-static gboolean tree_edit_key_press_cb(GtkWidget *UNUSED(widget), GdkEventKey *event, gpointer data)
+static gboolean tree_edit_key_press_cb(GtkWidget *, GdkEventKey *event, gpointer data)
 {
 	auto ted = static_cast<TreeEditData *>(data);
 
@@ -157,7 +159,7 @@ static gboolean tree_edit_by_path_idle_cb(gpointer data)
 	/* now show it */
 	gtk_widget_set_size_request(ted->window, w, h);
 	gtk_widget_realize(ted->window);
-	gtk_window_move(GTK_WINDOW(ted->window), x, y);
+	gq_gtk_window_move(GTK_WINDOW(ted->window), x, y);
 	gtk_window_resize(GTK_WINDOW(ted->window), w, h);
 	gtk_widget_show(ted->window);
 
@@ -232,9 +234,9 @@ gboolean tree_edit_by_path(GtkTreeView *tree, GtkTreePath *tpath, gint column, c
 			 G_CALLBACK(tree_edit_key_press_cb), ted);
 
 	ted->entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(ted->entry), ted->old_name);
+	gq_gtk_entry_set_text(GTK_ENTRY(ted->entry), ted->old_name);
 	gtk_editable_select_region(GTK_EDITABLE(ted->entry), 0, strlen(ted->old_name));
-	gtk_container_add(GTK_CONTAINER(ted->window), ted->entry);
+	gq_gtk_container_add(GTK_WIDGET(ted->window), ted->entry);
 	gtk_widget_show(ted->entry);
 
 	/* due to the fact that gtktreeview scrolls in an idle loop, we cannot
@@ -461,15 +463,18 @@ gboolean tree_view_move_cursor_away(GtkTreeView *widget, GtkTreeIter *iter, gboo
 	return move;
 }
 
-//gint tree_path_to_row(GtkTreePath *tpath)
-//{
-	//gint *indices;
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+gint tree_path_to_row_unused(GtkTreePath *tpath)
+{
+	gint *indices;
 
-	//indices = gtk_tree_path_get_indices(tpath);
-	//if (indices) return indices[0];
+	indices = gtk_tree_path_get_indices(tpath);
+	if (indices) return indices[0];
 
-	//return -1;
-//}
+	return -1;
+}
+#pragma GCC diagnostic pop
 
 
 /*
@@ -478,9 +483,9 @@ gboolean tree_view_move_cursor_away(GtkTreeView *widget, GtkTreeIter *iter, gboo
  *-------------------------------------------------------------------
  */
 
-void shift_color(GdkColor *src, gshort val, gint direction)
+void shift_color(GdkRGBA *src, gshort val, gint direction)
 {
-	gshort cs;
+	gdouble cs;
 
 	if (val == -1)
 		{
@@ -490,11 +495,11 @@ void shift_color(GdkColor *src, gshort val, gint direction)
 		{
 		val = CLAMP(val, 1, 100);
 		}
-	cs = 0xffff / 100 * val;
+
+	cs = 1.0 / 100 * val;
 
 	/* up or down ? */
-	if (direction < 0 ||
-	    (direction == 0 &&(static_cast<gint>(src->red) + static_cast<gint>(src->green) + static_cast<gint>(src->blue)) / 3 > 0xffff / 2))
+	if (direction < 0 || (direction == 0 &&(static_cast<gdouble>(src->red) + static_cast<gdouble>(src->green) + static_cast<gdouble>(src->blue)) / 3 > 1.0 / 2))
 		{
 		src->red = MAX(0 , src->red - cs);
 		src->green = MAX(0 , src->green - cs);
@@ -502,23 +507,12 @@ void shift_color(GdkColor *src, gshort val, gint direction)
 		}
 	else
 		{
-		src->red = MIN(0xffff, src->red + cs);
-		src->green = MIN(0xffff, src->green + cs);
-		src->blue = MIN(0xffff, src->blue + cs);
+		src->red = MIN(1.0, src->red + cs);
+		src->green = MIN(1.0, src->green + cs);
+		src->blue = MIN(1.0, src->blue + cs);
 		}
 }
 
-/* darkens or lightens a style's color for given state
- * esp. useful for alternating dark/light in (c)lists
- */
-//void style_shift_color(GtkStyle *style, GtkStateType type, gshort shift_value, gint direction)
-//{
-	//if (!style) return;
-
-	//shift_color(&style->base[type], shift_value, direction);
-	//shift_color(&style->bg[type], shift_value, direction);
-//}
-
 /*
  *-------------------------------------------------------------------
  * auto scroll by mouse position
