@@ -19,12 +19,13 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <string.h>
+#include <cstring>
 
 #include "main.h"
 #include "ui-utildlg.h"
 
 #include "filedata.h"
+#include "misc.h"
 #include "rcfile.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
@@ -122,7 +123,7 @@ void generic_dialog_close(GenericDialog *gd)
 
 	generic_dialog_save_window(actual_title, gtk_window_get_role(GTK_WINDOW(gd->dialog)), x, y, w, h);
 
-	gtk_widget_destroy(gd->dialog);
+	gq_gtk_widget_destroy(gd->dialog);
 	g_free(gd);
 	g_free(ident_string);
 	g_free(full_title);
@@ -188,7 +189,7 @@ static gboolean generic_dialog_key_press_cb(GtkWidget *widget, GdkEventKey *even
 	return FALSE;
 }
 
-static gboolean generic_dialog_delete_cb(GtkWidget *UNUSED(w), GdkEventAny *UNUSED(event), gpointer data)
+static gboolean generic_dialog_delete_cb(GtkWidget *, GdkEventAny *, gpointer data)
 {
 	auto gd = static_cast<GenericDialog *>(data);
 	gboolean auto_close;
@@ -228,19 +229,19 @@ gboolean generic_dialog_get_alternative_button_order(GtkWidget *widget)
 	return alternative_order;
 }
 
-GtkWidget *generic_dialog_add_button(GenericDialog *gd, const gchar *stock_id, const gchar *text,
+GtkWidget *generic_dialog_add_button(GenericDialog *gd, const gchar *icon_name, const gchar *text,
 				     void (*func_cb)(GenericDialog *, gpointer), gboolean is_default)
 {
 	GtkWidget *button;
 	gboolean alternative_order;
 
-	button = pref_button_new(nullptr, stock_id, text, FALSE,
+	button = pref_button_new(nullptr, icon_name, text,
 				 G_CALLBACK(generic_dialog_click_cb), gd);
 
 	gtk_widget_set_can_default(button, TRUE);
 	g_object_set_data(G_OBJECT(button), "dialog_function", reinterpret_cast<void *>(func_cb));
 
-	gtk_container_add(GTK_CONTAINER(gd->hbox), button);
+	gq_gtk_container_add(GTK_WIDGET(gd->hbox), button);
 
 	alternative_order = generic_dialog_get_alternative_button_order(gd->hbox);
 
@@ -268,12 +269,12 @@ GtkWidget *generic_dialog_add_button(GenericDialog *gd, const gchar *stock_id, c
  * @param icon_stock_id
  * @param heading
  * @param text
- * @param expand Used as the "expand" and "fill" parameters in the eventual call to gtk_box_pack_start()
+ * @param expand Used as the "expand" and "fill" parameters in the eventual call to gq_gtk_box_pack_start()
  * @returns
  *
  *
  */
-GtkWidget *generic_dialog_add_message(GenericDialog *gd, const gchar *icon_stock_id,
+GtkWidget *generic_dialog_add_message(GenericDialog *gd, const gchar *icon_name,
 				      const gchar *heading, const gchar *text, gboolean expand)
 {
 	GtkWidget *hbox;
@@ -281,14 +282,14 @@ GtkWidget *generic_dialog_add_message(GenericDialog *gd, const gchar *icon_stock
 	GtkWidget *label;
 
 	hbox = pref_box_new(gd->vbox, expand, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_SPACE);
-	if (icon_stock_id)
+	if (icon_name)
 		{
 		GtkWidget *image;
 
-		image = gtk_image_new_from_stock(icon_stock_id, GTK_ICON_SIZE_DIALOG);
+		image = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_DIALOG);
 		gtk_widget_set_halign(GTK_WIDGET(image), GTK_ALIGN_CENTER);
 		gtk_widget_set_valign(GTK_WIDGET(image), GTK_ALIGN_START);
-		gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 0);
+		gq_gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 0);
 		gtk_widget_show(image);
 		}
 
@@ -390,7 +391,7 @@ static void generic_dialog_setup(GenericDialog *gd,
 	gd->data = data;
 	gd->cancel_cb = cancel_cb;
 
-	gd->dialog = window_new(GTK_WINDOW_TOPLEVEL, role, nullptr, nullptr, title);
+	gd->dialog = window_new(role, nullptr, nullptr, title);
 	DEBUG_NAME(gd->dialog);
 	gtk_window_set_type_hint(GTK_WINDOW(gd->dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
@@ -399,7 +400,7 @@ static void generic_dialog_setup(GenericDialog *gd,
 		if (generic_dialog_find_window(title, role, &x, &y, &w, &h))
 			{
 			gtk_window_set_default_size(GTK_WINDOW(gd->dialog), w, h);
-			gtk_window_move(GTK_WINDOW(gd->dialog), x, y);
+			gq_gtk_window_move(GTK_WINDOW(gd->dialog), x, y);
 			}
 		}
 
@@ -430,29 +431,29 @@ static void generic_dialog_setup(GenericDialog *gd,
 	gtk_window_set_resizable(GTK_WINDOW(gd->dialog), TRUE);
 	gtk_container_set_border_width(GTK_CONTAINER(gd->dialog), PREF_PAD_BORDER);
 
-	scrolled = gtk_scrolled_window_new(nullptr, nullptr);
+	scrolled = gq_gtk_scrolled_window_new(nullptr, nullptr);
 	gtk_scrolled_window_set_propagate_natural_height(GTK_SCROLLED_WINDOW(scrolled), TRUE);
 	gtk_scrolled_window_set_propagate_natural_width(GTK_SCROLLED_WINDOW(scrolled), TRUE);
 	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, PREF_PAD_BUTTON_SPACE);
-	gtk_container_add(GTK_CONTAINER(scrolled), vbox);
-	gtk_container_add(GTK_CONTAINER(gd->dialog), scrolled);
+	gq_gtk_container_add(GTK_WIDGET(scrolled), vbox);
+	gq_gtk_container_add(GTK_WIDGET(gd->dialog), scrolled);
 	gtk_widget_show(scrolled);
 
 	gtk_widget_show(vbox);
 
 	gd->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, PREF_PAD_GAP);
-	gtk_box_pack_start(GTK_BOX(vbox), gd->vbox, TRUE, TRUE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(vbox), gd->vbox, TRUE, TRUE, 0);
 	gtk_widget_show(gd->vbox);
 
-	gd->hbox = gtk_hbutton_box_new();
+	gd->hbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(gd->hbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing(GTK_BOX(gd->hbox), PREF_PAD_BUTTON_GAP);
-	gtk_box_pack_start(GTK_BOX(vbox), gd->hbox, FALSE, FALSE, 0);
+	gq_gtk_box_pack_start(GTK_BOX(vbox), gd->hbox, FALSE, FALSE, 0);
 	gtk_widget_show(gd->hbox);
 
 	if (gd->cancel_cb)
 		{
-		gd->cancel_button = generic_dialog_add_button(gd, GTK_STOCK_CANCEL, nullptr, gd->cancel_cb, TRUE);
+		gd->cancel_button = generic_dialog_add_button(gd, GQ_ICON_CANCEL, _("Cancel"), gd->cancel_cb, TRUE);
 		}
 	else
 		{
@@ -486,20 +487,20 @@ GenericDialog *generic_dialog_new(const gchar *title,
  *-----------------------------------------------------------------------------
  */
 
-static void warning_dialog_ok_cb(GenericDialog *UNUSED(gd), gpointer UNUSED(data))
+static void warning_dialog_ok_cb(GenericDialog *, gpointer)
 {
 	/* no op */
 }
 
 GenericDialog *warning_dialog(const gchar *heading, const gchar *text,
-			      const gchar *icon_stock_id, GtkWidget *parent)
+			      const gchar *icon_name, GtkWidget *parent)
 {
 	GenericDialog *gd;
 
 	gd = generic_dialog_new(heading, "warning", parent, TRUE, nullptr, nullptr);
-	generic_dialog_add_button(gd, GTK_STOCK_OK, nullptr, warning_dialog_ok_cb, TRUE);
+	generic_dialog_add_button(gd, GQ_ICON_OK, "OK", warning_dialog_ok_cb, TRUE);
 
-	generic_dialog_add_message(gd, icon_stock_id, heading, text, TRUE);
+	generic_dialog_add_message(gd, icon_name, heading, text, TRUE);
 
 	gtk_widget_show(gd->dialog);
 
@@ -511,18 +512,12 @@ GenericDialog *warning_dialog(const gchar *heading, const gchar *text,
  * AppImage version update notification message with fade-out
  *-----------------------------------------------------------------------------
  *
- * It is expected that the version file on the server has the following format
- * for the first two lines in these formats:
- *
- * 1. x86_64 AppImage - e.g. Geeqie-v2.0+20221113-x86_64.AppImage
- * 2. arm AppImage - e.g. Geeqie-v2.0+20221025-aarch64.AppImage
+ * If the current version is not on GitHub, assume a newer one is available
+ * and show a fade-out message.
  */
 
 struct AppImageData
 {
-	GFile *version_file;
-	GDataInputStream *data_input_stream;
-	GFileInputStream *file_input_stream;
 	GThreadPool *thread_pool;
 	GtkWidget *window;
 	guint id;
@@ -532,19 +527,16 @@ static gboolean appimage_notification_close_cb(gpointer data)
 {
 	auto appimage_data = static_cast<AppImageData *>(data);
 
-	if (appimage_data->window && gtk_window_get_opacity(GTK_WINDOW(appimage_data->window)) != 0)
+	if (appimage_data->window && gtk_widget_get_opacity(appimage_data->window) != 0)
 		{
 		g_source_remove(appimage_data->id);
 		}
 
 	if (appimage_data->window)
 		{
-		gtk_widget_destroy(appimage_data->window);
+		g_object_unref(appimage_data->window);
 		}
 
-	g_object_unref(appimage_data->data_input_stream);
-	g_object_unref(appimage_data->file_input_stream);
-	g_object_unref(appimage_data->version_file);
 	g_thread_pool_free(appimage_data->thread_pool, TRUE, TRUE);
 	g_free(appimage_data);
 
@@ -555,9 +547,9 @@ static gboolean appimage_notification_fade_cb(gpointer data)
 {
 	auto appimage_data = static_cast<AppImageData *>(data);
 
-	gtk_window_set_opacity(GTK_WINDOW(appimage_data->window), (gtk_window_get_opacity(GTK_WINDOW(appimage_data->window)) - 0.02));
+	gtk_widget_set_opacity(appimage_data->window, (gtk_widget_get_opacity(appimage_data->window) - 0.02));
 
-	if (gtk_window_get_opacity(GTK_WINDOW(appimage_data->window)) == 0)
+	if (gtk_widget_get_opacity(appimage_data->window) == 0)
 		{
 		g_idle_add(appimage_notification_close_cb, data);
 
@@ -567,7 +559,7 @@ static gboolean appimage_notification_fade_cb(gpointer data)
 	return TRUE;
 }
 
-static gboolean user_close_cb(GtkWidget *UNUSED(widget), GdkEvent *UNUSED(event), gpointer data)
+static gboolean user_close_cb(GtkWidget *, GdkEvent *, gpointer data)
 {
 	auto appimage_data = static_cast<AppImageData *>(data);
 
@@ -576,120 +568,78 @@ static gboolean user_close_cb(GtkWidget *UNUSED(widget), GdkEvent *UNUSED(event)
 	return FALSE;
 }
 
-static void show_notification_message(gchar *version_string_from_file, AppImageData *appimage_data)
+static void show_notification_message(AppImageData *appimage_data)
 {
-	GtkWidget *label;
-	gint server_version;
-	gint running_version;
-	gchar *version_string;
+	GtkBuilder *builder;
 
-	server_version = atoi(strtok(strstr(version_string_from_file, "+") + 1, "-") );
-	version_string = g_strdup(strstr(VERSION, "git"));
+	builder = gtk_builder_new_from_resource(GQ_RESOURCE_PATH_UI "/appimage-notification.ui");
 
-	/* If a release version is running, do not look for updates */
-	if (version_string)
-		{
-		running_version = atoi(strtok(version_string + 3, "-") );
-		g_free(version_string);
+	appimage_data->window = GTK_WIDGET(gtk_builder_get_object(builder, "appimage_notification"));
 
-		if (server_version > running_version)
-			{
-			appimage_data->window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-			label = gtk_label_new (_("A new Geeqie AppImage is available"));
-			gtk_widget_show(label);
-			gtk_container_add(GTK_CONTAINER(appimage_data->window), label);
-			gtk_window_set_decorated(GTK_WINDOW(appimage_data->window), FALSE);
-			gtk_widget_set_size_request(appimage_data->window, 300, 40);
-			gtk_window_set_gravity(GTK_WINDOW(appimage_data->window), GDK_GRAVITY_NORTH_EAST);
-			gtk_window_move(GTK_WINDOW(appimage_data->window), (gdk_screen_width() * 0.8), (gdk_screen_height() / 20));
-			gtk_window_set_skip_taskbar_hint(GTK_WINDOW(appimage_data->window), TRUE);
-			gtk_window_set_focus_on_map(GTK_WINDOW(appimage_data->window), FALSE);
-			g_signal_connect(appimage_data->window, "focus-in-event", G_CALLBACK(user_close_cb), appimage_data);
-			appimage_data->id = g_timeout_add(100, appimage_notification_fade_cb, appimage_data);
-			gtk_widget_show((appimage_data->window));
-			}
-		else
-			{
-			g_idle_add(appimage_notification_close_cb, appimage_data);
-			}
-		}
+	GdkRectangle workarea;
+	gdk_monitor_get_workarea(gdk_display_get_primary_monitor(gdk_display_get_default()),
+                             &workarea);
+	gq_gtk_window_move(GTK_WINDOW(appimage_data->window), workarea.width * 0.8, workarea.height / 20);
+	g_signal_connect(appimage_data->window, "focus-in-event", G_CALLBACK(user_close_cb), appimage_data);
+	appimage_data->id = g_timeout_add(100, appimage_notification_fade_cb, appimage_data);
+
+	g_object_unref(builder);
+	gtk_widget_show(appimage_data->window);
 }
 
-#ifdef __arm__
-static void appimage_data_arm_read_line_async_ready_cb(GObject *source_object, GAsyncResult *res, gpointer data)
+void appimage_notification_func(gpointer data, gpointer)
 {
 	auto appimage_data = static_cast<AppImageData *>(data);
-	gsize length;
-	gchar *result;
-
-	result = g_data_input_stream_read_line_finish(appimage_data->data_input_stream, res, &length, nullptr);
-
-	if (result && strstr(result, "-aarch64.AppImage"))
-		{
-		show_notification_message(result, appimage_data);
-		}
-	else
-		{
-		g_idle_add(appimage_notification_close_cb, data);
-		}
-
-	g_free(result);
-}
-#endif
-
-static void appimage_data_x86_read_line_async_ready_cb(GObject *UNUSED(source_object), GAsyncResult *res, gpointer data)
-{
-	auto appimage_data = static_cast<AppImageData *>(data);
-	gsize length;
-	gchar *result;
-
-	result = g_data_input_stream_read_line_finish(appimage_data->data_input_stream, res, &length, nullptr);
-
-#ifdef __x86_64__
-	if (result && strstr(result, "-x86_64.AppImage"))
-		{
-		show_notification_message(result, appimage_data);
-		}
-	else
-		{
-		g_idle_add(appimage_notification_close_cb, data);
-		}
-#endif
-
-#ifdef __arm__
-	g_data_input_stream_read_line_async(appimage_data->data_input_stream, G_PRIORITY_LOW, nullptr, appimage_data_arm_read_line_async_ready_cb, appimage_data);
-#endif
-
-	g_free(result);
-}
-
-static void appimage_notification_func(gpointer data, gpointer UNUSED(user_data))
-{
-	auto appimage_data = static_cast<AppImageData *>(data);
-	GNetworkMonitor *net_mon;
-	GSocketConnectable *geeqie_github_io;
 	gboolean internet_available = FALSE;
+	gchar **version_split;
+	GFile *file_github;
+	GFileInfo *file_info;
+	GNetworkMonitor *net_mon;
+	GSocketConnectable *geeqie_github;
+	struct tm current_version_date;
+	int64_t file_github_date;
+	unsigned int year, month, day;
 
-	net_mon = g_network_monitor_get_default();
-	geeqie_github_io = g_network_address_parse_uri(APPIMAGE_VERSION_FILE, 80, nullptr);
-	if (geeqie_github_io)
+	/* If this is a release version, do not check for updates */
+	if (g_strrstr(VERSION, "git"))
 		{
-		internet_available = g_network_monitor_can_reach(net_mon, geeqie_github_io, nullptr, nullptr);
-		g_object_unref(geeqie_github_io);
-		}
+		net_mon = g_network_monitor_get_default();
+		geeqie_github = g_network_address_parse_uri("https://github.com/", 80, nullptr);
 
-	if (internet_available)
-		{
-		appimage_data->version_file = g_file_new_for_uri(APPIMAGE_VERSION_FILE);
-		appimage_data->file_input_stream = g_file_read(appimage_data->version_file, nullptr, nullptr);
-		appimage_data->data_input_stream = g_data_input_stream_new(G_INPUT_STREAM(appimage_data->file_input_stream));
+		if (geeqie_github)
+			{
+			internet_available = g_network_monitor_can_reach(net_mon, geeqie_github, nullptr, nullptr);
+			g_object_unref(geeqie_github);
+			}
 
-		g_data_input_stream_read_line_async(appimage_data->data_input_stream, G_PRIORITY_LOW, nullptr, appimage_data_x86_read_line_async_ready_cb, appimage_data);
-		}
-	else
-		{
-		g_thread_pool_free(appimage_data->thread_pool, TRUE, TRUE);
-		g_free(appimage_data);
+		if (internet_available)
+			{
+			/* VERSION looks like: 2.0.1+git20220116-c791cbee */
+			version_split = g_strsplit_set(VERSION, "+-", -1);
+
+			file_github = g_file_new_for_uri("https://github.com/BestImageViewer/geeqie/releases/download/continuous/Geeqie-latest-x86_64.AppImage");
+			file_info = g_file_query_info(file_github, "time::modified", G_FILE_QUERY_INFO_NONE, nullptr, nullptr);
+
+			file_github_date = g_file_info_get_attribute_uint64(file_info, "time::modified");
+
+			sscanf(version_split[1] + 3, "%4u%2u%2u", &year, &month, &day);
+			current_version_date.tm_year  = year - 1900;
+			current_version_date.tm_mon   = month - 1;
+			current_version_date.tm_mday  = day;
+			current_version_date.tm_hour  = 0;
+			current_version_date.tm_min   = 0;
+			current_version_date.tm_sec   = 0;
+			current_version_date.tm_isdst = 0;
+
+			if (file_github_date > mktime(&current_version_date))
+				{
+				show_notification_message(appimage_data);
+				}
+
+			g_object_unref(file_github);
+			g_object_unref(file_info);
+			g_strfreev(version_split);
+			}
 		}
 }
 
@@ -741,14 +691,14 @@ GtkWidget *file_dialog_add_button(FileDialog *fdlg, const gchar *stock_id, const
 					 reinterpret_cast<void(*)(GenericDialog *, gpointer)>(func_cb), is_default);
 }
 
-static void file_dialog_entry_cb(GtkWidget *UNUSED(widget), gpointer data)
+static void file_dialog_entry_cb(GtkWidget *, gpointer data)
 {
 	auto fdlg = static_cast<FileDialog *>(data);
 	g_free(fdlg->dest_path);
-	fdlg->dest_path = remove_trailing_slash(gtk_entry_get_text(GTK_ENTRY(fdlg->entry)));
+	fdlg->dest_path = remove_trailing_slash(gq_gtk_entry_get_text(GTK_ENTRY(fdlg->entry)));
 }
 
-static void file_dialog_entry_enter_cb(const gchar *UNUSED(path), gpointer data)
+static void file_dialog_entry_enter_cb(const gchar *, gpointer data)
 {
 	auto gd = static_cast<GenericDialog *>(data);
 
@@ -767,7 +717,7 @@ void file_dialog_add_path_widgets(FileDialog *fdlg, const gchar *default_path, c
 
 	tabcomp = tab_completion_new_with_history(&fdlg->entry, nullptr,
 		  history_key, -1, file_dialog_entry_enter_cb, fdlg);
-	gtk_box_pack_end(GTK_BOX(GENERIC_DIALOG(fdlg)->vbox), tabcomp, FALSE, FALSE, 0);
+	gq_gtk_box_pack_end(GTK_BOX(GENERIC_DIALOG(fdlg)->vbox), tabcomp, FALSE, FALSE, 0);
 	generic_dialog_attach_default(GENERIC_DIALOG(fdlg), fdlg->entry);
 	gtk_widget_show(tabcomp);
 
@@ -796,13 +746,13 @@ void file_dialog_add_path_widgets(FileDialog *fdlg, const gchar *default_path, c
 
 	list = path_selection_new_with_files(fdlg->entry, fdlg->dest_path, filter, filter_desc);
 	path_selection_add_select_func(fdlg->entry, file_dialog_entry_enter_cb, fdlg);
-	gtk_box_pack_end(GTK_BOX(GENERIC_DIALOG(fdlg)->vbox), list, TRUE, TRUE, 0);
+	gq_gtk_box_pack_end(GTK_BOX(GENERIC_DIALOG(fdlg)->vbox), list, TRUE, TRUE, 0);
 	gtk_widget_show(list);
 
 	gtk_widget_grab_focus(fdlg->entry);
 	if (fdlg->dest_path)
 		{
-		gtk_entry_set_text(GTK_ENTRY(fdlg->entry), fdlg->dest_path);
+		gq_gtk_entry_set_text(GTK_ENTRY(fdlg->entry), fdlg->dest_path);
 		gtk_editable_set_position(GTK_EDITABLE(fdlg->entry), strlen(fdlg->dest_path));
 		}
 
@@ -810,17 +760,20 @@ void file_dialog_add_path_widgets(FileDialog *fdlg, const gchar *default_path, c
 			 G_CALLBACK(file_dialog_entry_cb), fdlg);
 }
 
-//void file_dialog_add_filter(FileDialog *fdlg, const gchar *filter, const gchar *filter_desc, gboolean set)
-//{
-	//if (!fdlg->entry) return;
-	//path_selection_add_filter(fdlg->entry, filter, filter_desc, set);
-//}
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+void file_dialog_add_filter_unused(FileDialog *fdlg, const gchar *filter, const gchar *filter_desc, gboolean set)
+{
+	if (!fdlg->entry) return;
+	path_selection_add_filter(fdlg->entry, filter, filter_desc, set);
+}
 
-//void file_dialog_clear_filter(FileDialog *fdlg)
-//{
-	//if (!fdlg->entry) return;
-	//path_selection_clear_filter(fdlg->entry);
-//}
+void file_dialog_clear_filter_unused(FileDialog *fdlg)
+{
+	if (!fdlg->entry) return;
+	path_selection_clear_filter(fdlg->entry);
+}
+#pragma GCC diagnostic pop
 
 void file_dialog_sync_history(FileDialog *fdlg, gboolean dir_only)
 {
