@@ -25,6 +25,8 @@
 
 #include "ui-utildlg.h"
 
+struct FileData;
+
 void file_maint_renamed(FileData *fd);
 void file_maint_moved(FileData *fd, GList *ignore_list);
 void file_maint_copied(FileData *fd);
@@ -38,7 +40,7 @@ FileDialog *file_util_file_dlg(const gchar *title,
 			       GtkWidget *parent,
 			       void (*cancel_cb)(FileDialog *, gpointer), gpointer data);
 GenericDialog *file_util_warning_dialog(const gchar *heading, const gchar *message,
-					const gchar *icon_stock_id, GtkWidget *parent);
+					const gchar *icon_name, GtkWidget *parent);
 
 /* all functions takes over the filelist and frees it when done */
 
@@ -49,7 +51,7 @@ void file_util_copy(FileData *source_fd, GList *source_list, const gchar *dest_p
 void file_util_rename(FileData *source_fd, GList *source_list, GtkWidget *parent);
 void file_util_write_metadata(FileData *source_fd, GList *source_list, GtkWidget *parent, gboolean force_dialog, FileUtilDoneFunc done_func, gpointer done_data);
 
-void file_util_create_dir(FileData *dir_fd, GtkWidget *parent, FileUtilDoneFunc done_func, gpointer done_data);
+void file_util_create_dir(const gchar *path, GtkWidget *parent, FileUtilDoneFunc done_func, gpointer done_data);
 
 void file_util_rename_dir(FileData *source_fd, const gchar *new_path, GtkWidget *parent, FileUtilDoneFunc done_func, gpointer done_data);
 
