@@ -23,10 +23,17 @@
 #include "view-dir-tree.h"
 
 #include "filedata.h"
+#include "layout.h"
 #include "ui-fileops.h"
 #include "ui-tree-edit.h"
 #include "view-dir.h"
 
+struct ViewDirInfoTree
+{
+	guint drop_expand_id; /**< event source id */
+	gint busy_ref;
+};
+
 #define VDTREE(_vd_) ((ViewDirInfoTree *)(_vd_->info))
 
 
@@ -49,10 +56,13 @@ static void vdtree_row_expanded(GtkTreeView *treeview, GtkTreeIter *iter, GtkTre
 static void set_cursor(GtkWidget *widget, GdkCursorType cursor_type)
 {
 	GdkCursor *cursor = nullptr;
+	GdkDisplay *display;
 
 	if (!widget || !gtk_widget_get_window(widget)) return;
 
-	if (cursor_type > -1) cursor = gdk_cursor_new(cursor_type);
+	display = gdk_display_get_default();
+
+	if (cursor_type > -1) cursor = gdk_cursor_new_for_display(display, cursor_type);
 	gdk_window_set_cursor(gtk_widget_get_window(widget), cursor);
 	if (cursor) g_object_unref(G_OBJECT(cursor));
 	gdk_flush();
@@ -253,18 +263,12 @@ static GList *parts_list(const gchar *path)
 	return list;
 }
 
-static void parts_list_free(GList *list)
+static void path_data_free(PathData *pd)
 {
-	GList *work = list;
-	while (work)
-		{
-		auto pd = static_cast<PathData *>(work->data);
-		g_free(pd->name);
-		g_free(pd);
-		work = work->next;
-		}
+	if (!pd) return;
 
-	g_list_free(list);
+	g_free(pd->name);
+	g_free(pd);
 }
 
 static GList *parts_list_add_node_points(ViewDir *vd, GList *list)
@@ -376,9 +380,7 @@ static void vdtree_add_by_data(ViewDir *vd, FileData *fd, GtkTreeIter *parent)
 {
 	GtkTreeStore *store;
 	GtkTreeIter child;
-	NodeData *nd;
 	GdkPixbuf *pixbuf;
-	NodeData *end;
 	GtkTreeIter empty;
 	gchar *link = nullptr;
 
@@ -404,7 +406,7 @@ static void vdtree_add_by_data(ViewDir *vd, FileData *fd, GtkTreeIter *parent)
 		pixbuf = vd->pf->deny;
 		}
 
-	nd = g_new0(NodeData, 1);
+	auto nd = g_new0(NodeData, 1);
 	nd->fd = fd;
 	nd->version = fd->version;
 	nd->expanded = FALSE;
@@ -429,7 +431,7 @@ static void vdtree_add_by_data(ViewDir *vd, FileData *fd, GtkTreeIter *parent)
 
 	/* all nodes are created with an "empty" node, so that the expander is shown
 	 * this is removed when the child is populated */
-	end = g_new0(NodeData, 1);
+	auto end = g_new0(NodeData, 1);
 	end->fd = nullptr;
 	end->expanded = TRUE;
 
@@ -648,7 +650,7 @@ FileData *vdtree_populate_path(ViewDir *vd, FileData *target_fd, gboolean expand
 				{
 				/* should not happen */
 				log_printf("vdtree warning, root node not found\n");
-				parts_list_free(list);
+				g_list_free_full(list, reinterpret_cast<GDestroyNotify>(path_data_free));
 				vdtree_busy_pop(vd);
 				return nullptr;
 				}
@@ -660,7 +662,7 @@ FileData *vdtree_populate_path(ViewDir *vd, FileData *target_fd, gboolean expand
 			    (nd = vdtree_find_iter_by_name(vd, &parent_iter, pd->name, &iter)) == nullptr)
 				{
 				log_printf("vdtree warning, aborted at %s\n", parent_pd->name);
-				parts_list_free(list);
+				g_list_free_full(list, reinterpret_cast<GDestroyNotify>(path_data_free));
 				vdtree_busy_pop(vd);
 				return nullptr;
 				}
@@ -697,7 +699,7 @@ FileData *vdtree_populate_path(ViewDir *vd, FileData *target_fd, gboolean expand
 		auto pd = static_cast<PathData *>(work->data);
 		fd = pd->node;
 		}
-	parts_list_free(list);
+	g_list_free_full(list, reinterpret_cast<GDestroyNotify>(path_data_free));
 
 	vdtree_busy_pop(vd);
 
@@ -712,7 +714,7 @@ FileData *vdtree_populate_path(ViewDir *vd, FileData *target_fd, gboolean expand
 
 static gboolean selection_is_ok = FALSE;
 
-static gboolean vdtree_select_cb(GtkTreeSelection *UNUSED(selection), GtkTreeModel *UNUSED(store), GtkTreePath *UNUSED(tpath), gboolean UNUSED(path_currently_selected), gpointer UNUSED(data))
+static gboolean vdtree_select_cb(GtkTreeSelection *, GtkTreeModel *, GtkTreePath *, gboolean, gpointer)
 {
 	return selection_is_ok;
 }
@@ -771,7 +773,7 @@ void vdtree_refresh(ViewDir *vd)
 	vdtree_populate_path(vd, vd->dir_fd, FALSE, TRUE);
 }
 
-const gchar *vdtree_row_get_path(ViewDir *UNUSED(vd), gint UNUSED(row))
+const gchar *vdtree_row_get_path(ViewDir *, gint)
 {
 /** @FIXME no get row path */
 	log_printf("FIXME: no get row path\n");
@@ -840,7 +842,7 @@ gboolean vdtree_press_key_cb(GtkWidget *widget, GdkEventKey *event, gpointer dat
 }
 
 static gboolean vdtree_clicked_on_expander(GtkTreeView *treeview, GtkTreePath *tpath,
-				           GtkTreeViewColumn *column, gint x, gint UNUSED(y), gint *left_of_expander)
+				           GtkTreeViewColumn *column, gint x, gint, gint *left_of_expander)
 {
 	gint depth;
 	gint size;
@@ -976,10 +978,11 @@ static void vdtree_row_collapsed(GtkTreeView *treeview, GtkTreeIter *iter, GtkTr
 		}
 }
 
-static gint vdtree_sort_cb(GtkTreeModel *store, GtkTreeIter *a, GtkTreeIter *b, gpointer UNUSED(data))
+static gint vdtree_sort_cb(GtkTreeModel *store, GtkTreeIter *a, GtkTreeIter *b, gpointer data)
 {
 	NodeData *nda;
 	NodeData *ndb;
+	auto vd = static_cast<ViewDir *>(data);
 
 	gtk_tree_model_get(store, a, DIR_COLUMN_POINTER, &nda, -1);
 	gtk_tree_model_get(store, b, DIR_COLUMN_POINTER, &ndb, -1);
@@ -988,10 +991,34 @@ static gint vdtree_sort_cb(GtkTreeModel *store, GtkTreeIter *a, GtkTreeIter *b,
 	if (!nda->fd) return 1;
 	if (!ndb->fd) return -1;
 
-	if (options->file_sort.case_sensitive)
-		return strcmp(nda->fd->collate_key_name, ndb->fd->collate_key_name);
+	if (vd->layout->options.dir_view_list_sort.method == SORT_NUMBER)
+		{
+		if (vd->layout->options.dir_view_list_sort.case_sensitive == TRUE)
+			{
+			return strcmp(nda->fd->collate_key_name_natural, ndb->fd->collate_key_name_natural);
+			}
+		else
+			{
+			return strcmp(nda->fd->collate_key_name_nocase_natural, ndb->fd->collate_key_name_nocase_natural);
+			}
+		}
+	else if (vd->layout->options.dir_view_list_sort.method == SORT_TIME)
+		{
+		if (nda->fd->date < ndb->fd->date) return -1;
+		if (nda->fd->date > ndb->fd->date) return 1;
+		return 0;
+		}
 	else
-		return strcmp(nda->fd->collate_key_name_nocase, ndb->fd->collate_key_name_nocase);
+		{
+		if (vd->layout->options.dir_view_list_sort.case_sensitive == TRUE)
+			{
+			return strcmp(nda->fd->collate_key_name, ndb->fd->collate_key_name);
+			}
+		else
+			{
+			return strcmp(nda->fd->collate_key_name_nocase, ndb->fd->collate_key_name_nocase);
+			}
+		}
 }
 
 /*
@@ -1013,7 +1040,7 @@ static void vdtree_setup_root(ViewDir *vd)
 	vdtree_populate_path(vd, fd, FALSE, FALSE);
 }
 
-static gboolean vdtree_destroy_node_cb(GtkTreeModel *store, GtkTreePath *UNUSED(tpath), GtkTreeIter *iter, gpointer UNUSED(data))
+static gboolean vdtree_destroy_node_cb(GtkTreeModel *store, GtkTreePath *, GtkTreeIter *iter, gpointer)
 {
 	NodeData *nd;
 
@@ -1023,7 +1050,7 @@ static gboolean vdtree_destroy_node_cb(GtkTreeModel *store, GtkTreePath *UNUSED(
 	return FALSE;
 }
 
-void vdtree_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
+void vdtree_destroy_cb(GtkWidget *, gpointer data)
 {
 	auto vd = static_cast<ViewDir *>(data);
 	GtkTreeModel *store;
@@ -1036,7 +1063,7 @@ void vdtree_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
 	gtk_tree_model_foreach(store, vdtree_destroy_node_cb, vd);
 }
 
-ViewDir *vdtree_new(ViewDir *vd, FileData *UNUSED(dir_fd))
+ViewDir *vdtree_new(ViewDir *vd, FileData *)
 {
 	GtkTreeStore *store;
 	GtkTreeSelection *selection;
