@@ -52,7 +52,7 @@ enum {
 };
 
 static void vficon_toggle_filenames(ViewFile *vf);
-static void vficon_selection_remove(ViewFile *vf, FileData *id, SelectionType mask, GtkTreeIter *iter);
+static void vficon_selection_remove(ViewFile *vf, FileData *fd, SelectionType mask, GtkTreeIter *iter);
 static void vficon_move_focus(ViewFile *vf, gint row, gint col, gboolean relative);
 static void vficon_set_focus(ViewFile *vf, FileData *fd);
 static void vficon_populate_at_new_size(ViewFile *vf, gint w, gint h, gboolean force);
@@ -64,7 +64,7 @@ static void vficon_populate_at_new_size(ViewFile *vf, gint w, gint h, gboolean f
  *-----------------------------------------------------------------------------
  */
 
-GList *vficon_selection_get_one(ViewFile *UNUSED(vf), FileData *fd)
+GList *vficon_selection_get_one(ViewFile *, FileData *fd)
 {
 	return g_list_prepend(filelist_copy(fd->sidecar_files), file_data_ref(fd));
 }
@@ -81,7 +81,7 @@ GList *vficon_pop_menu_file_list(ViewFile *vf)
 	return vficon_selection_get_one(vf, VFICON(vf)->click_fd);
 }
 
-void vficon_pop_menu_view_cb(GtkWidget *UNUSED(widget), gpointer data)
+void vficon_pop_menu_view_cb(GtkWidget *, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
@@ -101,14 +101,14 @@ void vficon_pop_menu_view_cb(GtkWidget *UNUSED(widget), gpointer data)
 		}
 }
 
-void vficon_pop_menu_rename_cb(GtkWidget *UNUSED(widget), gpointer data)
+void vficon_pop_menu_rename_cb(GtkWidget *, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
 	file_util_rename(nullptr, vf_pop_menu_file_list(vf), vf->listview);
 }
 
-void vficon_pop_menu_show_names_cb(GtkWidget *UNUSED(widget), gpointer data)
+void vficon_pop_menu_show_names_cb(GtkWidget *, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
@@ -125,21 +125,21 @@ static void vficon_toggle_star_rating(ViewFile *vf)
 	vficon_populate_at_new_size(vf, allocation.width, allocation.height, TRUE);
 }
 
-void vficon_pop_menu_show_star_rating_cb(GtkWidget *UNUSED(widget), gpointer data)
+void vficon_pop_menu_show_star_rating_cb(GtkWidget *, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
 	vficon_toggle_star_rating(vf);
 }
 
-void vficon_pop_menu_refresh_cb(GtkWidget *UNUSED(widget), gpointer data)
+void vficon_pop_menu_refresh_cb(GtkWidget *, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
 	vf_refresh(vf);
 }
 
-void vficon_popup_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
+void vficon_popup_destroy_cb(GtkWidget *, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 	vficon_selection_remove(vf, VFICON(vf)->click_fd, SELECTION_PRELIGHT, nullptr);
@@ -353,7 +353,7 @@ static void tip_show(ViewFile *vf)
 	label = gtk_label_new(VFICON(vf)->tip_fd->name);
 
 	g_object_set_data(G_OBJECT(VFICON(vf)->tip_window), "tip_label", label);
-	gtk_container_add(GTK_CONTAINER(VFICON(vf)->tip_window), label);
+	gq_gtk_container_add(GTK_WIDGET(VFICON(vf)->tip_window), label);
 	gtk_widget_show(label);
 
 	display = gdk_display_get_default();
@@ -362,13 +362,13 @@ static void tip_show(ViewFile *vf)
 	gdk_device_get_position(device, nullptr, &x, &y);
 
 	if (!gtk_widget_get_realized(VFICON(vf)->tip_window)) gtk_widget_realize(VFICON(vf)->tip_window);
-	gtk_window_move(GTK_WINDOW(VFICON(vf)->tip_window), x + 16, y + 16);
+	gq_gtk_window_move(GTK_WINDOW(VFICON(vf)->tip_window), x + 16, y + 16);
 	gtk_widget_show(VFICON(vf)->tip_window);
 }
 
 static void tip_hide(ViewFile *vf)
 {
-	if (VFICON(vf)->tip_window) gtk_widget_destroy(VFICON(vf)->tip_window);
+	if (VFICON(vf)->tip_window) g_object_unref(VFICON(vf)->tip_window);
 	VFICON(vf)->tip_window = nullptr;
 }
 
@@ -430,7 +430,7 @@ static void tip_update(ViewFile *vf, FileData *fd)
 
 		gdk_device_get_position(device, nullptr, &x, &y);
 
-		gtk_window_move(GTK_WINDOW(VFICON(vf)->tip_window), x + 16, y + 16);
+		gq_gtk_window_move(GTK_WINDOW(VFICON(vf)->tip_window), x + 16, y + 16);
 
 		if (fd != VFICON(vf)->tip_fd)
 			{
@@ -461,9 +461,9 @@ static void tip_update(ViewFile *vf, FileData *fd)
  *-------------------------------------------------------------------
  */
 
-static void vficon_dnd_get(GtkWidget *UNUSED(widget), GdkDragContext *UNUSED(context),
-			   GtkSelectionData *selection_data, guint UNUSED(info),
-			   guint UNUSED(time), gpointer data)
+static void vficon_dnd_get(GtkWidget *, GdkDragContext *,
+			   GtkSelectionData *selection_data, guint,
+			   guint, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 	GList *list = nullptr;
@@ -484,9 +484,9 @@ static void vficon_dnd_get(GtkWidget *UNUSED(widget), GdkDragContext *UNUSED(con
 	filelist_free(list);
 }
 
-static void vficon_drag_data_received(GtkWidget *UNUSED(entry_widget), GdkDragContext *UNUSED(context),
+static void vficon_drag_data_received(GtkWidget *, GdkDragContext *,
 				      int x, int y, GtkSelectionData *selection,
-				      guint info, guint UNUSED(time), gpointer data)
+				      guint info, guint, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
@@ -499,7 +499,7 @@ static void vficon_drag_data_received(GtkWidget *UNUSED(entry_widget), GdkDragCo
 			GList *kw_list = string_to_keywords_list(str);
 
 			metadata_append_list(fd, KEYWORD_KEY, kw_list);
-			string_list_free(kw_list);
+			g_list_free_full(kw_list, g_free);
 			g_free(str);
 		}
 	}
@@ -524,7 +524,7 @@ static void vficon_dnd_begin(GtkWidget *widget, GdkDragContext *context, gpointe
 		}
 }
 
-static void vficon_dnd_end(GtkWidget *UNUSED(widget), GdkDragContext *context, gpointer data)
+static void vficon_dnd_end(GtkWidget *, GdkDragContext *context, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
@@ -605,14 +605,14 @@ static void vficon_selection_remove(ViewFile *vf, FileData *fd, SelectionType ma
 	vficon_selection_set(vf, fd, static_cast<SelectionType>(fd->selected & ~mask), iter);
 }
 
-void vficon_marks_set(ViewFile *vf, gint UNUSED(enable))
+void vficon_marks_set(ViewFile *vf, gint)
 {
 	GtkAllocation allocation;
 	gtk_widget_get_allocation(vf->listview, &allocation);
 	vficon_populate_at_new_size(vf, allocation.width, allocation.height, TRUE);
 }
 
-void vficon_star_rating_set(ViewFile *vf, gint UNUSED(enable))
+void vficon_star_rating_set(ViewFile *vf, gint)
 {
 	GtkAllocation allocation;
 	gtk_widget_get_allocation(vf->listview, &allocation);
@@ -804,14 +804,17 @@ static void vficon_select_region_util(ViewFile *vf, FileData *start, FileData *e
 		}
 }
 
-//gboolean vficon_index_is_selected(ViewFile *vf, gint row)
-//{
-	//FileData *fd = g_list_nth_data(vf->list, row);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+gboolean vficon_index_is_selected_unused(ViewFile *vf, gint row)
+{
+	FileData *fd = static_cast<FileData *>(g_list_nth_data(vf->list, row));
 
-	//if (!fd) return FALSE;
+	if (!fd) return FALSE;
 
-	//return (fd->selected & SELECTION_SELECTED);
-//}
+	return (fd->selected & SELECTION_SELECTED);
+}
+#pragma GCC diagnostic pop
 
 guint vficon_selection_count(ViewFile *vf, gint64 *bytes)
 {
@@ -839,29 +842,16 @@ guint vficon_selection_count(ViewFile *vf, gint64 *bytes)
 GList *vficon_selection_get_list(ViewFile *vf)
 {
 	GList *list = nullptr;
-	GList *work, *work2;
 
-	work = VFICON(vf)->selection;
-	while (work)
+	for (GList *work = g_list_last(VFICON(vf)->selection); work; work = work->prev)
 		{
 		auto fd = static_cast<FileData *>(work->data);
 		g_assert(fd->magick == FD_MAGICK);
 
+		list = g_list_concat(filelist_copy(fd->sidecar_files), list);
 		list = g_list_prepend(list, file_data_ref(fd));
-
-		work2 = fd->sidecar_files;
-		while (work2)
-			{
-			fd = static_cast<FileData *>(work2->data);
-			list = g_list_prepend(list, file_data_ref(fd));
-			work2 = work2->next;
-			}
-
-		work = work->next;
 		}
 
-	list = g_list_reverse(list);
-
 	return list;
 }
 
@@ -1159,7 +1149,7 @@ static gint page_height(ViewFile *vf)
 	gint row_height;
 	gint ret;
 
-	adj = gtk_tree_view_get_vadjustment(GTK_TREE_VIEW(vf->listview));
+	adj = gtk_scrollable_get_vadjustment(GTK_SCROLLABLE(vf->listview));
 	page_size = static_cast<gint>(gtk_adjustment_get_page_increment(adj));
 
 	row_height = options->thumbnails.max_height + THUMB_BORDER_PADDING * 2;
@@ -1309,7 +1299,7 @@ gboolean vficon_press_key_cb(GtkWidget *widget, GdkEventKey *event, gpointer dat
  *-------------------------------------------------------------------
  */
 
-static gboolean vficon_motion_cb(GtkWidget *UNUSED(widget), GdkEventMotion *event, gpointer data)
+static gboolean vficon_motion_cb(GtkWidget *, GdkEventMotion *event, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 	FileData *fd;
@@ -1320,7 +1310,7 @@ static gboolean vficon_motion_cb(GtkWidget *UNUSED(widget), GdkEventMotion *even
 	return FALSE;
 }
 
-gboolean vficon_press_cb(GtkWidget *UNUSED(widget), GdkEventButton *bevent, gpointer data)
+gboolean vficon_press_cb(GtkWidget *, GdkEventButton *bevent, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 	GtkTreeIter iter;
@@ -1330,36 +1320,39 @@ gboolean vficon_press_cb(GtkWidget *UNUSED(widget), GdkEventButton *bevent, gpoi
 
 	fd = vficon_find_data_by_coord(vf, static_cast<gint>(bevent->x), static_cast<gint>(bevent->y), &iter);
 
-	VFICON(vf)->click_fd = fd;
-	vficon_selection_add(vf, VFICON(vf)->click_fd, SELECTION_PRELIGHT, &iter);
-
-	switch (bevent->button)
+	if (fd)
 		{
-		case MOUSE_BUTTON_LEFT:
-			if (!gtk_widget_has_focus(vf->listview))
-				{
-				gtk_widget_grab_focus(vf->listview);
-				}
+		VFICON(vf)->click_fd = fd;
+		vficon_selection_add(vf, VFICON(vf)->click_fd, SELECTION_PRELIGHT, &iter);
 
-			if (bevent->type == GDK_2BUTTON_PRESS && vf->layout)
-				{
-				if (VFICON(vf)->click_fd->format_class == FORMAT_CLASS_COLLECTION)
+		switch (bevent->button)
+			{
+			case MOUSE_BUTTON_LEFT:
+				if (!gtk_widget_has_focus(vf->listview))
 					{
-					collection_window_new(VFICON(vf)->click_fd->path);
+					gtk_widget_grab_focus(vf->listview);
 					}
-				else
+
+				if (bevent->type == GDK_2BUTTON_PRESS && vf->layout)
 					{
-					vficon_selection_remove(vf, VFICON(vf)->click_fd, SELECTION_PRELIGHT, &iter);
-					layout_image_full_screen_start(vf->layout);
+					if (VFICON(vf)->click_fd->format_class == FORMAT_CLASS_COLLECTION)
+						{
+						collection_window_new(VFICON(vf)->click_fd->path);
+						}
+					else
+						{
+						vficon_selection_remove(vf, VFICON(vf)->click_fd, SELECTION_PRELIGHT, &iter);
+						layout_image_full_screen_start(vf->layout);
+						}
 					}
-				}
-			break;
-		case MOUSE_BUTTON_RIGHT:
-			vf->popup = vf_pop_menu(vf);
-			gtk_menu_popup_at_pointer(GTK_MENU(vf->popup), nullptr);
-			break;
-		default:
-			break;
+				break;
+			case MOUSE_BUTTON_RIGHT:
+				vf->popup = vf_pop_menu(vf);
+				gtk_menu_popup_at_pointer(GTK_MENU(vf->popup), nullptr);
+				break;
+			default:
+				break;
+			}
 		}
 
 	return FALSE;
@@ -1446,7 +1439,7 @@ gboolean vficon_release_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer d
 	return TRUE;
 }
 
-static gboolean vficon_leave_cb(GtkWidget *UNUSED(widget), GdkEventCrossing *UNUSED(event), gpointer data)
+static gboolean vficon_leave_cb(GtkWidget *, GdkEventCrossing *, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
@@ -1460,7 +1453,7 @@ static gboolean vficon_leave_cb(GtkWidget *UNUSED(widget), GdkEventCrossing *UNU
  *-------------------------------------------------------------------
  */
 
-static gboolean vficon_destroy_node_cb(GtkTreeModel *store, GtkTreePath *UNUSED(tpath), GtkTreeIter *iter, gpointer UNUSED(data))
+static gboolean vficon_destroy_node_cb(GtkTreeModel *store, GtkTreePath *, GtkTreeIter *iter, gpointer)
 {
 	GList *list;
 
@@ -1640,7 +1633,7 @@ static void vficon_populate(ViewFile *vf, gboolean resize, gboolean keep_positio
 	vf_star_update(vf);
 }
 
-static void vficon_populate_at_new_size(ViewFile *vf, gint w, gint UNUSED(h), gboolean force)
+static void vficon_populate_at_new_size(ViewFile *vf, gint w, gint, gboolean force)
 {
 	gint new_cols;
 	gint thumb_width;
@@ -1659,7 +1652,7 @@ static void vficon_populate_at_new_size(ViewFile *vf, gint w, gint UNUSED(h), gb
 	DEBUG_1("col tab pop cols=%d rows=%d", VFICON(vf)->columns, VFICON(vf)->rows);
 }
 
-static void vficon_sized_cb(GtkWidget *UNUSED(widget), GtkAllocation *allocation, gpointer data)
+static void vficon_sized_cb(GtkWidget *, GtkAllocation *allocation, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
@@ -1672,12 +1665,13 @@ static void vficon_sized_cb(GtkWidget *UNUSED(widget), GtkAllocation *allocation
  *-----------------------------------------------------------------------------
  */
 
-void vficon_sort_set(ViewFile *vf, SortType type, gboolean ascend)
+void vficon_sort_set(ViewFile *vf, SortType type, gboolean ascend, gboolean case_sensitive)
 {
-	if (vf->sort_method == type && vf->sort_ascend == ascend) return;
+	if (vf->sort_method == type && vf->sort_ascend == ascend && vf->sort_case == case_sensitive) return;
 
 	vf->sort_method = type;
 	vf->sort_ascend = ascend;
+	vf->sort_case = case_sensitive;
 
 	if (!vf->list) return;
 
@@ -1914,8 +1908,8 @@ static gboolean vficon_refresh_real(ViewFile *vf, gboolean keep_position)
 
 		}
 
-	vf->list = filelist_sort(vf->list, vf->sort_method, vf->sort_ascend); /* the list might not be sorted if there were renames */
-	new_filelist = filelist_sort(new_filelist, vf->sort_method, vf->sort_ascend);
+	vf->list = filelist_sort(vf->list, vf->sort_method, vf->sort_ascend, vf->sort_case); /* the list might not be sorted if there were renames */
+	new_filelist = filelist_sort(new_filelist, vf->sort_method, vf->sort_ascend, vf->sort_case);
 
 	if (VFICON(vf)->selection)
 		{
@@ -2063,14 +2057,14 @@ struct ColumnData
 	gint number;
 };
 
-static void vficon_cell_data_cb(GtkTreeViewColumn *UNUSED(tree_column), GtkCellRenderer *cell,
+static void vficon_cell_data_cb(GtkTreeViewColumn *, GtkCellRenderer *cell,
 				GtkTreeModel *tree_model, GtkTreeIter *iter, gpointer data)
 {
-	GList *list;
-	FileData *fd;
 	auto cd = static_cast<ColumnData *>(data);
-	ViewFile *vf = cd->vf;
+	FileData *fd;
 	gchar *star_rating;
+	GList *list;
+	ViewFile *vf = cd->vf;
 
 	if (!GQV_IS_CELL_RENDERER_ICON(cell)) return;
 
@@ -2080,12 +2074,14 @@ static void vficon_cell_data_cb(GtkTreeViewColumn *UNUSED(tree_column), GtkCellR
 
 	if (fd)
 		{
-		GdkColor color_fg;
-		GdkColor color_bg;
-		GtkStyle *style;
-		gchar *name_sidecars = nullptr;
 		const gchar *link;
+		gchar *name_sidecars = nullptr;
+		GdkRGBA color_bg;
+		GdkRGBA color_fg;
+		GdkRGBA color_bg_style;
+		GdkRGBA color_fg_style;
 		GtkStateType state = GTK_STATE_NORMAL;
+		GtkStyle *style;
 
 		g_assert(fd->magick == FD_MAGICK);
 
@@ -2140,21 +2136,24 @@ static void vficon_cell_data_cb(GtkTreeViewColumn *UNUSED(tree_column), GtkCellR
 			state = GTK_STATE_SELECTED;
 			}
 
-		memcpy(&color_fg, &style->text[state], sizeof(color_fg));
-		memcpy(&color_bg, &style->base[state], sizeof(color_bg));
+		convert_gdkcolor_to_gdkrgba(&style->text[state], &color_fg_style);
+		convert_gdkcolor_to_gdkrgba(&style->base[state], &color_bg_style);
+
+		memcpy(&color_fg, &color_fg_style, sizeof(color_fg));
+		memcpy(&color_bg, &color_bg_style, sizeof(color_bg));
 
 		if (fd->selected & SELECTION_PRELIGHT)
 			{
 			shift_color(&color_bg, -1, 0);
 			}
 
-		g_object_set(cell,	"pixbuf", fd->thumb_pixbuf,
+		g_object_set(cell, "pixbuf", fd->thumb_pixbuf,
 					"text", name_sidecars,
 					"marks", file_data_get_marks(fd),
 					"show_marks", vf->marks_enabled,
-					"cell-background-gdk", &color_bg,
+					"cell-background-rgba", &color_bg,
 					"cell-background-set", TRUE,
-					"foreground-gdk", &color_fg,
+					"foreground-rgba", &color_fg,
 					"foreground-set", TRUE,
 					"has-focus", (VFICON(vf)->focus_fd == fd), NULL);
 		g_free(name_sidecars);
@@ -2172,7 +2171,6 @@ static void vficon_cell_data_cb(GtkTreeViewColumn *UNUSED(tree_column), GtkCellR
 
 static void vficon_append_column(ViewFile *vf, gint n)
 {
-	ColumnData *cd;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
 
@@ -2191,7 +2189,7 @@ static void vficon_append_column(ViewFile *vf, gint n)
 	g_object_set_data(G_OBJECT(column), "column_number", GINT_TO_POINTER(n));
 	g_object_set_data(G_OBJECT(renderer), "column_number", GINT_TO_POINTER(n));
 
-	cd = g_new0(ColumnData, 1);
+	auto cd = g_new0(ColumnData, 1);
 	cd->vf = vf;
 	cd->number = n;
 	gtk_tree_view_column_set_cell_data_func(column, renderer, vficon_cell_data_cb, cd, g_free);
@@ -2232,7 +2230,7 @@ gboolean vficon_set_fd(ViewFile *vf, FileData *dir_fd)
 	return ret;
 }
 
-void vficon_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
+void vficon_destroy_cb(GtkWidget *, gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
@@ -2249,7 +2247,7 @@ void vficon_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
 	g_list_free(VFICON(vf)->selection);
 }
 
-ViewFile *vficon_new(ViewFile *vf, FileData *UNUSED(dir_fd))
+ViewFile *vficon_new(ViewFile *vf, FileData *)
 {
 	GtkListStore *store;
 	GtkTreeSelection *selection;
