@@ -21,7 +21,7 @@
 #ifndef WINDOW_H
 #define WINDOW_H
 
-GtkWidget *window_new(GtkWindowType type, const gchar *role, const gchar *icon,
+GtkWidget *window_new(const gchar *role, const gchar *icon,
 		      const gchar *icon_file, const gchar *subtitle);
 void window_set_icon(GtkWidget *window, const gchar *icon, const gchar *file);
 gboolean window_maximized(GtkWidget *window);
