@@ -25,16 +25,19 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <assert.h>
-#include <stdlib.h>
-#include <string.h>
-#include <math.h>
+#include <cassert>
+#include <cmath>
+#include <cstdlib>
+#include <cstring>
 #if defined(_MSC_VER) || defined(__MINGW32__)
 #include <windows.h>
 #elif defined(__APPLE__) || defined(__linux__) || defined(__unix__) || defined(_POSIX_VERSION)
-#include <errno.h>
-#include <sys/mman.h>
+#include <cerrno>
+#include <memory>
+#include <vector>
+
 #include <fcntl.h>
+#include <sys/mman.h>
 #include <unistd.h>
 #endif
 
@@ -381,107 +384,110 @@ static int ZDReaderGetPoint(struct Reader *reader, int32_t *pointLat, int32_t *p
 {
     int32_t diffLat = 0, diffLon = 0;
 
-readNewPoint:
-    if(reader->done > 1) {
-        return 0;
-    }
+    while(true) {
+        if(reader->done > 1) {
+            return 0;
+        }
 
-    if(reader->first && reader->library->version == 0) {
-        if(!ZDDecodeVariableLengthUnsigned(reader->library, &reader->polygonIndex, &reader->numVertices)) return -1;
-        if(!reader->numVertices) return -1;
-    }
+        if(reader->first && reader->library->version == 0) {
+            if(!ZDDecodeVariableLengthUnsigned(reader->library, &reader->polygonIndex, &reader->numVertices)) return -1;
+            if(!reader->numVertices) return -1;
+        }
 
-    uint8_t referenceDone = 0;
+        uint8_t referenceDone = 0;
 
-    if(reader->library->version == 1) {
-        uint64_t point = 0;
+        if(reader->library->version == 1) {
+            uint64_t point = 0;
 
-        if(!reader->referenceDirection) {
-            if(!ZDDecodeVariableLengthUnsigned(reader->library, &reader->polygonIndex, &point)) return -1;
-        } else {
-            if(reader->referenceDirection > 0) {
-                /* Read reference forward */
-                if(!ZDDecodeVariableLengthUnsigned(reader->library, &reader->referenceStart, &point)) return -1;
-                if(reader->referenceStart >= reader->referenceEnd) {
-                    referenceDone = 1;
+            if(!reader->referenceDirection) {
+                if(!ZDDecodeVariableLengthUnsigned(reader->library, &reader->polygonIndex, &point)) return -1;
+            } else {
+                if(reader->referenceDirection > 0) {
+                    /* Read reference forward */
+                    if(!ZDDecodeVariableLengthUnsigned(reader->library, &reader->referenceStart, &point)) return -1;
+                    if(reader->referenceStart >= reader->referenceEnd) {
+                        referenceDone = 1;
+                    }
+                } else if(reader->referenceDirection < 0) {
+                    /* Read reference backwards */
+                    if(!ZDDecodeVariableLengthUnsignedReverse(reader->library, &reader->referenceStart, &point)) return -1;
+                    if(reader->referenceStart <= reader->referenceEnd) {
+                        referenceDone = 1;
+                    }
                 }
-            } else if(reader->referenceDirection < 0) {
-                /* Read reference backwards */
-                if(!ZDDecodeVariableLengthUnsignedReverse(reader->library, &reader->referenceStart, &point)) return -1;
-                if(reader->referenceStart <= reader->referenceEnd) {
-                    referenceDone = 1;
+            }
+
+            if(!point) {
+                /* This is a special marker, it is not allowed in reference mode */
+                if(reader->referenceDirection) {
+                    return -1;
+                }
+
+                uint64_t value;
+                if(!ZDDecodeVariableLengthUnsigned(reader->library, &reader->polygonIndex, &value)) return -1;
+
+                if(value == 0) {
+                    reader->done = 2;
+                } else if(value == 1) {
+                    int32_t diff;
+                    int64_t start;
+                    if(!ZDDecodeVariableLengthUnsigned(reader->library, &reader->polygonIndex, reinterpret_cast<uint64_t*>(&start))) return -1;
+                    if(!ZDDecodeVariableLengthSigned(reader->library, &reader->polygonIndex, &diff)) return -1;
+
+                    reader->referenceStart = reader->library->dataOffset+static_cast<uint32_t>(start);
+                    reader->referenceEnd = reader->library->dataOffset+static_cast<uint32_t>(start + diff);
+                    reader->referenceDirection = diff;
+                    if(diff < 0) {
+                        reader->referenceStart--;
+                        reader->referenceEnd--;
+                    }
+                    continue;
+                }
+            } else {
+                ZDDecodePoint(point, &diffLat, &diffLon);
+                if(reader->referenceDirection < 0) {
+                    diffLat = -diffLat;
+                    diffLon = -diffLon;
                 }
             }
         }
 
-        if(!point) {
-            /* This is a special marker, it is not allowed in reference mode */
-            if(reader->referenceDirection) {
-                return -1;
-            }
+        if(reader->library->version == 0) {
+            if(!ZDDecodeVariableLengthSigned(reader->library, &reader->polygonIndex, &diffLat)) return -1;
+            if(!ZDDecodeVariableLengthSigned(reader->library, &reader->polygonIndex, &diffLon)) return -1;
+        }
 
-            uint64_t value;
-            if(!ZDDecodeVariableLengthUnsigned(reader->library, &reader->polygonIndex, &value)) return -1;
-
-            if(value == 0) {
-                reader->done = 2;
-            } else if(value == 1) {
-                int32_t diff;
-                int64_t start;
-                if(!ZDDecodeVariableLengthUnsigned(reader->library, &reader->polygonIndex, reinterpret_cast<uint64_t*>(&start))) return -1;
-                if(!ZDDecodeVariableLengthSigned(reader->library, &reader->polygonIndex, &diff)) return -1;
-
-                reader->referenceStart = reader->library->dataOffset+static_cast<uint32_t>(start);
-                reader->referenceEnd = reader->library->dataOffset+static_cast<uint32_t>(start + diff);
-                reader->referenceDirection = diff;
-                if(diff < 0) {
-                    reader->referenceStart--;
-                    reader->referenceEnd--;
-                }
-                goto readNewPoint;
+        if(!reader->done) {
+            reader->pointLat += diffLat;
+            reader->pointLon += diffLon;
+            if(reader->first) {
+                reader->firstLat = reader->pointLat;
+                reader->firstLon = reader->pointLon;
             }
         } else {
-            ZDDecodePoint(point, &diffLat, &diffLon);
-            if(reader->referenceDirection < 0) {
-                diffLat = -diffLat;
-                diffLon = -diffLon;
+            /* Close the polygon (the closing point is not encoded) */
+            reader->pointLat = reader->firstLat;
+            reader->pointLon = reader->firstLon;
+            reader->done = 2;
+        }
+
+        reader->first = 0;
+
+        if(reader->library->version == 0) {
+            reader->numVertices--;
+            if(!reader->numVertices) {
+                reader->done = 1;
+            }
+            if(!diffLat && !diffLon) {
+                continue;
             }
         }
-    }
 
-    if(reader->library->version == 0) {
-        if(!ZDDecodeVariableLengthSigned(reader->library, &reader->polygonIndex, &diffLat)) return -1;
-        if(!ZDDecodeVariableLengthSigned(reader->library, &reader->polygonIndex, &diffLon)) return -1;
-    }
-
-    if(!reader->done) {
-        reader->pointLat += diffLat;
-        reader->pointLon += diffLon;
-        if(reader->first) {
-            reader->firstLat = reader->pointLat;
-            reader->firstLon = reader->pointLon;
+        if(referenceDone) {
+            reader->referenceDirection = 0;
         }
-    } else {
-        /* Close the polygon (the closing point is not encoded) */
-        reader->pointLat = reader->firstLat;
-        reader->pointLon = reader->firstLon;
-        reader->done = 2;
-    }
 
-    reader->first = 0;
-
-    if(reader->library->version == 0) {
-        reader->numVertices--;
-        if(!reader->numVertices) {
-            reader->done = 1;
-        }
-        if(!diffLat && !diffLon) {
-            goto readNewPoint;
-        }
-    }
-
-    if(referenceDone) {
-        reader->referenceDirection = 0;
+        break;
     }
 
     if(pointLat) {
@@ -534,77 +540,53 @@ static int ZDFindPolygon(const ZoneDetect *library, uint32_t wantedId, uint32_t*
     return 0;
 }
 
-static int32_t* ZDPolygonToListInternal(const ZoneDetect *library, uint32_t polygonIndex, size_t* length)
+static std::vector<int32_t> ZDPolygonToListInternal(const ZoneDetect *library, uint32_t polygonIndex)
 {
     struct Reader reader;
     ZDReaderInit(&reader, library, polygonIndex);
 
-    size_t listLength = 2 * 100;
-    size_t listIndex = 0;
-
-    auto  list = static_cast<int32_t *>(malloc(sizeof(int32_t) * listLength));
-    if(!list) {
-        goto fail;
-    }
+    constexpr size_t listLength = 2 * 100;
+    std::vector<int32_t> list;
+    list.reserve(listLength);
 
     while(true) {
         int32_t pointLat, pointLon;
         int result = ZDReaderGetPoint(&reader, &pointLat, &pointLon);
         if(result < 0) {
-            goto fail;
-        } else if(result == 0) {
+            return {};
+        }
+        if(result == 0) {
             break;
         }
 
-        if(listIndex >= listLength) {
-            listLength *= 2;
-            if(listLength >= 1048576) {
-                goto fail;
-            }
+        list.push_back(pointLat);
+        list.push_back(pointLon);
 
-            list = static_cast<int32_t *>(realloc(list, sizeof(int32_t) * listLength));
-            if(!list) {
-                goto fail;
-            }
+        if(list.size() >= 1048576) {
+            return {};
         }
-
-        list[listIndex++] = pointLat;
-        list[listIndex++] = pointLon;
-    }
-
-    if(length) {
-        *length = listIndex;
     }
 
     return list;
-
-fail:
-    if(list) {
-        free(list);
-    }
-    return nullptr;
 }
 
 float* ZDPolygonToList(const ZoneDetect *library, uint32_t polygonId, size_t* lengthPtr)
 {
     uint32_t polygonIndex;
-    int32_t* data = nullptr;
     float* flData = nullptr;
-    size_t length = 0;
 
-    if(!ZDFindPolygon(library, polygonId, nullptr, &polygonIndex)) {
-        goto fail;
-    }
+    if (!ZDFindPolygon(library, polygonId, nullptr, &polygonIndex))
+        return nullptr;
 
-    data = ZDPolygonToListInternal(library, polygonIndex, &length);
+    const auto data = ZDPolygonToListInternal(library, polygonIndex);
+    if (data.empty())
+        return nullptr;
 
-    if(!data) {
-        goto fail;
-    }
+    size_t length = data.size();
 
     flData = static_cast<float *>(malloc(sizeof(float) * length));
     if(!flData) {
-        goto fail;
+        return nullptr;
     }
 
     for(size_t i = 0; i<length; i+= 2) {
@@ -620,15 +602,6 @@ float* ZDPolygonToList(const ZoneDetect *library, uint32_t polygonId, size_t* le
     }
 
     return flData;
-
-fail:
-    if(data) {
-        free(data);
-    }
-    if(flData) {
-        free(flData);
-    }
-    return nullptr;
 }
 
 static ZDLookupResult ZDPointInPolygon(const ZoneDetect *library, uint32_t polygonIndex, int32_t latFixedPoint, int32_t lonFixedPoint, uint64_t *distanceSqrMin)
@@ -809,12 +782,20 @@ void ZDCloseDatabase(ZoneDetect *library)
     }
 }
 
+struct ZoneDetectDeleter {
+    void operator()(ZoneDetect *library)
+    {
+        ZDCloseDatabase(library);
+    }
+};
+
+using ZoneDetectPtr = std::unique_ptr<ZoneDetect, ZoneDetectDeleter>;
+
 ZoneDetect *ZDOpenDatabaseFromMemory(void* buffer, size_t length)
 {
-    auto library = static_cast<ZoneDetect *>(malloc(sizeof(ZoneDetect)));
+    ZoneDetectPtr library{static_cast<ZoneDetect *>(calloc(1, sizeof(ZoneDetect)))};
 
     if(library) {
-        memset(library, 0, sizeof(*library));
         library->closeType = 1;
         library->length = static_cast<long int>(length);
 
@@ -824,90 +805,80 @@ ZoneDetect *ZDOpenDatabaseFromMemory(void* buffer, size_t length)
 #else
             zdError(ZD_E_DB_SEEK, 0);
 #endif
-            goto fail;
+            return nullptr;
         }
 
         library->mapping = static_cast<uint8_t *>(buffer);
 
         /* Parse the header */
-        if(ZDParseHeader(library)) {
+        if(ZDParseHeader(library.get())) {
             zdError(ZD_E_PARSE_HEADER, 0);
-            goto fail;
+            return nullptr;
         }
     }
 
-    return library;
-
-fail:
-    ZDCloseDatabase(library);
-    return nullptr;
+    return library.release();
 }
 
 ZoneDetect *ZDOpenDatabase(const char *path)
 {
-    auto library = static_cast<ZoneDetect *>(malloc(sizeof(ZoneDetect)));
+    ZoneDetectPtr library{static_cast<ZoneDetect *>(calloc(1, sizeof(ZoneDetect)))};
 
     if(library) {
-        memset(library, 0, sizeof(*library));
-
 #if defined(_MSC_VER) || defined(__MINGW32__)
         library->fd = CreateFile(path, GENERIC_READ, 0, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
         if (library->fd == INVALID_HANDLE_VALUE) {
             zdError(ZD_E_DB_OPEN, (int)GetLastError());
-            goto fail;
+            return nullptr;
         }
 
         const DWORD fsize = GetFileSize(library->fd, NULL);
         if (fsize == INVALID_FILE_SIZE) {
             zdError(ZD_E_DB_SEEK, (int)GetLastError());
-            goto fail;
+            return nullptr;
         }
         library->length = (int32_t)fsize;
 
         library->fdMap = CreateFileMappingA(library->fd, NULL, PAGE_READONLY, 0, 0, NULL);
         if (!library->fdMap) {
             zdError(ZD_E_DB_MMAP, (int)GetLastError());
-            goto fail;
+            return nullptr;
         }
 
         library->mapping = MapViewOfFile(library->fdMap, FILE_MAP_READ, 0, 0, 0);
         if (!library->mapping) {
             zdError(ZD_E_DB_MMAP_MSVIEW, (int)GetLastError());
-            goto fail;
+            return nullptr;
         }
 #elif defined(__APPLE__) || defined(__linux__) || defined(__unix__) || defined(_POSIX_VERSION)
         library->fd = open(path, O_RDONLY | O_CLOEXEC);
         if(library->fd < 0) {
             zdError(ZD_E_DB_OPEN, errno);
-            goto fail;
+            return nullptr;
         }
 
         library->length = lseek(library->fd, 0, SEEK_END);
         if(library->length <= 0 || library->length > 50331648) {
             zdError(ZD_E_DB_SEEK, errno);
-            goto fail;
+            return nullptr;
         }
         lseek(library->fd, 0, SEEK_SET);
 
         library->mapping = static_cast<uint8_t *>(mmap(nullptr, static_cast<size_t>(library->length), PROT_READ, MAP_PRIVATE | MAP_FILE, library->fd, 0));
         if(library->mapping == MAP_FAILED) {
             zdError(ZD_E_DB_MMAP, errno);
-            goto fail;
+            return nullptr;
         }
 #endif
 
         /* Parse the header */
-        if(ZDParseHeader(library)) {
+        if(ZDParseHeader(library.get())) {
             zdError(ZD_E_PARSE_HEADER, 0);
-            goto fail;
+            return nullptr;
         }
     }
 
-    return library;
-
-fail:
-    ZDCloseDatabase(library);
-    return nullptr;
+    return library.release();
 }
 
 ZoneDetectResult *ZDLookup(const ZoneDetect *library, float lat, float lon, float *safezone)
@@ -915,7 +886,7 @@ ZoneDetectResult *ZDLookup(const ZoneDetect *library, float lat, float lon, floa
     const int32_t latFixedPoint = ZDFloatToFixedPoint(lat, 90, library->precision);
     const int32_t lonFixedPoint = ZDFloatToFixedPoint(lon, 180, library->precision);
     size_t numResults = 0;
-    auto  distanceSqrMin = static_cast<uint64_t>(-1);
+    auto distanceSqrMin = static_cast<uint64_t>(-1);
 
     /* Iterate over all polygons */
     uint32_t bboxIndex = library->bboxOffset;
@@ -1182,7 +1153,7 @@ int ZDSetErrorHandler(void (*handler)(int, int))
 
 char* ZDHelperSimpleLookupString(const ZoneDetect* library, float lat, float lon)
 {
-    ZoneDetectResult *result = ZDLookup(library, lat, lon, nullptr);
+    std::unique_ptr<ZoneDetectResult, decltype(&ZDFreeResults)> result{ZDLookup(library, lat, lon, nullptr), ZDFreeResults};
     if(!result) {
         return nullptr;
     }
@@ -1191,23 +1162,23 @@ char* ZDHelperSimpleLookupString(const ZoneDetect* library, float lat, float lon
     size_t length = 0;
     char* strings[2] = {nullptr};
 
-    if(result[0].lookupResult == ZD_LOOKUP_END) {
-        goto done;
+    if(result->lookupResult == ZD_LOOKUP_END) {
+        return nullptr;
     }
 
-    for(int i = 0; i < result[0].numFields; i++) {
-        if(result[0].fieldNames[i] && result[0].data[i]) {
+    for(int i = 0; i < result->numFields; i++) {
+        if(result->fieldNames[i] && result->data[i]) {
             if(library->tableType == 'T') {
-                if(!strcmp(result[0].fieldNames[i], "TimezoneIdPrefix")) {
-                    strings[0] = result[0].data[i];
+                if(!strcmp(result->fieldNames[i], "TimezoneIdPrefix")) {
+                    strings[0] = result->data[i];
                 }
-                if(!strcmp(result[0].fieldNames[i], "TimezoneId")) {
-                    strings[1] = result[0].data[i];
+                if(!strcmp(result->fieldNames[i], "TimezoneId")) {
+                    strings[1] = result->data[i];
                 }
             }
             if(library->tableType == 'C') {
-                if(!strcmp(result[0].fieldNames[i], "Name")) {
-                    strings[0] = result[0].data[i];
+                if(!strcmp(result->fieldNames[i], "Name")) {
+                    strings[0] = result->data[i];
                 }
             }
         }
@@ -1217,14 +1188,14 @@ char* ZDHelperSimpleLookupString(const ZoneDetect* library, float lat, float lon
         if(string) {
             size_t partLength = strlen(string);
             if(partLength > 512) {
-                goto done;
+                return nullptr;
             }
             length += partLength;
         }
     }
 
     if(length == 0) {
-        goto done;
+        return nullptr;
     }
 
     length += 1;
@@ -1239,7 +1210,5 @@ char* ZDHelperSimpleLookupString(const ZoneDetect* library, float lat, float lon
         }
     }
 
-done:
-    ZDFreeResults(result);
     return output;
 }
